/****************************************************************************
 *
 * /home/bat/bat/fast3202_4_0_21_3_3_1/rg/vendor/adi/ad6843/linux-2.6/fusiv_src/kernel/drivers/uart2/uart2_wrapper.c
 * 
 * Copyright (C) Jungo LTD 2004
 * 
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General 
 * Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * Developed by Jungo LTD.
 * Residential Gateway Software Division
 * www.jungo.com
 * info@jungo.com
 */

#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/completion.h>
#include <linux/spinlock.h>
#include <asm/delay.h>
#include "uart2_wrapper.h"
#include "msgwrapper.h"
#include "uart2.h"

#ifdef DEBUG_UART_WRAPPER
#define UW_DBG(fmt, arg...)  printk(KERN_INFO "%s: " fmt "\n" , \
    __func__ , ## arg)
#else
#define UW_DBG(fmt, arg...)
#endif

#ifndef MIN
#define MIN(a,b) (((a) < (b)) ? (a) : (b))
#endif

#define BUFFER_SIZE 1024

recv_callback_t recv_callback = NULL;
void *recv_context = NULL;
int recv_task_pid = -1;
static DECLARE_COMPLETION(recv_task_exited);

static int uart_wrapper_wait_for_data(void)
{
    return wait_event_interruptible(Q_waitq, msgQNumMsgs(gulUartRcvQId)); 
}

static int uart_wrapper_recv_task(void *dummy)
{
    char buff[BUFFER_SIZE];
    int recv_len;

    daemonize("uart_recv");

    while (!signal_pending(current))
    {
	if (uart_wrapper_wait_for_data())
	{
	    UW_DBG("received signal");
	    break;
	}
	if ((recv_len = uart_wrapper_receive(buff, sizeof(buff))))
	    recv_callback(recv_context, buff, recv_len);   
    }
    recv_task_pid = -1;
    complete_and_exit(&recv_task_exited, 0);
    return 0;
}

int uart_wrapper_start_receiving_task(recv_callback_t recv, void *context)
{
    if (!recv)
	return -1;

    recv_callback = recv;
    recv_context = context;
    recv_task_pid = kernel_thread(uart_wrapper_recv_task, NULL,
	CLONE_FS | CLONE_FILES | CLONE_SIGHAND);
    if (recv_task_pid >= 0)
    {
	UW_DBG("started task");
	return 0;
    }
    return -1;
}
EXPORT_SYMBOL(uart_wrapper_start_receiving_task);

#define MAX_TX_RETRIES 10

int uart_wrapper_send(unsigned char *buff, unsigned int count)
{
    int i;
    
    UW_DBG("");
    
    for (i = 0; i < MAX_TX_RETRIES; i++)
    {
	if (uart_send_handler(buff, count) == SUCCESS)
	    break;
	udelay(10);
    }
    return i < MAX_TX_RETRIES ? count : 0;
}
EXPORT_SYMBOL(uart_wrapper_send);

typedef struct
{
    unsigned char *buff;
    unsigned char *curr_ptr;
    unsigned int curr_len;
} buffered_data_t;

static buffered_data_t buffered_data;

int uart_wrapper_receive(unsigned char *buff, unsigned int count)
{      
    unsigned int save_count = count;
    unsigned char *buff_idx = buff;

    while(count)
    {
	/* we don't have any buffered data, try reading from Q */
	if (!buffered_data.curr_len)
	{
	    uartMsg_t uartData;
	    if (msgQReceive(gulUartRcvQId, (char *) &uartData, sizeof(uartData),
		IPC_NOWAIT) != FAILURE)
	    {
		buffered_data.buff = (unsigned char *)uartData.ptr;
		if(buffered_data.buff)
		{
		    buffered_data.curr_len = buffered_data.buff[0]; 
		    if(buffered_data.curr_len)
			buffered_data.curr_ptr = &buffered_data.buff[1]; 
		}
	    }
	    else
	    {
		UW_DBG("no data recevied from Q");
		return 0;
	    }
	}
	if (buffered_data.curr_len)
	{
	    int tmp_len = MIN(buffered_data.curr_len, count);
	    memcpy(buff_idx, buffered_data.curr_ptr, tmp_len);
	    buff_idx += tmp_len;
	    buffered_data.curr_ptr += tmp_len;
	    count -= tmp_len;
	    buffered_data.curr_len -= tmp_len;
	}

	if (!buffered_data.curr_len)
	{
	    if (buffered_data.buff)
	    {
		uartFreeCluster(buffered_data.buff);
		memset(&buffered_data, 0, sizeof(buffered_data));
	    }
	    break;
	}
    }	  
    UW_DBG("returning with %d bytes", save_count-count);
    return save_count-count;


}
EXPORT_SYMBOL(uart_wrapper_receive);

void uart_wrapper_stop_task(void)
{
    UW_DBG("");

    if ( recv_task_pid > -1)
    {
	kill_proc(recv_task_pid, SIGTERM, 1);
	wait_for_completion(&recv_task_exited);
    }
}
EXPORT_SYMBOL(uart_wrapper_stop_task);


