/****************************************************************************
 *
 * /home/bat/bat/fast3202_4_0_21_3_3_1/rg/vendor/adi/ad6843/common/kernel/epld.c
 * 
 * Copyright (C) Jungo LTD 2004
 * 
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General 
 * Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * Developed by Jungo LTD.
 * Residential Gateway Software Division
 * www.jungo.com
 * info@jungo.com
 */

#include <asm/io.h>
#include <linux/module.h>

#include <vendor/epld.h>

#define EPLD_REGS_NUM 4

typedef struct {
    unsigned long addr; /* register memory mapped physical address */
    unsigned short read_mask; /* physically allowed read mask */
    unsigned short write_mask; /* physically allowed write mask */
    unsigned short status; /* mirrored written value of register */
} epld_reg_info_t;

static epld_reg_info_t epld_reg[EPLD_REGS_NUM] = {
    /* Reg 0 is write only (8 lsbs) */
    { KSEG1ADDR(0x1d000000), 0, 0xff, EPLD_LUMIN0 },
    /* Reg 1 is write only (4 lsbs) */
    { KSEG1ADDR(0x1d004000), 0, 0x0f, EPLD_RST_USBH_N },
    /* Reg 2 is read only (4 lsbs) */
    { KSEG1ADDR(0x1d008000), 0x0f, 0 },
    /* Reg 3: some bits are r.o, other are w.o */
    { KSEG1ADDR(0x1d00c000), EPLD_USBPOWDET|EPLD_WIRELESS_ASSOC,
	EPLD_RELANCE_WDOG|EPLD_SPI_CS_FXO_N, EPLD_SPI_CS_FXO_N },
};

unsigned short epld_reg_read(epld_reg_num_t reg)
{
    epld_reg_info_t *r = epld_reg + reg;
    unsigned short val;

    /* combine mirrored stored value (w.o bits) with actual physical r.o bits */
    val = r->status & r->write_mask;
    if (r->read_mask)
	val |= inw(r->addr) & r->read_mask;
    return val;
}

void epld_reg_flags_set(epld_reg_num_t reg, unsigned short flags)
{
    epld_reg_info_t *r = epld_reg + reg;

    r->status |= flags & r->write_mask;
    outw(r->status, r->addr);
}
    
void epld_reg_flags_reset(epld_reg_num_t reg, unsigned short flags)
{
    epld_reg_info_t *r = epld_reg + reg;

    r->status &= ~(flags & r->write_mask);
    outw(r->status, r->addr);
}

void epld_reg_flags_toggle(epld_reg_num_t reg, unsigned short flags)
{
    epld_reg_info_t *r = epld_reg + reg;
    
    r->status ^= flags & r->write_mask;
    outw(r->status, r->addr);
}

void epld_reg_flags_mask_write(epld_reg_num_t reg, unsigned short flags,
    unsigned short mask)
{
    epld_reg_info_t *r = epld_reg + reg;

    mask &= r->write_mask;
    r->status = (r->status & ~mask) | (flags & mask);
    outw(r->status, r->addr);
}

void epld_reg_init(void)
{
    int i;

    /* initialize write registers according to their init values */
    for (i = 0; i < EPLD_REGS_NUM; i++)
    {
	epld_reg_info_t *r = epld_reg + i;
	
	if (r->write_mask)
	    outw(r->status & r->write_mask, r->addr);
    }
/* LUA Bug 2736 & 1890 leds flicking at start time */
    epld_reg_flags_set(EPLD_REG0, EPLD_LED_LAN_TRAF | EPLD_LED_PHONE | EPLD_LED_WAN | EPLD_LED_WIRELESS);
    epld_reg_flags_set(EPLD_REG1, EPLD_LED_FAIL);
}

EXPORT_SYMBOL(epld_reg_flags_set);
EXPORT_SYMBOL(epld_reg_flags_reset);
EXPORT_SYMBOL(epld_reg_flags_toggle);
EXPORT_SYMBOL(epld_reg_flags_mask_write);
EXPORT_SYMBOL(epld_reg_read);
