/*
 * Copyright 2005 Analog Devices
 * Author: Leo @ Analog Devices
 *
 * This program is free software; you can redistribute  it and/or modify it
 * under  the terms of  the GNU General  Public License as published by the
 * Free Software Foundation;  either version 2 of the  License, or (at your
 * option) any later version.
 */
#include <linux/init.h>
#include <linux/mm.h>
#include <linux/sched.h>
#include <linux/bootmem.h>

#include <asm/addrspace.h>
#include <asm/bootinfo.h>
#include <asm/pmon.h>
#include <linux/initrd.h>
#include <linux/sbi_k.h>

#define MB 1024 * 1024

#define REG(addr) (*(volatile char *)addr)

#ifdef CONFIG_FORCE_RECOVERY		//BUG5864

#define FORCE_RECOVERY_ADDR 0x1000
#define FORCE_RECOVERY_SIZE 0x1000

#endif

static void prom_putc(char c)
{
    while (0 == (0x20 & REG(0xb9020014)));
    REG(0xb9020000) = c;
}

void prom_puts(char *s)
{
    for (; *s; s++) 
    {
    	prom_putc(*s);
	if (*s == '\n')
	    prom_putc('\r');
    }
}

void __init prom_init(void)
{
#if 0
	mips_machgroup = MACH_GROUP_ANALOG;
	mips_machtype = MACH_ADI_GATEWAY;
#endif

	sbi = &sagem_board_info;  
	init_sbi_cpu();

	printk("<3>\n");
	printk("<3>\t.----------------------------------------------------------------.\n");
	printk("<3>\t|                     CPU_ID = 0x%04x                            |\n", CPU_ID);
	printk("<3>\t`----------------------------------------------------------------'\n");
	printk("<3>\n");
	
    sbi->mem_detect();

	printk("<3>\n");
	printk("<3>\t.----------------------------------------------------------------.\n");
	printk("<3>\t|           DYNAMICALLY DETECTED SDRAM_SIZE = %-3d Mbytes         |\n", RAM_SIZE);
	printk("<3>\t`----------------------------------------------------------------'\n");
	printk("<3>\n");

#ifdef CONFIG_FORCE_RECOVERY		//BUG5864
	add_memory_region(0, FORCE_RECOVERY_ADDR, BOOT_MEM_RAM);
	add_memory_region(FORCE_RECOVERY_ADDR, FORCE_RECOVERY_SIZE, BOOT_MEM_RESERVED);
	add_memory_region(FORCE_RECOVERY_ADDR + FORCE_RECOVERY_SIZE, RAM_SIZE * MB - (FORCE_RECOVERY_ADDR + FORCE_RECOVERY_SIZE), BOOT_MEM_RAM);
#else
	add_memory_region(0x00000000, RAM_SIZE * MB, BOOT_MEM_RAM);
#endif
	add_memory_region(0x20000000 - FLASH_SIZE * MB, FLASH_SIZE * MB,
		BOOT_MEM_ROM_DATA);

 	change_c0_status(ST0_BEV, 0);
}

unsigned long __init prom_free_prom_memory(void)
{
	return 0;
}
