#include <oswrapper.h> 
#include "G711PLCCons.h"
#include "G711PLCBasic_op.h"
#include "G711pLcProto.h"
#include "G711pLcVar.h"

#if G711_PLC

/****************************************************************************
File Name : G711PlcLib.c
            It has got following function definitions :
		  - overLapAdd			 
	          - overLapAddatEnd
	          - SaveSpeech 
                  - GetFeSpeech //--> get First Erased Speech	  
			  - ScaleSpeech
			  - CopyBuffer
			  - FillZeros
***************************************************************************/


/**************************************************************************
 	Function Name: 	overlapadd
	Description:     Overlap add left and right sides
***************************************************************************/
 
void overlapadd()
{

  Word16 i;
	  
	incr  =  div_s_plc(1,Temp1_plc);
	lw    =  sub(32767,incr);
	rw    =  incr;

	for (i = 0; i < Temp1_plc; i++)
	{
		OLAdd = L_add_plc( L_mult_plc(lw,BuffPtr1[i]), L_mult_plc(rw,BuffPtr2[i]) );
		BuffPtr3[i] = round(OLAdd);
		lw = sub(lw, incr);
		rw = add(rw,incr);
	}
}
														  
/**************************************************************************
 	Function Name: 	overlapaddatend
	Description:     Overlap add the end of the erasure with the start of the first good frame
					 Scale the synthetic speech by the gain factor before the OLA.

***************************************************************************/


void overlapaddatend()
{

  Word16 i;	

	incr = div_s_plc(1,Temp1_plc); 
		
#if ( FRAME_LEN == 40)
	if(EraseCnt < 4 )		
		   gain = 32767;
		   else if(EraseCnt < 12 )		
	          gain  =  32767 - ATTENT_START * ( EraseCnt - 3);
		     else		
		       gain = 0;
#endif

#if ( FRAME_LEN == 44)
	if(EraseCnt < 4 )		
	       gain = 32767;
	   else if(EraseCnt < 11 )		
               gain  =  32767 - ATTENT_START * ( EraseCnt - 3);
	     else		
	       gain = 0;
#endif

#if ( FRAME_LEN == 80)
	if(EraseCnt < 6 )		
	       gain  =  32767 - ATTENT_START * ( EraseCnt - 1);
		else		
		   gain = 0;
#endif				
		/*  gain = sub(32767, mult(sub(erasecnt,1),ATTENFAC)); */

	incrg = mult(incr,gain);
	lw = mult(sub(32767,incr),gain);
	rw = incr;

	//if (gain < 0)
	//	gain = 0;	

	for (i = 0; i < Temp1_plc; i++)
	{	 
		OLAddAtEnd = L_add_plc( L_mult_plc(lw,TempBuff[i]) , L_mult_plc(rw,speech[i]));
		speech[i] = round(OLAddAtEnd);	
		lw = sub(lw,incrg);
		rw = add(rw,incr);
	}
}



/**************************************************************************
 	Function Name: 	savespeech										  
	Description:     Save a frames worth of new speech in the history buffer.
			 Return the output speech delayed by POVERLAPMAX.
 	Input Parameter:
			pointer to present frame 80 samples 
	Return Values
		none													
	Functions called
			copys																	  	
***************************************************************************/
void savespeech()
{

  Word16 i;
	/* make room for new signal */	   
        for ( i = 0; i < FRAME_LEN ; i++ )
	{  
		HistoryBuffPtr[ HistoryWtIndex++ ] = speech[i]; 
		speech[i] = HistoryBuffPtr[HistoryRdIndex++];
		
		HistoryWtIndex = HistoryWtIndex % HISTORYLEN;
		HistoryRdIndex = HistoryRdIndex % HISTORYLEN;
	}
	//copy(&SMM_History[FRAME_LEN], SMM_History, HISTORYLEN - FRAME_LEN);
				/* copy in the new frame */
	//copy(speechPtr, &SMM_History[HISTORYLEN - FRAME_LEN], FRAME_LEN);
				/* copy out the delayed frame */
	//copy(&SMM_History[HISTORYLEN - FRAME_LEN - POVERLAPMAX], speechPtr, FRAME_LEN);
}

  
/**************************************************************************
Function Name: 	getfespeech										  
Description:    Get samples from the circular pitch buffer. Update Pitch_offset
		so when subsequent frames are erased the signal continues.

input Parameters:												   
		pointer to present frame 80 samples 
Return Values 													  
		none											
Functions called
		none.
***************************************************************************/


void getfespeech()
{	
	   //--> BuffPtr1 --> out
	   //--> Temp1   --> sz
        while (Temp1_plc)
	{
		//--> Available samples Count in Synthetic Speech Buffer.
		//--> SMM_Pitch_offset caters the  previous, movement of
		//--> Synthetic bufferRead Pointer.

		cnt =  PitchBlen - Pitch_offset;
		if (cnt > Temp1_plc)
			cnt = Temp1_plc;
		
		copy((Word16 *)( PitchBuffPtr + HISTORYLEN + Pitch_offset - PitchBlen), BuffPtr1, cnt);
			
		Pitch_offset += cnt;
	
		if ( Pitch_offset == PitchBlen)
			Pitch_offset = 0;
	
		BuffPtr1 += cnt;
		Temp1_plc -= cnt;
	}
}

/**************************************************************************
 	Function Name: 	scalespeech										  
	Description:     scale down speech in case of multiple frame erasures
 	Input Parameters:												   
			pointer to present frame 80 samples 
	Return Values 													  
			none														
	Functions called
			none
***************************************************************************/

void scalespeech()
{
  Word16 i;

#if (( FRAME_LEN == 40) || ( FRAME_LEN == 44 ))	   
	   if(EraseCnt == 1)
		  return;
	   RampFact  =  32767 - ATTENT_START * ( EraseCnt - 2);
#endif

#if ( FRAME_LEN == 80)
	    RampFact  =  32767 - ATTENT_START * ( EraseCnt - 1);
#endif

	// 20% Downsloping ramp starting sample.		
	for (i = 0; i < FRAME_LEN; i++)
	{
	  speech[i] = mult(speech[i],RampFact); // Scale down each sample with a 20% downsloping ramp.
          RampFact  = sub(RampFact , ATTEN_INCR);
	}
}




/******************************************************************
 Function Purpose:		This function will generate, Packet Loss  cases.
		                by using Uniform Random Number generator.

 Input  :    What is        
 OutPut :    PacketType.

*******************************************************************/				

void copy(Word16 *SourcePtr, Word16 *DestPtr, Word16 cnt)
{
  Word16 i;

	for (i = 0; i < cnt; i++)
		DestPtr[i] = SourcePtr[i];
}


/******************************************************************
 Function Purpose:		This function will generate, Packet Loss  cases.
		                by using Uniform Random Number generator.

 Input  :    What is        
 OutPut :    PacketType.

*******************************************************************/				

void zeros()
{
  Word16 i;

	for (i = 0; i < FRAME_LEN; i++)
		speech[i] = 0;
}
	  
#endif
