/* ============================================================================
 *
 * Copyright (C) 2001 Analog Devices Inc. All rights reserved
 *
 * The information and source code contained herein is the exclusive property
 * of Analog Devices and may not be disclosed, examined or reproduced in whole
 * or in part without the explicit written authorization from Analog Devices.
 *
 * ============================================================================
 */

#ifndef __DSPIPC_H
#define __DSPIPC_H

#include <voiceopt.h>
#include <voicelib.h>
#include <voiceconf.h>
#include "../dsplib/ToneGenCons.h"
/* SAGEM -> [ Modified DECT, RTP and GenVoice Api ] { */
#include <voiceApi.h>
/* } */
#define MAX_COMMANDQ_BUF 80
#define MAX_COMMAND_WORDS_PER_CHANNEL   7

#define MAX_PAYLOAD_SIZE_IN_WORDS  40
#define MAX_PAYLOAD_SIZE_IN_BYTES  80
#define MAX_JITTER_BUF_SIZE 50


#define H2D_RESET_ALL_CH_CMD    		0x1
#define H2D_CONNECT_CH_CMD      		0x2
#define H2D_MODIFY_CH_CMD       		0x3
#define H2D_DISCONNECT_CH_CMD   		0x4
#define H2D_TONE_GENERATE_CMD   		0x6
#define H2D_QUIT_TONE_CMD       		0x7
#define H2D_DTMF_DIGIT_RCVD_CMD 		0x8
#define H2D_VAR_GAIN_ADJUST_CMD 		0x9
#define H2D_ECHO_PARAMS_CMD     		0xb
#define H2D_SET_DTMF_REJ_HANGOVER_CMD 0xe 
#define H2D_SET_DTMF_REJ_CMD    0xf

#define H2D_V21_DETECTION_RCVD_CMD              0x0012

#define H2D_FAX_SG3TOG3_FALLBACK_CMD            0x0014

#define H2D_SPORT_CODEC_CONFIG_CMD  		0x0015
#define H2D_FAR_END_TONE_START  		0x38
#define H2D_FAR_END_TONE_STOP    		0x39




#define H2D_START_CONFERENCE_CMD                0x00aa
#define H2D_STOP_CONFERENCE_CMD                 0x00bb

/******************************************************************
          DSP TO ACKNOWLEDGEMENTS/ COMMANDS
******************************************************************/

#define D2H_INIT_THREE_WAY_CONFERENCE_DONE      0x00cc
#define D2H_QUIT_THREE_WAY_CONFERENCE_DONE      0x00dd





#define H2D_mANSWER_CMD         0x32
#define H2D_CED_TONE_RCVD_CMD   0x34
#define H2D_FAX_DEBUG           0x35
                                                                                
#define H2D_CNCT_TONEDTMF_FXSFXO    0x205
#define H2D_QUIT_TONEDTMF_FXSFXO    0x206
                                                                                
#define D2H_RESET_ALL_CH_DONE    0x40
#define D2H_CONNECT_CH_DONE      0x41
#define D2H_MODIFY_CH_DONE       0x42
#define D2H_DISCONNECT_CH_DONE   0x43
#define D2H_DEBUG_DATA_DONE      0x44
#define D2H_ERROR_ON_BLK_SLT     0x45
#define D2H_TONE_GENERATE_DONE   0x46
#define D2H_QUIT_TONE_DONE       0x47

#define D2H_DTMF_DIGIT_REPORT    0x48
#define D2H_DTMF_DIGIT_TONE_START_REPORT   0x50
#define D2H_DTMF_DIGIT_TONE_END_REPORT  0x51
#define D2H_DTMF_DIGIT_TONE_CONT_REPORT 0x52

#define D2H_INIT_THREE_WAY_CONFERENCE_DONE  0x00cc
#define D2H_QUIT_THREE_WAY_CONFERENCE_DONE  0x00dd

#define D2H_VAR_GAIN_ADJUST_DONE     0x49 
#define D2H_CNG_TONE_REPORT          0x61
#define D2H_mMODEMREADY              0x62
#define D2H_FAX_MODEM_TONE_DETECTED    0x4c 
/*
#define D2H_SIN_FAXTONE_DETECTED    0x4c 
#define D2H_RIN_FAXTONE_DETECTED    0x4d 

#define D2H_SIN_MODEMTONE_DETECTED   0x4e 
#define D2H_RIN_MODEMTONE_DETECTED   0x4f 
*/

#define D2H_V21_PREAMBLE_DETECT   0x006a

#if DECT_MODULE
#define H2D_DECT_TRANSCODING_START   0x100
#define H2D_DECT_TRANSCODING_STOP      0x101
#define H2D_DECT_FXO_START           0x102 /*DECTFXO JAN 19, 2009*/
#define H2D_DECT_FXO_STOP            0x103 /*DECTFXO JAN 19, 2009*/
#endif
                                                                                
#define MAX_CMD_LIST    10
#define MAX_VOICE_BUFS 10
#define  DEFAULT_INIT_CODEC  1

#if !TONE_GEN
                                                                                
#define DIAL_TONE                       0x1
#define RING_BACK_TONE                  0x2
#define BUSY1_TONE                      0x3
#define CALL_WAITING_TONE1              0x5
                                                                                
#ifdef FRANCETONES
  #define ERROR_TONE                    BUSY1_TONE
  #define SPECIAL_DIAL_TONE             0x1b
  #define CALL_WAITING_TONE2            CALL_WAITING_TONE1
  #define STUTTER_TONE                  SPECIAL_DIAL_TONE
  #define OFFHOOK_WARNING_TONE          BUSY1_TONE
  #define SPL_INFO_TONE                 0x1c
  #define ROC_TONE                      0x1d
  #define MESG_WAITING_INDICATOR_TONE   0x1f
  #define VOIP_DIAL_TONE                0x20
#else
  #define ERROR_TONE                    0x4
  #define CALL_WAITING_TONE2            0x6
  #define REORDER_TONE                  0x7
  #define STUTTER_TONE                  0x8
  #define OFFHOOK_WARNING_TONE            0x9
#endif
                                                                                
#define MELODY_TONE                     0xa
#define CPE_ALERTING_TONE    0x1e
                                                                                
// DIGIT_TONES
#define DIG_0_TONE                      0xb
#define DIG_1_TONE                      0xc
#define DIG_2_TONE                      0xd
#define DIG_3_TONE                      0xe
#define DIG_4_TONE                      0xf
#define DIG_5_TONE                      0x10
#define DIG_6_TONE                      0x11
#define DIG_7_TONE                      0x12
#define DIG_8_TONE                      0x13
#define DIG_9_TONE                      0x14
#define DIG_A_TONE                      0x15
#define DIG_B_TONE                      0x16
#define DIG_C_TONE                      0x17
#define DIG_D_TONE                      0x18
#define DIG_STAR_TONE                   0x19
#define DIG_HASH_TONE                   0x1a
#endif
#define DTMF_REJ_HANG_CNTR 9

#ifdef DECT_DIGIT
#define H2D_DECT_DIGIT_GEN_START            0x0036
#define H2D_DECT_DIGIT_GEN_END              0x0037
                                                                                
#define DIG_0_TONE      0xb
#define DIG_1_TON       0xc
#define DIG_2_TONE      0xd
#define DIG_3_TONE      0xe
#define DIG_4_TONE      0xf
#define DIG_5_TONE      0x10
#define DIG_6_TONE      0x11
#define DIG_7_TONE      0x12
#define DIG_8_TONE      0x13
#define DIG_9_TONE      0x14
#define DIG_A_TONE      0x15
#define DIG_B_TONE      0x16
#define DIG_C_TONE      0x17
#define DIG_D_TONE      0x18
#define DIG_STAR_TONE   0x19
#define DIG_HASH_TONE   0x1a
#endif

#define DSP_INTERFACE_ADDR      0x3fa5
#define RG_DATA_PKT  122

#define MAX_TX_VOICE_Q MAX_VOICE_BUFS
#define MAX_DSP2HOST_CMDQ_BUFFS (MAX_VOICE_CHANNELS*MAX_COMMANDQ_BUF)




#define JIT_TONE_PACKET        6
#define JIT_FAX_DP_PACKET      5
#define JIT_CIDTX_PACKET       4
#define JIT_SPEECH_PACKET      2
#define JIT_VAD_PACKET         1
#define CONTINUE_SILENCE       0
#define JIT_NO_PACKET          0





/* Possible states for the CA */
enum caState_e
{
  CA_READY,             /* 1 */
  CA_CONNECTED,         /* 3 */
  CA_ONHOOK,            /* 11 */
  CA_CALL_WAIT,
  CA_CIDCW,
  CA_CIDCW_ACK,
  CA_DIGIT_RCVD,
  CA_DIGIT_TONE,
  CA_MWI_ON,
  CA_MWI_DIS,
  CA_DIGIT_OFF,
  CA_TONE_ON,
  CA_LOCAL_QUIT_TONE,
  CA_CIDCW_END
};
                                                                                

/* Circular Command Queue Buffer */
typedef struct _command_Q_
{
    UINT16         command[MAX_COMMAND_WORDS_PER_CHANNEL];
}CommandQ;

/* Command Buffer Structure */
typedef struct
{
  UINT16 writePtr;
  UINT16 readPtr;
  CommandQ commands[MAX_COMMANDQ_BUF];
}CommandBuffer;


/* DSP COdec Mapping */
typedef enum
{
  DSP_PCMA=0,DSP_PCMU,DSP_G729=6,DSP_G723_AH=7,DSP_G723_AL=8, DSP_3WAY=9,DSP_T38,DSP_G722
}DSPCodec_e;




/* DSPIPC Codec Structure. */
typedef struct _dspipcCodec_
{
    int curEncoderType;
    int curDecoderType;
    int newEncoderType;
    int newDecoderType;
}DspipcCodec;

/* Call Status Information Strucure */
typedef struct rcvCallStatus
{
  UCHAR dsp_ch_num; // Voice channel number
  UCHAR codec_type; // Voice codec type
  UCHAR sequence_number[4]; // Rcvd packet seq. no.
  UCHAR sr_timestamp[4]; // Send time stamp
  UCHAR rr_timestamp[4]; // rcv time stamp
  UCHAR inter_jitter[4]; // Inter jitter as in the RTCP
  UCHAR average_delay[4]; // As in the RTCP
  UCHAR payload_length;    // Voice payload length
  UCHAR valid;             // 1 :: if packet is good otherwise 0.
} RcvCallStatus_t;
                                                                                
/* DSP State Info Structure */
typedef struct
{
  UCHAR ucState;
  UCHAR ucExpSeqNo;
  UCHAR ucToneType;
  UINT16 uiWaitCntr;
  UINT16 uiEncoder;
  UINT16 uiDecoder;
  UINT32 ulToneTimeOut;
  UINT32 ulToneExpCntr;
  UCHAR  ucCallWtState;
  UINT16 uiWaitCwCntr;
  UINT16 uiIntDigTimer;
  UINT16 uiOutBandDigTimer;
  BOOL   bInitDone;
  UCHAR  toneState;
  UCHAR  ucMsgWiState;
  UINT16 uiMsgWiCntr;
  UCHAR  ucDigitCnt;
  UCHAR  ucDigitLen;
  UINT16 aucDigitStr[20];
}DspStateInfo_t;

/* Specifiy time in secs */
typedef struct _dspTimers
{
  UINT32   uiInterDigTimer;
}DSPTimerInfo_t;


/* Host based commands */
typedef struct
{
  int cmd;
  UCHAR port;
}dspipcHostCmd_t;

  
/* DSP Bank Address */
typedef struct _dspipcaddress_
{
    unsigned short dspBankSelectCntr;
    unsigned short hostBankSelectCntr;
    unsigned short bankSelectErrorCntr;
    unsigned short cmdHost2dspBank0;
    unsigned short cmdHost2dspBank1;
    unsigned short cmdDsp2hostBank0;
    unsigned short cmdDsp2hostBank1;
    unsigned short dataHost2dspBank0;
    unsigned short dataHost2dspBank1;
    unsigned short dataDsp2hostBank0;
    unsigned short dataDsp2hostBank1;
#if DTMFRX
    unsigned short DtmfrxDsp2hostBank0;
    unsigned short DtmfrxDsp2hostBank1;
#endif
}DspipcAddr;


typedef struct _dspipc_reg_funct_
{
  void (*voicePkt)(void);
  void (*regCmdDigit)(void);
  void (*t38Data)(void);
  void (*hookStateChanged)(void);
  void (*fxoEventRcv)(void);
}DspipcRegFunct;
                                                                                           

/* Function Prototypes */
void dspipcInitCmdRingBuffer(void);
void dspipcInitPort(UINT16 portNum, VoiceOptions *vo);
void dspipcClosePort(UINT16 portNum);
void dspipcGainCntrl(UINT16 portNum,
                     UINT16 ucGainCntrl,
                     UINT16  ucBlkGainCtrl);
void dspipcGenTone(UINT16 portNum, UINT16 ToneType,int uiTimeOut);
void dspipcSetDtmfRej(UINT16 portNum);
void dspipcQuitDtmfRej(UINT16 portNum);
void dspipcEchoCntrl(UINT16 portNum,UINT16  uiECparams);
void dspipcQuitTone(UINT16 portNum, UINT16 ToneType);
void dspipcStartConference(UINT16 portNum, VoiceOptions *vo);
void dspipcQuitConference(UINT16 port1, UINT16 port2);
void dspipcAcknowledgeDigit( UINT16 portNum,
                             UINT16 errorType,
                             UINT16 ReceivedSequence,
                             UINT16 ExpectedSequence);
void dspipcGetAddress(int dspnumber);
//void dspipcModifyPortCodec( unsigned portNum, unsigned short newEncType, unsigned short newDecType);
void dspipcModifyPortCodec(UINT16 portNum, VoiceOptions *vo);
void dspipcInitJitterBuffer(INT16 portNum);
void dspipcInitialize(void);
void dspipcCmdIntrpret(CommandQ *cmdAcks, unsigned short portNum);
void dspipcWriteJitterBuffer(VoiceQ_t *pVoice);
void dspipcResetRingDSPStateInfo(UCHAR ucPort);
void dspipcVoiceRing(UCHAR ucPort, int ucNumRings);
void dspipcVoiceRingOff(UCHAR ucPort, BOOL bActivate);
void dspipcResetDSPStateInfo(UCHAR ucPort, VoiceOptions *vo);
void dspipcUpdateRings(UCHAR ucPort);
void dspMainTask(unsigned long dspNumber);
void dspipcResetAllPorts(void);
BOOL isPortInDiagMode(UCHAR ucPort);
VOID dspipcCopyVoiceRxPkt(VoiceQ_t *dest, VoiceQ_t *src,UCHAR pktIndex,UCHAR len);
void dspipcTaskLet(UINT16  dspnumber);
void dspipcIsr(UINT16 dspnumber);
void dspipcResetDataTxQ(UCHAR ucEpIndex);
VoiceQ_t* dspipcGetVoicePkt(UINT16, UCHAR ucSessType) ;
INT32 dspipcGetVoicePktCnt(int);
int dspipcGetDSPCmdCount(void);
CmdDigitInfo_t* dspipcGetCmdPkt(void);
void dspipcRegVoiceFromDsp(void (*f)(void));
void dspipcRegCmdDigitFromDsp(void (*f)(void));
BOOL dspipcIsInitPortDone(int port);
UINT16 dspReadDataMem(UINT16 dspNum,
                                UINT16 addr);
void dspWriteIntoDataMem(UINT16 dspNum,
                                  UINT16 addr,
                                  UINT16 value);
void dspipcSetDSPDataMode(UINT16 portNum,UCHAR dspMode);

void dspDownloadMem(UINT16 dspNum,
                     UINT16 control_word1,
                     UINT16 control_word2,
                     UINT16 *dsp_code_start,
                     UINT16 count);

void dspipcInitPortDone(INT32 port,BOOL bVal);
void dspInitSportCodec(void);
void dspAssignIDMAReg(void);
void dspipcSystemInit(void);
void dspipcRegSlicStateChangeHandler(void (*f)(void));
void voiceInit(unsigned short *dsp_data);
void dspipcWriteVoicePkt(VoiceQ_t *pVoice);
void dspipcSlicStateChanged(UINT16 portNum,int hookState);
void dspipcSetCallWtState(UINT16 CurChanNum);
void mu_compress(short in[], UCHAR out[]);
void dspipcClearQs(UINT16 iIndex);

void mu_compress_short(
    Word16 in[], /* (i) - {Pointer to the input sequence } */
    Word16 out[]      /* (o) - {Pointer to the output sequence} */
);
void dspipcCidTxPlayDone(unsigned short portNum);
void dspipcSetDtmfRejHangOver(unsigned portNum);
void dspipcResetDtmfRejHangOver(unsigned portNum);
void dspipcGetDSPBankAddress(INT32 dspnumber);
int dspipcResetStateInfo(UINT16 portNum, UCHAR bOpen);
void dspipcResetFXOQ(void);
int dspipcChangeDSPImage(UINT16 portNum,int codec);
int dspipcMapDSPNum(int port);
void confSetToneDetect(UCHAR port, UCHAR toneEnable);
void ToneGenSetCountry(void);
void dspipcReportIndication(UINT16 portNum, int indication);
void dspipcGenFarEndTone(unsigned portNum);
void dspipcStopFarEndTone(unsigned portNum);
void switchJitterBuffToFjb(UCHAR ucPortNum);
UCHAR confGetJBType(void);
void
mu_expand(
    UCHAR in[], /* sneha(i) - {Pointer to the input sequence } */
    Word16 out[]            /* (o) - {Pointer to the output sequence} */
    //Word32 n                 /* (i) - {The number of input sequence  } */
);
void
a_expand(
    UCHAR in[],/* (i) - {Pointer to the input sequence } */
    Word16 out[]     /* (o) - {Pointer to the output sequence} */
    //Word32 n           /* (i) - {The number of input sequence } */
);

void a_compress(
    Word16 in[], /* (i) - {Pointer to the input sequence } */
    UCHAR  out[]      /* (o) - {Pointer to the output sequence} */

);
void G711PLC(uWord16 CurChanNum , Word16 PktType);
void CidTxPlay1(uWord16 PortNum);
UCHAR confGetFXOCallerIdDetectEnabled(void);
UCHAR confGetFXSCallerIdEnabled(UCHAR port);
UCHAR confGetToneDetect(UCHAR port);
UCHAR confGetDSPDownloadOpt(UINT16 dspNum);
void confSetDSPDownloadOpt(UINT16 dspNum, UCHAR downloadOpt);
int dsp_download_image(int dspNum);
void dspipcResetDrivers(void);
void G711PlcInit(uWord16 CurChanNum);
void dspipcSetDrivers(void);
int setMaxEthFrameReadCnt(int);
int resetMaxEthFrameReadCnt(void);
int setMaxATMFrameReadCnt(int);
int resetMaxATMFrameReadCnt(void);
void dspipcSetDataMode(UCHAR bEnable);
void dspipcToneCfg(Word16 portNum, FOURCADENCE_TONE_TYPE * pToneType);
void dspipcGenToneSpec(Word16 CurChan,Word16 ToneType, INT32 uiTimeOut);
void resetCidTxPlay(uWord16 CurChanNum);
void dspipcGenFarEndTone(unsigned portNum);
void dspipcMemWrite(VoiceMem_t *pMem);
void dspipcMemRead(VoiceMem_t *pMem);
#if FXO_MODULE
void dspipcDSPConnection(pstnDspCmdInfo_t *pstnDspInfoPtr);
void dspipcQuitConnection(pstnDspCmdInfo_t *pstnDspInfoPtr);
void setToneDet(Word16 ChNum,Word16 Tone_Type);
void ToneDetInit(Word16 ChanNum);
void confSetFXOCallerIdDetect(UCHAR port, UCHAR Enable);
UCHAR confGetfXOCallerIdDetect(UCHAR port);
INT32 dspipcGetFXOCmdCount(void);
CmdDigitInfo_t* dspipcGetFXOCmdPkt(void);
void dspipcReportFXOIndication(UINT16 port,int indication, UINT16 cptr);
#endif
void dspipcRegFXOStateChangeHandler(void (*f)(void));
void wakeupDynDownload(void);
void dspStartSPORT(void);
int  dspipcPollonDsp2completeIsr(int dspnumber);
void dspipcResetT38Q(UINT16 iIndex);
INT32 dspipcGetT38PktCnt(int context);
INT32 dspipcGetT38PktCnt(int context);
t38Pkt_t* dspipcGetT38Pkt(UINT16 portNum);
void dspipcSwitchToT38(UINT16 portNum);
void dspipcRegT38PacketFromDsp(void (*f)(void));
int dspipcWriteT38DataPkt(UCHAR *pT38Data);
void dspipcEnableConf(int port);
void dspipcFXOCallerIdDetected(UCHAR port,UCHAR CidTxFlag,UCHAR *ucRemoteUserNum,
                   UCHAR *ucRemoteUserName,UCHAR *DateBuffStr, UCHAR CidType);
void AJBDumpDebugInfo(uWord16 *pData);
void osLockTasklet(UINT16 PortNum);
void osUnlockTasklet(UINT16 PortNum);
UINT32 dspReadProgramMem(UINT16 dspNum,UINT16 addr);
void dspWriteIntoProgramMem(UINT16 dspNum,UINT16 addr,UINT16 value);

#if DECT_MODULE
int dectWriteVoice(int port, UCHAR *data, int len);
int dectReadVoicePkt(int port);
void dectISR(int dsp);
int dectInit(int dsp);
#endif

#if KERNEL_RTP_INTERFACE
int dsp_get_nw_pkt(VoiceQ_t **pVoice, int channel);
int dsp_write_nw_pkt(VoiceNWPkt_t *voice,unsigned char *pPayload);
UINT32 dspipcGetTimeStamp(int port);
#endif
void dspipcResetV21PreDet(UINT16 portNum);
void dspipcAckV21Detection( UINT16 portNum);

#endif
