/*
    Copyright (C) 2001, 2002 Encore Software Ltd.
    All rights reserved.
    Encore Software Ltd.
    6F Leo Complex
    44 & 45 Residency Cross Road
    Bangalore 560025 (INDIA)
    Tel: +91-80-558 0405 / 558 8257, Fax: +91-80-558 7690
    Email:  vasuki@ncoretech.com
*/

/*************************************************************************/
/* 
**  Filename:   t38.h
**  Description:
**    Has definitions of Iprelay data structure and relay configuration
**    structures.
**
**  Modification History:
**      
**     Date            By               Description    
**  --------------  ----------------   ------------------
** 3/ Nov /2000     Dhruva Kumar N        Created
**
*/
/***************************************************************************/

#ifndef _ESL_IPRLEAY_H
#define _ESL_IPRELAY_H 

#include "msg.h"
/*------------------------------------------------------------------------
 PREPROCESSOR OPTIONS
-------------------------------------------------------------------------*/


#ifdef T38

#define CISCO_GW

#define REALTIME            //To operate the fax data pump in real time along with T38


#endif

//---------------------------------------------------------------------------
//The following defines the ID's of Messages used by the Fax data pump
//The description of these messages is given in the ESL_FAXDP_API document
//---------------------------------------------------------------------------


#define TXHDLCLSTIME        250     //(2.5*1000)/10
#define ZEROESFOR1_35SECS   150 //135    // 1.35 secs = 1350 ms
#define ZEROESFOR1_5SECS    150    //1.5 secs = 1500ms
#define ORIGINATEMODE       1
#define ANSWERMODE          2
#define TCP                 1
#define UDP                 2


#define RELAY_INIT   0  //Relay channel is trying to establish connection
#define RELAY_V21TX  1  //Currently transmitting V.21 signal
#define RELAY_HSTX   2  // Currently transmitting High speed image signal
#define RELAY_V21RX  3  // Currently receiving V.21 signal
#define RELAY_HSRX   4  //Currently receiving High speed image signal
#define RELAY_ERROR  5  //An error condition occured, fax call needs to be
                        // terminated
#define RELAY_OK     6  //Fax relay operation successfully completed and 
                        //operation can be terminated


#define HDLCFRMEND  0x100   // To indicate frame end for back to back frames



/*Definitions of TypeOfMsg field of IFPPKTDATASTRUCT */

/*Type Of Msg = T30_INDICATOR  */
#define NOSIG           0x0
#define CNG             0x2
#define CED             0x4
#define V21PREAMBLE     0x6
#define V272400TRN      0x8
#define V274800TRN      0xA
#define V297200TRN      0xC
#define V299600TRN      0xE
#define V177200STTRN    0x10
#define V177200LTTRN    0x12
#define V179600STTRN    0x14
#define V179600LTTRN    0x16
#define V1712000STTRN   0x18
#define V1712000LTTRN   0x1A
#define V1714400STTRN   0x1C
#define V1714400LTTRN   0x1E

/*Type Of Msg = T30_DATA */
#define V21C2       0xC0
#define V27_2400    0xC2
#define V27_4800    0xC4
#define V29_7200    0xC6
#define V29_9600    0xC8
#define V17_7200    0xCA
#define V17_9600    0xCC
#define V17_12000   0xCE
#define V17_14400   0xD0

/*Definitions of FieldType field of DATAFIELDDATASTRUCT */
#define HDLCDATA         0x80
#define HDLCSIGEND       0x10
#define HDLCFCSOK        0x20
#define HDLCFCSBAD       0x30
#define HDLCFCSOKSIGEND  0x40
#define HDLCFCSBADSIGEND 0x50
#define T4NONECMDATA     0xe0
#define T4NONECMSIGEND   0x70
#define T4NONECMDATASIGEND 0xF0 


// T30 Related definitions
#define TURNAROUNDTIME    7

#define DISID   0x1         //0x80
#define DTCID   0x81        //0x81
#define DCSID   0x41        //0x82
#define FTTID   0x22        //0x44
#define CFRID   0x21        //0x84
#define EOPID   0x74        //0x2E
#define MPSID   0x72        //0x4E
#define MCFID   0x31        //0x8C
#define RTNID   0x33        //0xCC
#define RTPID   0x32        //0x4C
#define CSIID   0x02        //0x40
#define CIGID   0x82        //0x41
#define TSIID   0x42        //0x42
#define DCNID   0x5F        //0xFA
#define EOMID   0x71        //0x8E
#define NSFID   0x04        //0x20
#define NSCID   0x84        //0x21
#define NSSID   0x44        //0x22
#define CRPID   0x58        //0x1A

#define pWDID   0x83        //0xC1
#define SEPID   0x85        //0xA1
#define SUBID   0x43        //0xC2
#define PWDID   0x45        //0xA2
#define CTCID   0x48        //0x12
#define PPRID   0x3D        //0xBC
#define RNRID   0x37        //0XEC
#define ERRID   0x38        //0x1C
#define PEOMID  0x79        //0x9e
#define PMPSID  0x7A        //0x5e
#define PEOPID  0x7C        //0x3e
#define CTRID   0x23        //0xc4
#define EORID   0x73        //0xce
#define RRID    0x76        //0x6e
#define PIPID   0x35        //0xac
#define PINID   0x34        //0x2c
#define PPSID   0x7D        //0xBE
#define NULLID   0x0


#define MAXREDUNDANCY   6
#define MINIMGLEN       100
#define MINPLEN         3
#define BUFLEN          3000
#define SPOOFBUFLEN     64
#define MAXQLEN         511
#define PKTSIZE         400
#define RX_IFP_MAXSIZE  200
#define TX_IFP_MAXSIZE  200
#define MAX_IFP_REORDER	15 //8
#define REORDERBUFLEN   (RX_IFP_MAXSIZE * MAX_IFP_REORDER)
#define SIZEBUFSIZE     400
#define CRCBUFSIZE      10

#define TEMPBUFSIZE     2160    //180*6


/*Number of bytes to be transmitted in high speed mode for 10ms interval */
#define V2724MaxBytes   3
#define V2748MaxBytes   6
#define V2972MaxBytes   9
#define V2996MaxBytes   12
#define V1772MaxBytes   9
#define V1796MaxBytes   12
#define V17120MaxBytes  15
#define V17144MaxBytes  18

    
/*------------------------------------------------------------------------
 PUBLIC VARIABLES DEFINITIONS
-------------------------------------------------------------------------*/


typedef struct{
  INT16 iPortNo;
  INT16 iImageDataTx;         //set when image data packets will be 
                              //received
//Pointer to structure that maintains the Queue having messages to T38
  tMSGQSTRUCT *ptT38InMsgQStr;
//Pointer to structure that maintains the Queue having responsess from T38
  tMSGQSTRUCT *ptT38OutMsgQStr;

  UCHAR8 *piDataBufPtr;     //pointer to data buffer
  UCHAR8 *paiOpPktPtr;      //pointer to buffer that contains IPF packet
                            //that has to be sent to IP network
  UCHAR8 *piIpPktPtr;       //pointer to buffer that contains IPF packet
                            //that has been received from IP network
  INT16 iOpPktValid;        //when nonzero indicates presence of a
                            //valid pkt ready for transmission
  INT16 iIpPktValid;        //when nonzero indicates presence of a valid
                            //pkt that could be read by the T.38 layer
  INT16 iSequenceNumber;    //sequence number of the IFP packet
  INT16 iCallType;          //ORIGINATE = 1 or ANSWER = 2
  INT16 iPreambleTim;       //timer for preamble flags
  INT16 iTimerHL;           //While switching from high speed to low
                            //speed mode
  INT16 iTimerLH;           //While switching from low speed to high
                            //speed mode
  void (*fpStateFnPtr)(void *);       //state machine function pointer
  INT16 iHdlcEnable;        //Set to 1 for HDLC mode
  INT16 iHdlcFrameEnd;      //indicates end of HDLC frame
  INT16 iHdlcHSEnableTx;    //set to 1 for high speed HDLC transmit mode
  INT16 iHdlcHSEnableRx;    //set to 1 for high speed HDLC receive mode
  UCHAR8 *piImageDataPtr;   //to write high speed data to data buffer
  UCHAR8 *piReadDataPtr;    //to read from data buffer
  UCHAR8 *piFrameDataPtr;   //to write low speed data to data buffer
  INT16 iNoCarStat;         //indicates the drop of carrier
  INT16 iConnected;         //indicates status of DP
  INT16 iFrameAckFrmDp;     //acknlowdgement from DP for HDLC frame
  INT16 iTrnRxFlg;          //set when DP received the traning sequence
  INT16 iTrnTxFlg;          //set when traning sequence indicator pkt is
                            //received
  INT16 iLTrnTx;            //set to 1 for V.17 long train
  INT16 iCnt7e;             //to count flags from DP
  INT16 iSigEnd;            //set to 1 on reception of sig_end indicator
  INT16 iPreambleRxFlg;     //set on reception of HDLC flags from DP
  INT16 iPreambleTxFlg;     //set on reception of preamble indicator pkt
  INT16 iByteCnt;           //count the number of bytes in data buffer
  INT16 iPackedBytes;       //count the number of bytes to be packed
  INT16 iNumBytes;          //number of bytes to be packetized
  INT16 iHdlcDataAvl;       //when 1 indicates availability of HDLC data
  INT16 iPrevFrameTx;       //previous HDLC frame send to DP
  INT16 iPrevFrameRx;       //previous HDLC frame received from DP
  INT16 iFinalFrame;
  INT16 iPrevFrameRxPPS;
  INT16 idRateRx;           //used while sending msg to DP to configure
                            // it for high speed
  INT16 iPktdRateRx;        //used while forming packets
  INT16 iIndPktdRateRx;     //mode in which DP should demodulate
  INT16 idRateTx;           //rate at which image is remodulated
  INT16 iPktdRateTx;        //indicates the mode in which the image
                            //will be re-modulated
  INT16 iIndPktdRateTx;     //mode in which DP should re-modulate
  INT16 iV17ModeRx;         //set for V.17 receive mode
  INT16 iV17ModeTx;         //set for V.17 transmit mode
  tMESSAGE tMessage;        //message structure
  INT16 iCmdAckFrmDp;       //response of DP for a particular command
  INT16 iFlgTimer;          //timer to send flags by DP
  INT16 iBytesInHS;         //number of bytes required in TCF
  INT16 iShutDown;          //to stop the relay operation

  INT16 iEndOfSession;      //to stop the relay operation
  INT16 iErrTimer;
  INT16 iEcm;               //indicates error correction mode
 INT16 iCng;                //set on receiving CNG packet
 INT16 iCed;                //set on receiving CED packet
  INT16 iCallMode;          //ORIGINATE = 1 or ANSWER = 2
//level of redundancy in UDP mode
  UINT16 iLSRedundancy;
  UINT16 iHSRedundancy;
  UINT16 iCurrentRedundancy;

  UINT16 TxPayloadSize;		//Size of payload to be sent to IP n/w
  INT16 iSizeOfDataBuf;     //Size of the buffer which stores the data
                            //obtained from DP as well as from IP network
  INT16 iSizeOfInMsgQueue;  //Size of the buffer which queues messages
                            //that are to be sent to DP
  INT16 iSizeOfOutMsgQueue; //Size of the buffer which queues responses
                            //that are sent by DP
  INT16 iChannelMemory;     //memory required for 1 channel of IP relay
  INT16 iMinReqdZeroesInTCF;//minimum number of zeroes required in TCF
  INT16 iZeroesInTCF;       //number of zeroes in TCF
  INT16 iZeroesInTCFTx;
  INT16 iReqdZeroesInTCFForTx;
  INT16 iLocalRespOfTCF;    //local response for TCF
  INT16 iHdlcTxByteCnt;     //counter for HDLC bytes
  INT16 iProcLSFrameTx;
  INT16 iXOFF;                //to pause the DP from sending data
  INT16 iTxHdlcLSTimeOut;     //time with in which a Packet having a
                              //valid HDLC frame should arrive
  UCHAR8 *piSpoofingBufPtr;   //pointer to spoofing buffer
  UCHAR8 *piWrSpoofingBufPtr; //to read from spoofing buffer
  UCHAR8 *piRdSpoofingBufPtr; //to write to spoofing buffer
  UINT16 iSizeOfSpoofingBuf;  //Size of the buffer which stores data got
                              //from network which has to be spoofed to DP
  INT16 iSpoofPreambleTim;    //time for which flags will be spoofed
  INT16 iWaitForPreambleTxFlgTim;//time after which spoofing of flags will
                                 //be started
  INT16 iSpoofStartTimer;     //time after which spoofing of flags will
                              //be started
  INT16 iCRCStatusRx;         //CRC status of frame received from DP
  INT16 iPrevCRCStatus;       //FCS of prev frame received from n/w
  //INT16 iImageDataTx;         //set when image data packets will be 
                              //received
  INT16 iGOTEOL;              //set on detecting EOL sequence
  INT16 iZeroBitCount;        //counts number of zeroes in the pkt data
  INT16 iEOLCnt;              //incremented on receiving EOL
  INT16 iNoCarCounter;        //number of no carrier messages required
  INT16 iDisableData;         //stop packing the data 
  INT16 iDisablePktData;      //prevent repeated V.21 control data pkts
  INT16 iSigEndHS;            //indicates end of signal
  INT16 iTCFdata;             //set when TCF data is being transfered
  INT16 iTCFZeroCnt;          //counts zeroes received in TCF sequence
  INT16 iGoodTCFPkts;         //indicates the correcness of TCF received
  INT16 iMinImageLen;         //number of bytes of image data per packet

  UINT16 Impairment;

  //to ignore DS pkts when t38 starts packetization
  INT16 IgnorePkts;
  INT16 iResendPktCnt;	//to resend indicator pkts
  INT16 iDroppedPkt;
  INT16 iNoOfPktInROBuf;
  UINT16 iCRCRIndex;
  UINT16 iCRCWIndex;
  UINT16 iSizeRIndex;
  UINT16 iSizeWIndex;
  UINT16 PrevLineData;

  UCHAR8 *pTempImageW;
  UCHAR8 *pTempImageR;
  UINT16 iSizeOfTempImageBuf;

// length of Down Stream packet buffer queue (Jitter buffer)
  UINT16 JitterBufLen;
  UINT16 iBytesRemaining;
  INT16 iFrameLength;         //PCM frame length
  INT16 iTCPBytesRead;
  UCHAR8 *piReOrderBufPtr;    //pointer to re order buffer
  INT16 iPrevPktRead;         //sequence number of previous packet 
                              //processed
  INT16 iRxSeqNo;             //sequence number of received packet
//Number of seconary packets encoded in the received UDP payload
  UINT16 iNoOfSecInRxPkt;

//Run time flag to enable/disable debug strings
  UINT16 EnableDebug;

  INT16 iPrevBufIndex;
     //buffer that stores the out of order packets
  UCHAR8 aiReOrderBuffer[REORDERBUFLEN];
  // buffer which stores the data obtained from DP as well as from IP network
  UCHAR8 aiDataBuffer[BUFLEN];
    //buffer to store reordered received packet 
  UCHAR8 aiIpPktBuf[RX_IFP_MAXSIZE];
    //buffer to store low speed HDLC data for spoofing
  UCHAR8 aiSpoofBuffer[SPOOFBUFLEN];
    //buffer to hold the UDP packet which was formed earlier
  UCHAR8 aiPrevPktBuf[TX_IFP_MAXSIZE * MAXREDUNDANCY];

  UCHAR8 aiCRCBuf[CRCBUFSIZE];
  UINT16 aiSizeBuf[SIZEBUFSIZE];

  UCHAR8 TempImageBuf[TEMPBUFSIZE];

//Down stream packet queue, (Jitter buffer)
  UCHAR8 JitterBuffer[RXPKTQLEN];     
}tFAXRELAY_ESL_T38;


  //UCHAR8 JitterBuffer[MAX_VOICE_CHANNELS][RXPKTQLEN];     
  //void (*fpStateFnPtr)(void *);       //state machine function pointer
typedef void (*fpPtrIntFn)(void *);

#ifdef FAX_T38_QUE
#define T382DSPQUELEN 20

typedef struct
{
  UCHAR  T38op[T382DSPQUELEN][80]; //200ms Queue
  UINT16 T38OpFlag[T382DSPQUELEN];
  INT16  T38opRdIndex;
  INT16  T38opWtIndex;
  UINT16 T38RxSeqNo;
  UINT16 T38TxSeqNo;
  UINT16 T382DspErr;
}tT382Dsp_;
#endif //end of #ifdef FAX_T38_QUE

#endif

/*--------------------------------------------------------------------
             END    OF   FILE
---------------------------------------------------------------------*/
