/******************************************************************************
*
*   Copyright (C) 2002 Analog Devices India (P) Ltd. All rights are reserved.
*
*   The information and source code contained herein is the exclusive
*   property of Analog Devices India (P) Ltd. and may not be disclosed,
*   examined or reproduced in whole or in part without explicit written
*   authorization from the compnay.
*
******************************************************************************/
#ifndef _VOICEAPI_H /* { */
#define _VOICEAPI_H

#include "voiceconf.h"
#include "voicelib.h"

/*
 * Enums
 * ~~~~~
 */

#if KERNEL_RTP_INTERFACE /* { */
/* Enum defines all DSP commands */
enum dsp_network_cmd_toDsp_enu {
	/** Clear Buffer. */
	DSP_NETWORK_Cmd_toDsp_clear_buffer,

	/** Active mode data. */
	DSP_NETWORK_Cmd_toDsp_mode_data_enable,

	/** Set mode data. */
	DSP_NETWORK_Cmd_toDsp_mode_data,

	/** Get timeStamp Dsp value. */
	DSP_NETWORK_Cmd_toDsp_get_timeStamp,

	/** Get Frames_per_packet Dsp value. */
	DSP_NETWORK_Cmd_toDsp_get_frames_per_packet,
};

/** Enum defines all DSP events. */
enum dsp_network_evt_fromDsp_enu {
	/** Voice sample is ready to process. */
	DSP_NETWORK_Evt_fromDsp_voice_ready,

	/** Init port done appear. */
	DSP_NETWORK_Evt_fromDsp_init_port_done,

	/** Reset all port is appear. */
	DSP_NETWORK_Evt_fromDsp_reset_all_port,

	/** caller Id play done is appear. */
	DSP_NETWORK_Evt_fromDsp_callerid_play_done,
};

/** Enum defines all Network events. */
enum dsp_network_evt_fromNetwork_enu {
	/** Digit received. */
	DSP_NETWORK_Evt_fromNetwork_digit_received,

	/** digit start. */
	DSP_NETWORK_Evt_fromNetwork_digit_start_report,

	/** digit stop. */
	DSP_NETWORK_Evt_fromNetwork_digit_stop_report,
};
#endif /* KERNEL_RTP_INTERFACE } */

#if DECT_MODULE /* { */
/** Enum defines all DSP commands. */
enum dsp_endpoint_cmd_enu {
	/** Start transcode. */
	DSP_ENDPOINT_Cmd_Start_transcode,

	/** Stop transcode. */
	DSP_ENDPOINT_Cmd_Stop_transcode,
	DSP_ENDPOINT_Cmd_Start_FXO,
	DSP_ENDPOINT_Cmd_Stop_FXO,
};

/* Enum defines all DSP events */
enum dsp_endpoint_evt_enu {
	/** None. */
	DSP_ENDPOINT_EVT_none,
};
#endif /* DECT_MODULE } */

//FCLUZEAU relay module
#if EXT_MODULE /* { */
enum  dsp_relay_cmd{
	RELAY_PSTN,
	RELAY_VOIP
};
#endif /* EXT_MODULE } */
/*
 * Typedefs
 * ~~~~~~~~
 */

#if KERNEL_RTP_INTERFACE /* { */
/** Voice struct. */
typedef struct voiceNWPkt_str					VoiceNWPkt_t;

/** Struct voiceNWPkt. */
typedef struct dsp_regNetwork_str				dsp_regNetwork_t;

/** Enum defines all DSP commands. */
typedef enum dsp_network_cmd_toDsp_enu			DSP_NETWORK_Cmd_toDsp_e;

/** Enum defines all DSP events. */
typedef enum  dsp_network_evt_fromDsp_enu		DSP_NETWORK_Evt_fromDsp_e;

/** Enum defines all Network events. */
typedef enum  dsp_network_evt_fromNetwork_enu	DSP_NETWORK_Evt_fromNetwork_e;

/** Write voice packet to DSP. */
typedef int (*dsp_network_writeVoice_f)(		VoiceNWPkt_t *voice,
										unsigned char *pPayload);

/** Read voice from DSP. */
typedef int (*dsp_network_readVoice_f)(			VoiceQ_t **voice,
										int channel);


//Mbe (07/2009)
/** Clock from DSP. */
typedef int (*dsp_network_clockFromDsp_f)(		int _channel);
/** Event from DSP. */
typedef int (*dsp_network_evtFromDsp_f)(		DSP_NETWORK_Evt_fromDsp_e evt,
										int _channel,
										void *param);

/** Event from Network. */
typedef int (*dsp_network_evtFromNetwork_f)(		DSP_NETWORK_Evt_fromNetwork_e evt,
										int _channel,
										void *param);

/** Command to DSP. */
typedef int (*dsp_network_cmdToDsp_f)(			DSP_NETWORK_Cmd_toDsp_e cmd,
										int channel,
										void *param);
#endif /* KERNEL_RTP_INTERFACE } */

#if DECT_MODULE /* { */
/** Enum defines all DSP commands. */
typedef enum dsp_endpoint_cmd_enu			DSP_ENDPOINT_Cmd_e;

/* Enum defines all DSP events */
typedef enum dsp_endpoint_evt_enu			DSP_ENDPOINT_Evt_e;

/* Voice to DECT Voice packet Write */
typedef int (*dsp_endPoint_writeVoice_f)(	void *ref,
									unsigned char *voiceBuf,
									int len);

/* DECT to voice, packet read */
typedef int (*dsp_endPoint_readVoice_f)(	void *ref,
									unsigned char *voiceBuf,
									int len);

/* Event from DSP */
typedef int (*dsp_endPoint_evtFromDsp_f)(	DSP_ENDPOINT_Evt_e evt,
									void *param);

/* Command to DSP */
typedef int (*dsp_endPoint_cmdToDsp_f)(		DSP_ENDPOINT_Cmd_e cmd,
									void *param);
#endif /* DECT_MODULE } */

#if EXT_MODULE /* { */
/** Callback for clock. */
typedef void (*dsp_extModForClock_callback_f)(	void *);
//FCLUZEAU
/** Callback for relay . */
typedef void (*dsp_extModForRelay_callback_f)(	enum dsp_relay_cmd );
#endif /* EXT_MODULE } */

/*
 * Structs
 * ~~~~~~~
 */

#if KERNEL_RTP_INTERFACE /* { */
/** Struct voiceNWPkt.
 *
 * This struct manage Voice informations.
 */
struct voiceNWPkt_str {
  /* Port Number   */
  unsigned char  channel;

  /* Codec Type    */
  unsigned short CodecType;

  /* Sequence Number */
  unsigned short SeqNum;

  /* Packet length */
  unsigned short FrameLen;

	/** Time Stamp.
	 *
	 * /note  -1 value signify used DSP Kernel timestamp.
	 */
  unsigned int   timeStamp;
};

typedef enum
{
	DSP_DECT_MODE_FREE,
	DSP_DECT_MODE_VOIP_WITH_CONV,
	DSP_DECT_MODE_VOIP_WITHOUT_CONV,
	DSP_DECT_MODE_FX0,
}eDsp_endPoint_dectMode;
/** regNetwork_str.
 *
 * This  Structure defines the Network Call Backs for data control
 */
struct dsp_regNetwork_str {
  /** Write voice packet to DSP. */
  dsp_network_writeVoice_f					writeVoice;

  /** Read voice from DSP. */
  dsp_network_readVoice_f					readVoice;

  //Mbe (07/2009)
  /** Clock from DSP. */
  dsp_network_clockFromDsp_f					clockFromDsp;
  /** Event from DSP. */
  dsp_network_evtFromDsp_f					evtFromDsp;

  /** Event from Network. */
  dsp_network_evtFromNetwork_f				evtFromNetwork;

  /** Command to DSP. */
  dsp_network_cmdToDsp_f						cmdToDsp;
};
#endif /* KERNEL_RTP_INTERFACE } */

#if DECT_MODULE /* { */
/** dsp_regEndPoint_str.
 *
 * Structure defines the call backs for DECT.
 */
typedef struct
{
  /* DECT reference, voice does not use it */
  void *ref;

  /* DSP Port Number. */
  int  port;

  /* Packetization period */
  int  maxFrames;

  int  dectToneDtmf_Active;
  eDsp_endPoint_dectMode dectMode;

  /* Conversion read and write call backs */
	struct {
    /* Voice to DECT Voice packet Write */
    dsp_endPoint_writeVoice_f		writeVoice;

    /* DECT to voice, packet read */
    dsp_endPoint_readVoice_f		readVoice;
  }withConv;

  /* Without conversion read and write call backs. */
	struct {
    /* Voice to DECT Voice packet Write */
    dsp_endPoint_writeVoice_f		writeVoice;

    /* DECT to voice, packet read */
    dsp_endPoint_readVoice_f		readVoice;
  }withoutConv;

  /* Event from DSP */
  dsp_endPoint_evtFromDsp_f		evtFromDsp;

  /* Command to DSP */
  dsp_endPoint_cmdToDsp_f		cmdToDsp;
}dsp_regEndPoint_str;

#if DECT_DEBUG /* { */
/** dectDebugInfo_t.
 *
 * This struct manage Dect Debug.
 */
typedef struct
{
	/** WithConvWrite debug. */
	int									withConvWrite;

	/** WithConvRead debug. */
	int									withConvRead;

	/** WithoutConvWrite debug. */
	int									withoutConvWrite;

	/** WithuotConvRead debug. */
	int									withoutConvRead;

	/** Dect taskCnt debug. */
	int									dectTaskCnt;

	/** dspTranscodeRead debug. */
	int									dspTranscodeRead;

	/** dspTranscodeStart debug. */
	int									dspTranscodeWrite;
}dectDebugInfo_t;
#endif /* DECT_DEBUG } */
#endif /* DECT_MODULE } */

#if EXT_MODULE /* { */
/** dsp_regExtModForClock_str.
 *
 * This struct manage parameters for external module which want clock Dsp base.
 */
typedef struct
{
  /* Reference */
  void 						*ref;

  /* Dsp Number */
  int 						dspNumber;

  /* Callback */
  dsp_extModForClock_callback_f	callback;
}dsp_regExtModForClock_str;
typedef struct
{
  /* Callback */
  dsp_extModForRelay_callback_f	cb;
}dsp_regExtModForRelay_str;
#endif /* EXT_MODULE } */

/*
 * Functions
 * ~~~~~~~~~
 */

#if KERNEL_RTP_INTERFACE /* { */
/** Allow Network to register on DSP. */
void dsp_registerNetwork(dsp_regNetwork_t *_pRegNetwork);

/** Allow Network to unregister on DSP. */
void dsp_unregisterNetwork(void);
#endif /* KERNEL_RTP_INTERFACE } */

#if DECT_MODULE /* { */
#if DECT_DEBUG /* { */
/** Debug informations. */
dectDebugInfo_t* dectGetDebugStats(void);
#endif /* DECT_DEBUG } */

/** Allow to DECT to register on DSP. */
void dectRegisterCallBacks(dsp_regEndPoint_str *callbacks);

/** Allow to DECT to unregister on DSP. */
void dectUnRegisterCallBacks(void);
#endif /* DECT_MODULE } */

#if EXT_MODULE /* { */
/** Allow to Extern module to register to Dsp fro clock. */
void dsp_regExtModForClock(dsp_regExtModForClock_str *callbacks);

/** Allow to Extern module to unregister to Dsp fro clock. */
void dsp_unregExtModForClock(void);

//FCLUZEAU
/** Allow to Extern module to command relay. */
void dsp_regExtModForRelay(dsp_regExtModForRelay_str *callbacks);
void dsp_unregExtModForRelay(void);
#endif /* EXT_MODULE } */

/*
 * Inlines
 * ~~~~~~~~
 */

#if DECT_MODULE /* { */
/* Stop Dect */
static inline void dsp_dectStop(	dsp_regEndPoint_str 		*_ctx)
{
	/* WithConv */
	{
		_ctx->withConv.writeVoice		= NULL;
		_ctx->withConv.readVoice			= NULL;
	}

	/* WithoutConv */
	{
		_ctx->withoutConv.writeVoice		= NULL;
		_ctx->withoutConv.readVoice		= NULL;
	}
}

/* Start Dect With Convertion */
static inline void dsp_dectStartWithConv(	dsp_regEndPoint_str			*_ctx,
    									dsp_endPoint_readVoice_f		_readVoice,
    									dsp_endPoint_writeVoice_f	_writeVoice)
{
	/* WithConv */
	{
		_ctx->withConv.writeVoice		= _writeVoice;
		_ctx->withConv.readVoice			= _readVoice;
	}

	/* WithoutConv */
	{
		_ctx->withoutConv.writeVoice		= NULL;
		_ctx->withoutConv.readVoice		= NULL;
	}
}

/* Start Dect Without Convertion */
static inline void dsp_dectStartWithoutConv(	dsp_regEndPoint_str			*_ctx,
    									dsp_endPoint_readVoice_f		_readVoice,
    									dsp_endPoint_writeVoice_f	_writeVoice)
{
	/* WithConv */
	{
		_ctx->withConv.writeVoice		= NULL;
		_ctx->withConv.readVoice			= NULL;
	}

	/* WithoutConv */
	{
		_ctx->withoutConv.writeVoice		= _writeVoice;
		_ctx->withoutConv.readVoice		= _readVoice;
	}
}

/* Open Dect */
static inline void dsp_dectOpen(	dsp_regEndPoint_str 		*_ctx,
							void						*_ref)
{
	/* Set Reference */
	_ctx->ref							= _ref;

	/* Stop dect */
	dsp_dectStop(_ctx);
}

/* Close Dect */
static inline void dsp_dectClose(	dsp_regEndPoint_str 		*_ctx)
{
	/* Set Reference */
	_ctx->ref							= (void *)0;

	/* Stop dect */
	dsp_dectStop(_ctx);
}

#endif /* DECT_MODULE } */

#endif /* _VOICEAPI_ } */
