/*
 * ============================================================================
 *
 * Copyright : (c) 2005 SAGEM SA - Site Velizy - URD2
 *
 * The information and source code contained herein is the exclusive
 * property of SAGEM and may not be disclosed, examined, or
 * reproduced in whole or in part without explicit written authorization
 * of the company.
 *
 * ============================================================================
 */

/**
 * \file voiceSysCtl.h Voice /proc/sys interface
 *
 * This file contain all voice /proc/sys interface
 */

#ifndef _VOICESYSCTL_H /* { */
#define _VOICESYSCTL_H

#include <linux/sysctl.h>
#include <asm/uaccess.h>

#include "voiceconf.h"
#include "voicelib.h"

#ifdef VOICE_SYSCTL_STATS
/*
 * Enums
 * ~~~~~
 */

/** \name Rtp_sysctlSagem Enumerations.
 */
/*@{*/
/** Voice Sysctl Sagem. */
enum dsp_voice_sysctlSagem_enu {
	VOICE_SYSCTL_Sagem = 0x27062007
};

/** Voice Sysctl Sagem_list. */
enum dsp_voice_sysctlSagem_voice_enu {
	VOICE_SYSCTL_Sagem_voice = 1
};

/** Voice Sysctl Sagem_list. */
enum dsp_voice_sysctlSagem_voice_list_enu {
	VOICE_SYSCTL_Sagem_voice_port_0 = 1,
	VOICE_SYSCTL_Sagem_voice_port_1,
	VOICE_SYSCTL_Sagem_voice_data_mode,
	VOICE_SYSCTL_Sagem_voice_dev_nb_evts
}
;
/** Voice Sysctl Sagem_list. */
enum dsp_voice_sysctlSagem_voice_port_enu {
	VOICE_SYSCTL_Sagem_voice_port_stats = 1,
	VOICE_SYSCTL_Sagem_voice_port_params,
	VOICE_SYSCTL_Sagem_voice_port_ajb
};

/** Voice Sysctl Sagem_port. */
enum dsp_voice_sysctlSagem_voice_port_stats_enu {
	VOICE_SYSCTL_Sagem_voice_port_stats_endPoint = 1,
	VOICE_SYSCTL_Sagem_voice_port_stats_network,
};

/** Voice Sysctl Sagem_port. */
enum dsp_voice_sysctlSagem_voice_port_params_enu {
	VOICE_SYSCTL_Sagem_voice_port_params_data_mode = 1,
	VOICE_SYSCTL_Sagem_voice_port_params_init_port,
	VOICE_SYSCTL_Sagem_voice_port_params_slic_state,
	VOICE_SYSCTL_Sagem_voice_port_params_ring_state,
	VOICE_SYSCTL_Sagem_voice_port_params_voice_ready
};
/*@}*/
 
/*
 * Structs
 * ~~~~~~~
 */
 
/** Struct dsp_statsEndPoint.
 *
 * This struct manage EndPoint statistics informations.
 */
struct dsp_statsEndPoint_str {
	/** External Part. */
	struct {
		/** Rcv. */
		struct {
			/** Bytes. */
			__u32						bytes;
	
			/** Pkts. */
			__u32						pkts;
		}rcv;
	
		/** Snd. */
		struct {
			/** Bytes. */
			__u32						bytes;
	
			/** Pkts. */
			__u32						pkts;
		}snd;
	}external;

	/** Pcm part. */
	struct {
	}pcm;
};

/** Struct dsp_statsNetwork.
 *
 * This struct manage Network statistics informations.
 */
struct dsp_statsNetwork_str {
	/** Eternal part stats. */
	struct {
		/** Rcv. */
		struct {
			/** Bytes. */
			__u32					bytes;
	
			/** Pkts. */
			__u32					pkts;
		}rcv;

		/** Snd. */
		struct {
			/** Bytes. */
			__u32					bytes;
	
			/** Pkts. */
			__u32					pkts;
		}snd;
	}external;

	/** Dsp part stats. */
	struct {
		/** RcvSpeech. */
		struct {
			/** Bytes. */
			__u32					bytes;
	
			/** Pkts. */
			__u32					pkts;
		}rcvSpeech;

		/** RcvVad. */
		struct {
			/** Bytes. */
			__u32					bytes;
	
			/** Pkts. */
			__u32					pkts;
		}rcvVad;

		/** SndTone. */
		struct {
			/** Bytes. */
			__u32					bytes;
	
			/** Pkts. */
			__u32					pkts;
		}sndTone;

		/** SndSpeech. */
		struct {
			/** Bytes. */
			__u32					bytes;
	
			/** Pkts. */
			__u32					pkts;
		}sndSpeech;
	}dsp;

	/** Rtp part stats. */
	struct {
		/** Rcv. */
		struct {
			/** Bytes. */
			__u32					bytes;
	
			/** Pkts. */
			__u32					pkts;
	
			/** Dtmf. */
			__u32					dtmfs;
	
			/** Mode data. */
			struct {
				/** Mode Inactive. */
				__u32				inactive;
	
				/** Mode reception only. */
				__u32				recv_only;
	
				/** Mode transmission only. */
				__u32				send_only;
	
				/** Mode bidirectionnel. */
				__u32				send_recv;
			}modeData;
		}rcv;
	
		/** Snd. */
		struct {
			/** Bytes. */
			__u32					bytes;
	
			/** Pkts. */
			__u32					pkts;
	
			/** InitPortDone. */
			__u32					initPortDone;
	
			/** CallerIdDone. */
			__u32					callerIdDone;
	
			/** VoiceReady. */
			__u32					voiceReady;
		}snd;

		/** Error. */
		struct {
			/** SndVoiceNull. */
			__u32					sndVoiceNull;
		}error;
	}rtp;
};

/** Struct voiceStats.
 *
 * This struct manage Voice statistics informations.
 */
struct dsp_voiceSysCtl_str {
	/** Sysctl header. */
	struct ctl_table_header				*head;

	/** Sagem Sysctl. */
	struct ctl_table					sagem[2];

	/** Sagem_voice Sysctl. */
	struct ctl_table					sagem_voice[2];

	/** Sagem_list Sysctl. */
	struct ctl_table					sagem_voice_list[MAX_VOICE_CHANNELS + 2];

	/** Struct. */
	struct {
		/** Sysctl. */
		struct {
			/** Sagem_port Sysctl. */
			struct ctl_table			sagem_voice_port[4];

			/** Sagem_port_stats  Sysctl. */
			struct ctl_table			sagem_voice_port_stats[3];

			/** Sagem_port_state  Sysctl. */
			struct ctl_table			sagem_voice_port_params[6];

			/** Sagem_port_stats_endpoint  Sysctl. */
			struct ctl_table			sagem_voice_port_stats_endpoint[2];

			/** Sagem_port_stats_network  Sysctl. */
			struct ctl_table			sagem_voice_port_stats_network[2];
		}sysctl;
	
		/** Stats. */
		struct {
			/** Network part stats. */
			struct dsp_statsNetwork_str	network;
	
			/** EndPoint part stats. */
			struct dsp_statsEndPoint_str	endPoint;
		}stats;
	}ports[MAX_VOICE_CHANNELS];

	/** Stats. */
	struct {
		/** Network. */
		struct {
			/** RcvNetworkBadChannel. */
			__u32					rcvBadChannel;

			/** RcvModeDataEnable. */
			__u32					rcvModeDataEnable;

			/** SndResetAllPorts. */
			__u32					sndResetAllPorts;
		}network;
	}stats;
};
#endif /* _VOICESYSCTL_ } */

#endif /* _VOICESYSCTL_ } */

// vim:ts=5:
