/* =============================================================================
 *
 * Copyright (C) 2001 Analog Devices Inc. All rights reserved
 *
 * The information and source code contained herein is the exclusive property
 * of Analog Devices and may not be disclosed, examined or reproduced in whole
 * or in part without the explicit written authorization from Analog Devices.
 *
 * ===========================================================================*/

#ifndef _VOICE_BITMAP_H
#define _VOICE_BITMAP_H

# define ELE_ALLOCATED  1
# define ELE_FREE       0

#define BitmapSize(size) ((size % 8 == 0) ? (size/8) : (size/8 + 1)) 

extern void fatalError(CHAR *, ...); /* ksreeni */

/*
Parameters :
		inpBitArray : Pointer to the bitmap array declared using BitmapSize()
		inLen		: Length of the array
		outloc		: Output parameter which returns the array index
*/
static __inline INT16 GetFreeElement(UCHAR *inpBitArray, UINT32 inLen, UINT32 *outLoc)
{
	UINT32 ArrCount,BitCount;
	UINT32 Mask;
	*outLoc = 0;
	for(ArrCount = 0; ArrCount < BitmapSize(inLen) ; ArrCount++)
	{
		Mask = 0x80;
		for(BitCount =0; BitCount <8 ; BitCount++)
		{
			if((Mask & inpBitArray[ArrCount]) == 0)
			{
				if(((ArrCount * 8) + BitCount) >= inLen)
					return(FAILURE);
				else
				{
					*outLoc = (ArrCount * 8) + BitCount;
					inpBitArray[ArrCount] = inpBitArray[ArrCount] | Mask;
					return(SUCCESS);
				}
			}
			Mask = Mask >> 1;
		}
	}
	return(FAILURE);
}

/*
Parameters :
		inpBitArray : Pointer to the bitmap array declared using BitmapSize()
		inLen		: Length of the array
		inLoc		: array index which has to be released
*/

static __inline INT16 ReleaseElement(UCHAR *inpBitArray, UINT32 inLen, UINT32 inLoc)
{
	INT32 ArrCount,BitCount;
	UINT32 Mask = 0x80;
	if(inLoc > inLen) 
			return(FAILURE);
	ArrCount = inLoc/8;
	BitCount = inLoc%8;
	Mask = Mask >> BitCount;
	if((inpBitArray[ArrCount] & Mask) == 0)
		return(FAILURE);
	else
	{
		inpBitArray[ArrCount] = (inpBitArray[ArrCount] & ~(Mask));
		return(SUCCESS);
	}
}
/*
Parameters :
		inpBitArray : Pointer to the bitmap array declared using BitmapSize()
		inLen		: Length of the array
		inLoc		: array index of the element to be checked
*/

static __inline INT16 CheckElement(UCHAR *inpBitArray, UINT32 inLen, UINT32 inLoc)
{
	INT32 ArrCount,BitCount;
	UINT32 Mask = 0x80;
	if(inLoc > inLen) 
			return(FAILURE);
	ArrCount = inLoc/8;
	BitCount = inLoc%8;
	Mask = Mask >> BitCount;
	if((inpBitArray[ArrCount] & Mask) == 0)
		return(ELE_FREE);
	else
		return(ELE_ALLOCATED);
}


static __inline INT16	mFree(INT32 Index,UCHAR *bitArr,UINT32 inLen)
{
	

    if( ReleaseElement(bitArr,inLen,Index) == SUCCESS )	
	return SUCCESS;
    else
	return FAILURE;

}
#endif
