/**********************************************************************

  This file contains the BUILD configurations for the voice system.
   
 *********************************************************************/

/* TARGET Type. Select one at a time */
#define VOX200                          1
#define VOX150                          0
#define VOX160                          0

/* Board Model. Select one at a time */
#define HIMALAYA                        0
#define LIVEBOX                         1

/* SLIC Modules, disable it only when you are not interested in using SLIC modules at all.
   It is mainly provided if you want to use your own SLIC code. */
#define SLIC_MODULES 			1

/* Default Conutry Name, you can change it at run time also using CLI. 
   At present Supported options are : FRANCE / USA , by default USA => 600 Ohms 
*/
#define COUNTRY_NAME 			FRANCE

#define FXS_ToneDtmf_ACTIVE 		1

/*=====================================================================
    Enable / Disable DSP features 

 =====================================================================*/

/* Host based DTNF Modules */
#define DTMFRX				1

/* FAX T.38 Modules  */
#define T38				0

/* Caller ID detection for FXS */
#define CALLER_IDTx			1

/* G711 PLC Module	*/
#define G711_PLC			1

/* Host Based Tone Generation */
#define TONE_GEN			1

/* Dynamic Codec Download Support */
#define DYNAMIC_CODEC_DOWNLOAD		1

/* 3-way Conference Support. */
#define THREEWAY_CONFERENCE		0

/* FXO Module */
#define FXO_MODULE 			1

/* FXS CallerID Detection */
#define CID_RX_DET 			1


/*==============================================-==
    SPORT Configurations.
  ================================================*/
/* Number of DSPs */
#define MAX_DSP_NUM			2

/* Delay Optimization 	*/
#define DELAY_OPT 			1

/* Default SPORT Type, It can be also configured at run time 
   using CLI  */
#define SPORT_CODEC 			LINEAR

/* DSP Time Slots, for codec side following Time slots
   should be configured.
	FXS-1	=> 0x4
	FXS-2	=> 0x8
	FXO	=> 0x100
*/
#define DSP0_TIME_SLOT 			0x104	
#define DSP1_TIME_SLOT 			0x28
/************************************************************
  DSP Clock Coonfiguration. It depends upon three
  factors.
	-> PLL Setting
	-> Crytsal Frequenecy
	-> Multiplication Factor.

  DSP clock =>
    PLL Setting * Multiplication Factor * Crytsal Frequenecy
************************************************************/

/***************************************
  PLL Setting => 1
  Crytsal Frequenecy -> 32.768
  Multiplication Factor -> 2
***************************************/
#define DSP_VX200_CLOCK		  	77.824


/***************************************
  PLL Setting => 4
  Crytsal Frequenecy -> 32.768
  Multiplication Factor -> 1/2
***************************************/
#define DSP_VX150_CLOCK                       77.824
   	
/***************************************
  PLL Setting => (64/12)
  Crytsal Frequenecy -> 35.328
  Multiplication Factor -> 1/2
***************************************/
#define DSP_VX160_CLOCK                      	94.208 

/*==============================================================
	   OTHER CONFIGURATIONS.
 ===============================================================*/
/* Enable / Disable Debug messages. */
#define DEBUG_ENABLED			1

/* Number of ISR per DSP.  */
#define MAX_CHANNELS_ISR		1

/* Number of Countries Supported. */
//USA, FRANCE, NETHERLANDS, POLAND, SPAIN, BELGIUM
#define NUM_COUNTRY			6

/* Maximum number of voice Ports. In case of 3-way, total number
   of ports becomes double . */

/* Physical SLIC Channels */
#define MAX_SLIC_CHANNELS               2

#if THREEWAY_CONFERENCE
#define MAX_VOICE_CHANNELS		4
#else
#define MAX_VOICE_CHANNELS		MAX_SLIC_CHANNELS
#endif

/* Leave is as 1 ONLY. */
#define VOX_VOICE 			1

/* Enable / Disable Network driver control. 
   This feature is mainly available for our Linux router code and 
   by enable it, we are ensuring that Networking Drivers do not 
   block voice system in case of heavy data traffic.
*/
#define VOX_DRIVERS_CONTROL 		0

/* DSP Firmware Names. */
/* Default G-711 Image . */
#define DSP_G711_IMAGE_NAME 		"/dsp/dsp218x_1ch_g711.dsp"

/* G-729 Image */
#define DSP_G729_IMAGE_NAME 		"/dsp/dsp218x_1ch_g729only.dsp"

/* G-723 Image */
#define DSP_G723_IMAGE_NAME 		"/dsp/dsp218x_1ch_g723only.dsp"

/* FAX Only Image. */
#define DSP_FAX_ONLY_IMAGE_NAME 	"/dsp/dsp218x_1ch_faxonly.dsp"

/* DSP Image for 3-way Conferencing */
#define DSP_3WAY_IMAGE_NAME		"/dsp/dsp218x_1ch_3wayonly.dsp"

/* VAD2 DSP Image Name */
#define DSP_G711VAD2_IMAGE_NAME		"/dsp/dsp218x_1ch_g711vad2only.dsp"

/* DSP COnfiguraion File */
#define DSP_CONFIGURATION_FILE		 "/etc/voice.conf"

/* Linux 2.4/2.6 */
#define LINUX_2_6			1

/* This is Release Message, which will be flashed on target 
   during boot */
#define RELEASE_INFO "Software Build(voice_2_6 : Thu Dec  8 10:33:40 PST 2005)"


/* AJB Related Configurations */
/* Configuration of AJB Parameters using CLI rather then taking default values.
   This feature should not be enabled on Linux for time being. */
#define AJB_USE_CLI_CONFIGURATIONS      NO 
/* Enable/Disable AJB Statistics */
#define AJB_ENABLE_STATISTICS           1

#define DRV_DEBUG_STAT				1

#define TARGET_ALASKA				0

#define KERNEL_RTP_INTERFACE			1

#define KRTP						0

#define DECT_MODULE					1

#define DECT_TESTING				0

#define DECT_DEBUG					0

#define EXT_MODULE					1

