/* ============================================================================
 *
 * Copyright (C) 2001 Analog Devices Inc. All rights reserved
 *
 * The information and source code contained herein is the exclusive property
 * of Analog Devices and may not be disclosed, examined or reproduced in whole
 * or in part without the explicit written authorization from Analog Devices.
 *
 * ============================================================================
 */

#ifndef __VOICE_SPI_H
#define __VOICE_SPI_H

#define CODEC_CS0_GPIO                  1 
#define CODEC_CS1_GPIO                  2
#define CODEC_CS2_GPIO                  2  /* On all the boards, CS2 is connected to FXO */

/* Set this to the divisor for the BAUD rate calculation */
#define SPI_BAUD 5

/* Set this accordingly:
    0 for start transfer when the receive buffer is read from
    1 for start transfer when the transmit buffer is written to
*/
#define SPI_INIT_XFER 1
                                                                                
/* Set to 1 to send zeros when the TDBR is empty, or 0 to
   resend the last word */
#define SPI_SEND_ZEROS 1
                                                                                
/* Set to 1 to overwrite previously received data if the
   RDBR is full, or 0 to discard the incoming data */
#define SPI_OVERWRITE 0
                                                                                
/* Set to enable PIO_nSPISSIN pin. This is the Slave-Select input
   for Master. Disabling it frees up another GPIO pin on the SPI */
#define SPI_EN_SLAVE_SEL 0
                                                                                
/* Enable MISO pin as an output. Use for broadcasting to multiple slave
   devices */
#define SPI_EN_MISO_OUT 1
 
/* 1 == 16 bits, 0 == 8 bits */
#define SPI_WORD_LENGTH 0
                                                                                
/* 1 = Least Significant Bit First, 0 = Most Significant Bit First */
#define SPI_LSBF 0
                                                                                
/* 1 = SPICLK Starts toggling at the beginning of a data transfer,
   0 = SPICLK starts toggling at the middle of a data transfer */
#define SPI_CLOCK_PHASE 1
                                                                                
/* 0 = Active High SPICLK, 1 = Active Low SPICLK */
#define SPI_CLOCK_POLAR 1
                                                                                
/* Set to 1 to make this SPI the master device */
#define SPI_IS_MASTER 1
                                                                                
/* Set to 1 to make MISO and MOSI data output Open Drain */
#define SPI_OPEN_DRAIN 0
                                                                                
/* Function Prototypes */
void spiEnable(void);
void spiDisable(void);
void spiSetMode(int baud);
void spiInit(int baud);
int spiSendByte(unsigned char data);
void spiSendData(unsigned char *data,int len);
int spiRecvByte(unsigned char *data);
void spiRecvData(unsigned char *data,int len);
void spiControlChipSelect(unsigned char bEnable,int codec);
void spiInitOperation(unsigned char data,unsigned char *recvData);
void ASSERT_CHIPSELECT(int codec);
void DEASSERT_CHIPSELECT(int codec);








#endif
