#include <voice_typedef.h>
#include <voicelib.h>

#if KRTP

#include <linux/netfilter.h>
#include <voice_bitmap.h>
#include <dspipc.h>
#include <linux/inetdevice.h>
#include "rtpgdef.h"
#include <netpro/apflow.h>
#include <netpro/apload.h>


/* Total Number of RTP active session */
UCHAR 		gucTotalActiveSess;
UCHAR 		gaucActiveRTPSess[MAX_RTP_SESSIONS];

/* RTP Info Memory Management */
UCHAR     	gaRTPBitMap[BitmapSize(MAX_RTP_SESSIONS)];
RTPInfo_t  	gaRTPInfo[MAX_RTP_SESSIONS];

/* RTP Source Table . */
SrcInfoTable_t  gaSrcInfoTable[MAX_SOURCES];
UCHAR           aucSITBitMask[BitmapSize(MAX_SOURCES)];


extern struct nf_hook_ops rtpNFHook;
extern UINT16 apCalculateHash(UCHAR apId, apFlowEntry_t *ptr2UserFlowEntry);
extern simResult_t  apAddFlowEntry( unsigned char  apId,
                             unsigned short hashValue,
                             apFlowEntry_t  *ptr2UserFlowEntry,
                             apFlowEntry_t  **ptr2AddedFlowEntry);
extern simResult_t  apDeleteFlowEntry( unsigned char  apId,
                                unsigned short hashValue,
                                apFlowEntry_t  *ptr2UserFlowEntry,
                                UINT32         *ptr2AfterHeadFlowEntry);

#if KRTCP_ENABLED
static struct timer_list rtcpTimer[MAX_RTP_SESSIONS];
#endif

static unsigned long rand(void) 
{ 
  static unsigned long int xRandom = 0x126745;
  xRandom += 2;
  if(xRandom == 1)
    xRandom = 0x126745;
  return xRandom;
}

/****************************************************************
 *  Function Name : rtpGenSeqNum.                               *
 *  Description   : API Function to generate sequence number.   *
 *  Input         : None.                                       *
 *  Output        : Generate Sequence Number.                   *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpGenSeqNum(UINT16 *uiSeqNum)
{
  *uiSeqNum = (UINT16)rand();
  return(SUCCESS);
}

/****************************************************************
 *  Function Name : rtpGenTimeStamp.                            *
 *  Description   : API Function to generate Time Stamp.        *
 *  Input         : None.                                       *
 *  Output        : Generate Time Stamp.                        *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpGenTimeStamp(UINT32 *ulTimestamp)
{
  *ulTimestamp=rand();
  return(SUCCESS);
}
/****************************************************************
 *  Function Name : rtpGenSSRC.                                 *
 *  Description   : API Function to generate SSRC.              *
 *  Input         : None.                                       *
 *  Output        : Generate SSRC.                              *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpGenSSRC(UINT32 *ulSSRC)
{
  *ulSSRC = rand();
  return(SUCCESS);
}
/****************************************************************
 *  Function Name : rtpDeactivateRtpSess.                       *
 *  Description   : API Function to deactivate a RTP session.   *
 *  Input         : RTP Session ID.                             *
 *  Output        : None.                                       *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT32 rtpDeactivateRtpSess(INT32 iSessId)
{
  UCHAR ucIndex = 0;
  UCHAR ucCnt = 0;
  for(ucCnt=0; ucCnt<gucTotalActiveSess; ucCnt++)
  {
    if(gaucActiveRTPSess[ucCnt] != iSessId)
    {
      gaucActiveRTPSess[ucIndex] = gaucActiveRTPSess[ucCnt];
      ucIndex++;
    }
  }
  gucTotalActiveSess--;
  return SUCCESS;
}
/****************************************************************
 *  Function Name : rtpReleaseResources.                        *
 *  Description   : API Function to release RTP resources.      *
 *  Input         : RTP Session ID.                             *
 *  Output        : None.                                       *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT32 rtpReleaseResources(INT32 iSessId)
{
  INT32 iCount;
  /* Deactivate RTP Session */
  rtpDeactivateRtpSess(iSessId);
  /* Release Element for this session */
  if(ReleaseElement(gaRTPBitMap, MAX_RTP_SESSIONS,iSessId) == FAILURE)
  {
    printk("Can not Free RTP Session");
    return FAILURE;
  }
  for(iCount=0; iCount< MAX_SOURCES; iCount++)
  {
    if((CheckElement(aucSITBitMask, MAX_SOURCES, iCount) == ELE_ALLOCATED)
       && (gaSrcInfoTable[iCount].iSessionIndex ==  iSessId))
    {
      if(ReleaseElement(aucSITBitMask, MAX_SOURCES, iCount) == FAILURE)
      {
        printk("Can not Free RTP SSRC");
        return FAILURE;
      }
      memset(&gaSrcInfoTable[iCount],0,sizeof(gaSrcInfoTable[0]));
    }
  }
  return SUCCESS;
}
/****************************************************************
 *  Function Name : rtpDeleteSession.                           *
 *  Description   : API Function to delete a RTP session.       *
 *  Input         : RTP Session ID.                             *
 *  Output        : None.                                       *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpDeleteSession(UINT16 uiSessId)
{
  RTPInfo_t *pRtpInfo = &gaRTPInfo[uiSessId];
#if KRTCP_ENABLED
  UINT32 ulPktSize;
#endif
  rtpCreateAPFlow(pRtpInfo->ulDestIPAddr,
                  pRtpInfo->uiDestRTPPort,
                  pRtpInfo->ulSrcIPAddr,
                  pRtpInfo->uiRTPPort,0);

#if KRTCP_ENABLED
  if(pRtpInfo->bTimer == 1)
  {
    pRtpInfo->bEndSession = TRUE;
    if(pRtpInfo->lRTCPTimerId != -1)
    {
      if(timerStop(pRtpInfo) == FAILURE)
      {
        DEBUG(PRINT("rtpDeleteSession: Can not stop RTCP Timer"), DEBUG_EXCEPTION);
      }
    }
    else
      pRtpInfo->lRTCPTimerId = -1;
    if(rtcpSendData(pRtpInfo, &ulPktSize) != SUCCESS)
    {
       DEBUG(PRINT("rtcpHandleIntervalTimer: rtcpSendData() error\n"), DEBUG_EXCEPTION);
    }
    pRtpInfo->bEndSession = FALSE;
  }
  /* Close RTCP Socket */
  if(rtpSocketClose(pRtpInfo->rtcp_sock) == FAILURE)
    DEBUG(PRINT("RTCP SocketClose Failure\n"), DEBUG_EXCEPTION);
  pRtpInfo->rtcp_sock = NULL;
#endif
  /* Close RTP Sockets */
  if(rtpSocketClose(pRtpInfo->rtp_sock) == FAILURE)
    DEBUG(PRINT("RTP SocketClose Failure\n"),DEBUG_EXCEPTION);
  pRtpInfo->rtp_sock = NULL;
  /* Release other resources for this RTP Session */
  rtpReleaseResources(uiSessId);
  
  /* If there is no active session, remove the Netfilter Hook */
  if(gucTotalActiveSess == 0)
    nf_unregister_hook(&rtpNFHook);
  return SUCCESS;
}
/****************************************************************
 *  Function Name : rtpCreateSocket.                            *
 *  Description   : API Function to create a RTP sockets.       *
 *  Input         : Session ID.                                 *
 *  Output        : None.                                       *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpCreateSocket(INT16 iSessId)
{
  /* Check if the RTP and RTCP ports are valid */
  if((gaRTPInfo[iSessId].uiRTCPPort > gaRTPInfo[iSessId].uiRTPPort)
     && ((gaRTPInfo[iSessId].uiRTPPort % 2) ==0 ) 
     && ((gaRTPInfo[iSessId].uiRTCPPort % 2) == 1))
  {
#if KRTCP_ENABLED
    if(rtpSocketOpen(&gaRTPInfo[iSessId].rtcp_sock,
            gaRTPInfo[iSessId].ulSrcIPAddr,
            gaRTPInfo[iSessId].uiRTCPPort) == FAILURE)
    {
      printk("Can not create RTCP Socket \n");
      return FAILURE;
    }
#endif
    gaRTPInfo[iSessId].rtp_sock = NULL;
    if(rtpSocketOpen(&gaRTPInfo[iSessId].rtp_sock, 
        gaRTPInfo[iSessId].ulSrcIPAddr,
                gaRTPInfo[iSessId].uiRTPPort) == FAILURE)
    {
#if KRTCP_ENABLED
      rtpSocketClose(gaRTPInfo[iSessId].rtcp_sock);
#endif
      printk("Can not create RTP Socket \n");
      return FAILURE;
    } 
    return SUCCESS;
  }
  return FAILURE;
}

/****************************************************************
 *  Function Name : rtpCreateSession.                           *
 *  Description   : API Function to create a RTP session.       *
 *  Input         : None.                                       *
 *  Output        : RTP Session.                                *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpCreateSession(SessInfo_t *SessInfo)
{
  INT32 iSessId;

  /* Allocate free element for this new session */
  if(GetFreeElement(gaRTPBitMap,MAX_RTP_SESSIONS,&iSessId)== FAILURE)
  {
    printk("Can not get FREE RTP Sessions");
    return(FAILURE);
  }
  if(gucTotalActiveSess >= MAX_RTP_SESSIONS)
  {
    printk("gucTotalActiveSess[%d] exceeds %d max sessions \n",
               gucTotalActiveSess,MAX_RTP_SESSIONS);
    return FAILURE;
  }

  /* Start Getting Data from Other End, if required. */
  if(gucTotalActiveSess == 0)
    nf_register_hook(&rtpNFHook);
  /* FIll new session */
  gaucActiveRTPSess[gucTotalActiveSess] = iSessId;
  gucTotalActiveSess++;

  memset(&gaRTPInfo[iSessId],0,sizeof(RTPInfo_t));
#if SNMP_RTP
  gaRTPInfo[iSessId].ulSessStart =  rtpGetCurrTime();
#endif

  /* Generate a random sequence number */
  rtpGenSeqNum(&gaRTPInfo[iSessId].uiSeqNum );
  rtpGenSSRC(&gaRTPInfo[iSessId].ulSSRC);
  rtpGenTimeStamp(&gaRTPInfo[iSessId].ulTimestamp);

  /* update the RTP table */
  gaRTPInfo[iSessId].iSessionIndex=iSessId;
  gaRTPInfo[iSessId].uiRTPPort=SessInfo->uiRTPPort;
  gaRTPInfo[iSessId].uiRTCPPort=SessInfo->uiRTCPPort;
  gaRTPInfo[iSessId].ulSrcIPAddr = SessInfo->ulSrcIPAddr;
  gaRTPInfo[iSessId].iSessionBW=SessInfo->iSessionBW;
  gaRTPInfo[iSessId].uiPayloadType=SessInfo->uiPayloadType;
  gaRTPInfo[iSessId].uiDynPayloadType=SessInfo->uiDynPayloadType;
  gaRTPInfo[iSessId].bEndSession=FALSE;
  gaRTPInfo[iSessId].lRTCPTimerId = -1;
  gaRTPInfo[iSessId].bTimer = 0;
  gaRTPInfo[iSessId].ucSigSessId = SessInfo->ucSigSessId;
  gaRTPInfo[iSessId].ucMode = SessInfo->ucMode;  
  gaRTPInfo[iSessId].ucEpIndex = SessInfo->ucEpIndex;
  gaRTPInfo[iSessId].ucSessType = SessInfo->ucSessType;

  if(gaRTPInfo[iSessId].ucMode != RTP_SESS_CALLWAIT)
  {
    if(gaRTPInfo[iSessId].ucMode == RTP_SENDONLY ||
              gaRTPInfo[iSessId].ucMode == RTP_SENDRECV)
    {
      dspipcClearQs(gaRTPInfo[iSessId].ucEpIndex);
    }
  }
  /* Create RTP / RTCP Sockets */
  if(rtpCreateSocket(iSessId) == FAILURE)
  {
    printk("\nrtpCreateSocket FAILED");
    return FAILURE;
  }
  if(gaRTPInfo[iSessId].ucMode == RTP_SENDRECV ||
        gaRTPInfo[iSessId].ucMode == RTP_SENDONLY ||
        gaRTPInfo[iSessId].ucMode == RTP_RECVONLY ||
        gaRTPInfo[iSessId].ucMode == RTP_INACTIVE   )
    dspipcSetDSPDataMode(gaRTPInfo[iSessId].ucEpIndex, gaRTPInfo[iSessId].ucMode);
  SessInfo->iSessId = iSessId;


  return SUCCESS;
}
/****************************************************************
 *  Function Name : rtpModifySession.                           *
 *  Description   : API Function to modify a RTP session.       *
 *  Input         : None.                                       *
 *  Output        : RTP Session.                                *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpModifySession( SessInfo_t *SessInfo)
{
#if KRTCP_ENABLED
  UINT32 ulRTCPIntervalTime;
  INT32  lAvgRTCPSize;
#endif
  INT16  iIndex;
  UCHAR  ucEpIndex;

  iIndex = SessInfo->iSessId;
  gaRTPInfo[iIndex].ucMode = SessInfo->ucMode;
  gaRTPInfo[iIndex].ucSessType = SessInfo->ucSessType;
  gaRTPInfo[iIndex].ulDestIPAddr = SessInfo->ulDestIPAddr;
  gaRTPInfo[iIndex].uiDestRTPPort = SessInfo->uiDestRTPPort;
  gaRTPInfo[iIndex].uiDestRTCPPort = SessInfo->uiDestRTCPPort;
  gaRTPInfo[iIndex].ucEpIndex = SessInfo->ucEpIndex;
#if THREEWAY_CONFERENCE
  gaRTPInfo[iIndex].bVirtualPort = SessInfo->bVirtualPort;
  if(SessInfo->bVirtualPort == TRUE)
    ucEpIndex = gaRTPInfo[iIndex].ucEpIndex + MAX_SLIC_CHANNELS;
  else
#endif
    ucEpIndex = gaRTPInfo[iIndex].ucEpIndex;
  if(gaRTPInfo[iIndex].ucMode != RTP_SESS_CALLWAIT)
  {
    if(gaRTPInfo[iIndex].ucMode == RTP_SENDONLY ||
         gaRTPInfo[iIndex].ucMode == RTP_SENDRECV)
    {
      dspipcClearQs(ucEpIndex);
    }
    dspipcSetDSPDataMode(ucEpIndex, gaRTPInfo[iIndex].ucMode);
  }
  /* Check for the validity of requested bandwidth and payload type */
  if(SessInfo->iSessionBW != -1)
  {
    gaRTPInfo[iIndex].iSessionBW=SessInfo->iSessionBW;
  }
  if(SessInfo->uiPayloadType < 128)
  {
    gaRTPInfo[iIndex].uiPayloadType=SessInfo->uiPayloadType;
    gaRTPInfo[iIndex].uiDynPayloadType=SessInfo->uiDynPayloadType;
  }
#if SNMP_RTP
  gaRTPInfo[iIndex].ulSenderJoins++;
  gaRTPInfo[iIndex].ulRcvrJoins++;
#endif

#if KRTCP_ENABLED
  if(gaRTPInfo[iIndex].lRTCPTimerId == -1)
  {
    if(gaRTPInfo[iIndex].iSessionBW == 0)
       gaRTPInfo[iIndex].iSessionBW = 500;
    gaRTPInfo[iIndex].ulRTCPInterval = rtcpInterval(1,0,
                                             gaRTPInfo[iIndex].iSessionBW,
                                             FALSE,0,&lAvgRTCPSize, TRUE);
    ulRTCPIntervalTime = gaRTPInfo[iIndex].ulRTCPInterval;
    

    /* Start the timer for RTCP packets */
    timerStart(&gaRTPInfo[iIndex],
               ulRTCPIntervalTime,
               rtcpHandleIntervalTimer, 
               (unsigned long)&gaRTPInfo[iIndex]);
    gaRTPInfo[iIndex].bTimer = 1;

   }
#endif
  /* Create AP Flow to get voice on different RX Queue */
  rtpCreateAPFlow(SessInfo->ulDestIPAddr,
                  SessInfo->uiDestRTPPort,
                  SessInfo->ulSrcIPAddr,
                  SessInfo->uiRTPPort,1);
  return SUCCESS;
}
/****************************************************************
 *  Function Name : rtpModifySessMode.                          *
 *  Description   : API Function to modify a RTP session mode.  *
 *  Input         : None.                                       *
 *  Output        : RTP Session.                                *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpModifySessMode(UINT16 uiSesId,UCHAR ucMode,UCHAR ucEpIndex)
{
  gaRTPInfo[uiSesId].ucMode = ucMode;
  if(ucMode == RTP_SENDRECV || ucMode == RTP_SENDONLY)
  {
    dspipcClearQs(ucEpIndex);
  }
  dspipcSetDSPDataMode(ucEpIndex, gaRTPInfo[uiSesId].ucMode);
  return SUCCESS;
}
/****************************************************************
 *  Function Name : rtpModifySessCodec.                         *
 *  Description   : API Function to modify a RTP session codec. *
 *  Input         : None.                                       *
 *  Output        : RTP Session.                                *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
INT16 rtpModifySessCodec(INT16 iSessId,UINT16 uiPayloadType, UCHAR ucEpIndex)
{
  gaRTPInfo[iSessId].uiPayloadType=uiPayloadType;
  dspipcClearQs(ucEpIndex);
  return SUCCESS;
}
/****************************************************************
 *  Function Name : rtpGetSessId.                               *
 *  Description   : API Function to get RTP Session ID.         *
 *  Input         : RTP Session.                                *
 *  Output        : None.                                       *
 *  Return Value  : Session ID on SUCCESS / FAILURE.            *
 ***************************************************************/
INT16 rtpGetSessId(SessInfo_t *pSessInfo)
{
  UINT32 ulIndex;
  for(ulIndex = 0; ulIndex < MAX_RTP_SESSIONS; ulIndex++)
  {
    if(CheckElement(gaRTPBitMap,MAX_RTP_SESSIONS,ulIndex) == ELE_ALLOCATED)
    {
      if(gaRTPInfo[ulIndex].ucSigSessId == pSessInfo->ucSigSessId)
        return ulIndex;
    }
  }
  return FAILURE;
}


/****************************************************************
 *  Function Name : rtpCreateAPFlow.                            *
 *  Description   : API Function to Create AP Flow for RTP.     *
 *  Output        : None.                                       *
 *  Return Value  : Session ID on SUCCESS / FAILURE.            *
 ***************************************************************/
int rtpCreateAPFlow(UINT32 src, 
                    UINT16 sport, 
                    UINT32 dst, 
                    UINT16 dport,
                    UCHAR  bCreate)
{
  apFlowEntry_t apflow;
  apFlowEntry_t *pReturnFlow;
  UINT16 hash;
  int result;
  struct net_device *dev;
  unsigned char emacId;

  dev = (struct net_device*)ip_dev_find(dst);
  if(dev == NULL)
  {
     printk("Could not get Networking Device for Address: %x\n",dst);
     return FAILURE;
  }

  if(!strcmp(dev->name,"eth0"))
  {
    emacId = 1;
  }
  else if(!strcmp(dev->name,"eth1"))
  {
    emacId = 2;
  }
  else 
  {
    emacId = 5;
    return 0;
    /* In case of ATM, we need to take the MAC from "nas0" interface */
    dev = dev_get_by_name("nas0");
    if(dev == NULL)
    {
       printk("Could not get Device for nas0 interface \n");
       return FAILURE;
    }
  }
  
  /* intializing the entry with all Zeros */
  memset(&apflow, 0, sizeof(apFlowEntry_t));

  /* setting the 5 tuple values */
  apflow.srcIPAddr = src;
  apflow.dstIPAddr = dst;
  apflow.protocol = 17;
  apflow.otherInfo.tcpUdpInfo.srcPort = sport;
  apflow.otherInfo.tcpUdpInfo.dstPort = dport; 

#if 0
  printk("Flow Parameters: %x   %x  %d  %d\n",
         src,dst,sport,dport);
  printk("EMAC ID: %d   %s\n",emacId,dev->name);
#endif

  apflow.entryType = AP_TCP_UDP_ENTRY;
  apflow.operations = (0x1 << AP_ROUTE_VALID_BIT);
  apflow.operations |= (0x1 << AP_DO_ETH_HDR_BIT);
  for(result = 0; result < 6; result++)
    apflow.dstMacAddr[result] = dev->dev_addr[result];

  apflow.egressList[0].pFlowID = (void*)2;
  apflow.egressList[0].pEgress = (void*)0xffffffff;
  hash = apCalculateHash(emacId, &apflow);
  if(bCreate == 0)
    result = apDeleteFlowEntry(emacId,hash,&apflow,(UINT32*)&pReturnFlow);
  else 
  {
    result = apAddFlowEntry(emacId,hash,&apflow,&pReturnFlow);
  }
  return result;
}
#endif

#if KRTCP_ENABLED

/****************************************************************
 *  Function Name : timerStart.                                 *
 *  Description   : API Function to start timer for RTCP.       *
 *  Input         : RTP Session Index, Timeout, handler and data*
 *  Output        : None.                                       *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
int timerStart(RTPInfo_t *pRTPInfo,
               UINT32 timeout, 
               void (*handler)(unsigned long), 
               unsigned long data)
{
  struct timer_list *pTimer = &rtcpTimer[pRTPInfo->iSessionIndex];

  /* Initialize RTCP Timer */
  init_timer(pTimer);
  pTimer->function = handler;
  pTimer->expires = jiffies + timeout;
  pTimer->data = data; 
  add_timer(pTimer);   
  pRTPInfo->lRTCPTimerId = 1;
  return SUCCESS;
}


/****************************************************************
 *  Function Name : timerStop.                                  *
 *  Description   : API Function to stop RTCP timer.            *
 *  Input         : RTP Session Index.                          *
 *  Output        : None.                                       *
 *  Return Value  : SUCCESS / FAILURE.                          *
 ***************************************************************/
int timerStop(RTPInfo_t *pRTPInfo)
{
  /* Initialize RTCP Timer */
  if(pRTPInfo->lRTCPTimerId != -1)
    del_timer(&rtcpTimer[pRTPInfo->iSessionIndex]);
  else
    return FAILURE;
  pRTPInfo->lRTCPTimerId = -1;
  return SUCCESS;
}

#endif


