/*======================================================================
 * File Name	  :	legerity88111.c
 * Description	:	Legerity Le88111/Le88131 codec driver
 *======================================================================
 */

#include <oswrapper.h>
#include "legerityparams.h"
#include "legerityrw.h"

#define LEGERITY_COUNTRIES	2


/*******************************************************
  FOR USA ON OUR H/W => Put -0.5 DB Loss in Tx and -2.3 in Rx 
********************************************************/

extern slicHandlers_t slicHandlers;
#define LEGERITY_UNIT 0

/* Coefficients for Legerity88111 */
/* Reg Addr: 0xCA DISN Filter */
/* Digital Impedance Scaling Network (DISN Filter) */
UCHAR Impedance_DIMDENCE[LEGERITY_COUNTRIES][3]= {
                    /* USA  => 600 ohms */
                    {0xF5,  
		    0xF5,  
                    0xF5},

                    /* FRANCE */
                    {
                    0xE6,      
                    0xE6,
                    0xE6}
              };

/* Reg Addr: 0x98 ZFIR Filter */
UCHAR  Impedance_Z_FIR_COFF[LEGERITY_COUNTRIES][3][10] = {
        /* USA */
        {
	  {0xCA, 0x4D,  0xAB, 0xAD, 0x4B, 0x37, 0x33, 0xA5, 0xBA, 0x3F}, 
	  {0xCA, 0x4D,  0xAB, 0xAD, 0x4B, 0x37, 0x33, 0xA5, 0xBA, 0x3F}, 
	  {0xCA, 0x4D,  0xAB, 0xAD, 0x4B, 0x37, 0x33, 0xA5, 0xBA, 0x3F}
        },
        {
          /* FRANCE */
	  {0x4A, 0xA0, 0x32, 0xC1, 0xAA, 0xBA, 0x2B, 0xB9, 0xBA, 0xD2},  /* A-LAW   */
	  {0x4A, 0xA0, 0x32, 0xC1, 0xAA, 0xBA, 0x2B, 0xB9, 0xBA, 0xD2}, 
	  {0x4A, 0xA0, 0x32, 0xC1, 0xAA, 0xBA, 0x2B, 0xB9, 0xBA, 0xD2},  /* A-LAW   */
        }
     };


/* Reg Addr: 0x9A ZIIR Fitler */

UCHAR Impedance_Z_IIR_COFF[LEGERITY_COUNTRIES][3][5] = {
       {
         /* USA */
         {0xBA, 0xCB, 0x36, 0x9F, 0x01},  
         {0x4A, 0xCB, 0x36, 0x9F, 0x01},  
         {0xBA, 0xCB, 0x36, 0x9F, 0x01},  
       },
       {
         /* FRANCE */
         {0xBA, 0x24, 0xB5, 0x2E, 0x01},
         {0x52, 0xB2, 0x27, 0x2E, 0x01},
         {0xBA, 0x24, 0xB5, 0x2E, 0x01},
       }
     };

/* Reg Addr: 0x8A R Filter */
UCHAR Impedance_R_COFF[LEGERITY_COUNTRIES][3][14] = {
      {
        /* USA */
        {0xDC, 0x01, 0x32, 0xD0, 0x3A, 0xA4, 0x2A, 0x3F, 0x25, 0x9F, 0x5B, 0x97, 0xAB, 0x8F},
        {0xDC, 0x01, 0x2A, 0xC0, 0xBC, 0xB4, 0x73, 0x3F, 0xA4, 0x9F, 0xAB, 0x97, 0x2C, 0x8F},
        {0xDC, 0x01, 0x32, 0xD0, 0x3A, 0xA4, 0x2A, 0x3F, 0x25, 0x9F, 0x5B, 0x97, 0xAB, 0x8F},
      },
      {
        /* FRANCE */
        {0x1D, 0x01, 0xA1, 0x00, 0x2A, 0x08, 0xCA, 0xAA, 0x22, 0x41, 0x23, 0xA9, 0xA2, 0xA3}, 
        {0x1D, 0x01, 0xA1, 0x00, 0x2A, 0x08, 0xCA, 0xAA, 0x22, 0x41, 0x23, 0xA9, 0xA2, 0xA3}, 
        {0x1D, 0x01, 0xA1, 0x00, 0x2A, 0x08, 0xCA, 0xAA, 0x22, 0x41, 0x23, 0xA9, 0xA2, 0xA3}, 
      }

     };

/* Reg Addr: 0x88 X Filter */
UCHAR Impedance_X_COFF[LEGERITY_COUNTRIES][3][12] = {
     {
       /* USA */
       {0xA8, 0x70, 0xED, 0x8F, 0xBD, 0xAE, 0xAA, 0x97, 0x32, 0x37, 0x62, 0xBE},
       {0xA8, 0x70, 0xED, 0x8F, 0xBD, 0xAE, 0xAA, 0x97, 0x42, 0x37, 0x62, 0xBE},
       {0xA8, 0x70, 0xED, 0x8F, 0xBD, 0xAE, 0xAA, 0x97, 0x32, 0x37, 0x62, 0xBE},
     },
     {
       {0xA4, 0x40, 0x2B, 0xAE, 0xA2, 0xAB, 0xA2, 0xAD, 0xC5, 0x34, 0xAB, 0x2D},
       {0xA4, 0x40, 0x2B, 0xAE, 0xA2, 0xAB, 0x33, 0xAD, 0x25, 0x34, 0xAB, 0x2D},
       {0xA4, 0x40, 0x2B, 0xAE, 0xA2, 0xAB, 0xA2, 0xAD, 0xC5, 0x34, 0xAB, 0x2D},
     }
    };

/* Reg Addr: 0x82 GR Filter */
UCHAR Impedance_RX_GAIN[LEGERITY_COUNTRIES][3][2] = {
    {
      /* USA */
      {0x22, 0xC0},
      {0xB2, 0xC0},
      {0x22, 0xC0},
    },
    {

      {0xE6, 0x21},
      {0x22, 0xA0},
      {0xE6, 0x21},
    }
};

/* Reg Addr: 0x80 GX Filter */
UCHAR Impedance_TX_GAIN[LEGERITY_COUNTRIES][3][2] = {
   {
     /* USA */
     {0x2B, 0x50},
     {0xA6, 0x50},
     {0x2B, 0x50},
   },
   {
     /* FRANCE */
     {0xBA, 0xA1},
     {0x3A, 0xA0},
     {0xBA, 0xA1},
   }
};

/* Reg Addr: 0x50 ASIN Fliter */
UCHAR Impedance_VOICE_GAIN[LEGERITY_COUNTRIES][3] = {
   /* USA */
   { 0x00, 0x00, 0x00 },
 
   /* FRANCE */
   { 0x00, 0x00, 0x00 }
 };

/* Reg Addr: 0x70 */
UCHAR Impedance_OPCOND[LEGERITY_COUNTRIES][3] = {
   /* USA */
   { 0x00, 0x00, 0x00},

   /* FRANCE */
   { 0x00, 0x00, 0x00}
 };


/* Reg Addr: 0x86 BFIR Filter */
UCHAR Impedance_B_FIR_COFF[LEGERITY_COUNTRIES][3][14] =  {
  {
    /* USA */
    {0xAA, 0x42, 0xA1, 0x2B, 0x1A, 0xA3, 0xA8, 0xF4, 0x9F, 0x3A, 0xFA, 0x9F, 0xF9, 0xF0},
    {0xAA, 0x42, 0xA1, 0x2B, 0x1A, 0xA3, 0xA8, 0xFD, 0x9F, 0x2A, 0xF2, 0xAF, 0xC9, 0xF0},
    {0xAA, 0x42, 0xA1, 0x2B, 0x1A, 0xA3, 0xA8, 0xF4, 0x9F, 0x3A, 0xFA, 0x9F, 0xF9, 0xF0},
  },
  {
    /* FRANCE */
    {0x5A, 0x43, 0x22, 0xA5, 0x12, 0xA1, 0x33, 0x32, 0xA4, 0xC2, 0x7A, 0x87, 0xA8, 0xF0},
    {0x7A, 0x43, 0x22, 0xA5, 0x12, 0xA1, 0x33, 0x32, 0x25, 0xE2, 0x7A, 0x87, 0xA8, 0xF0},
    {0x5A, 0x43, 0x22, 0xA5, 0x12, 0xA1, 0x33, 0x32, 0xA4, 0xC2, 0x7A, 0x87, 0xA8, 0xF0},
  }
};

/* Reg Addr: 0x96 BIIR Filter */
UCHAR Impedance_B_IIR_COFF[LEGERITY_COUNTRIES][3][2] = {
  {
    /* USA */
    {0x2e, 0x01},
    {0x2e, 0x01},
    {0x2e, 0x01}
  },
  {
    /* FRANCE */
    {0x2E, 0x01},
    {0x2E, 0x01},
    {0x2E, 0x01}
   }
 };
 

/* Reg Addr: 0xD2 */
UCHAR TONE_SIGNAL_GEN[11] = {0x00,0x00,0x00,0x00,0x88,0x35,0xae,0x00,0x00,0x00,0x00};


/* Reg Addr: 0xE4 Only useful in Le88221/Le88241 */
UCHAR REGULATOR_PARA[3] = {0x02,0x04,0x0D}; /* Without Tracking */
//UCHAR REGULATOR_PARA[3] = {0x00,0x04,0x11}; /* Without Tracking */

/* Reg Addr: 0xC2 */
UCHAR LOOP_SUPERVISION[4] = {0x1B,0x84,0xb3,0x0e};

/* Reg Addr: 0xC6 */
UCHAR DC_FEED[2] = {0x12,0x08};

/**********************************************************************/
/*							Internal functions						  */
/**********************************************************************/
static void codecChanCfgEnable_88111(int codecNo,int chNo);
static void codecChanCfgDisable_88111(int codecNo,int chNo);
static void codecImpedanceCfg_88111(int codecNo);
static void codecSignalGBias_88111(int codecNo,int ToneType);

/***********************************************************************
   Description  : Function to get configured codec parameters based on
                  codec Type passed.
***********************************************************************/
void codecPcmInterface_88111(unsigned char ucCodecType)
{
  DEBUG(PRINT("Codec Type => %d\n",ucCodecType),DEBUG_INFO);
  switch(ucCodecType)
  {
   case A_LAW:
    slicHandlers.ucTimeSlot0 = 1;
    slicHandlers.ucTimeSlot1 = 2;
    slicHandlers.ucPcmMode = 0x3F; //A-law
    slicHandlers.ucClock = 0x82;  //  ---2.048MHz
    break;
   case MU_LAW:
    slicHandlers.ucTimeSlot0 = 1;
    slicHandlers.ucTimeSlot1 = 2;
    slicHandlers.ucPcmMode = 0x7F; //Mu-Law
    slicHandlers.ucClock = 0x82;  //  ---2.048MHz
    break;
   default:
    slicHandlers.ucTimeSlot0 = 3;
    slicHandlers.ucTimeSlot1 = 5;
    slicHandlers.ucPcmMode = 0xbF; //Linear
    slicHandlers.ucClock =  0x82;  //  ---2.048MHz
  }
  DEBUG(PRINT("Sport Codec:%d\r\n",ucCodecType), DEBUG_INFO);
}

/***********************************************************************
  Description : Ths function is used to initialize Legerity 88111 codec 
  based on the codec number passed.
 ======================================================================
 */ 
void legerity88111_init(int codecNo)
{
   int j,length;
   unsigned short pcmMode = confGetPCMMode(0);
   unsigned char ucAddr;
   unsigned char aucTempData[100];
   char cData;	

   DEBUG(PRINT("Codec Initialization => %d\r\n",codecNo), DEBUG_INFO);
   codecPcmInterface_88111(pcmMode);

   /* H/W Reset */
   write2codec1word(codecNo, 0x04);
   /* Give some delay after Codec Reset */
   mdelay(10);
   /* Verify device ID */
   ucAddr = CODEC_REG_PCN_R;
   length = 2;
   read2codecArray(codecNo,ucAddr,aucTempData,length);
   if((aucTempData[0] == 0x2 && aucTempData[1] == 0xa ))
   {
     DEBUG(PRINT("\r\n Codec Type => CODEC_LE88111\n"), DEBUG_INFO);
   }
   else 
   {
     DEBUG(PRINT("Not 88111 device [%x]/[%x] \n",aucTempData[0],
                              aucTempData[1]), DEBUG_EXCEPTION);
   }
   /* Program the Clock based on type of codec */
   write2codec2word(codecNo,CODEC_REG_CFG_W,slicHandlers.ucClock);	
#if LEGERITY_UNIT
   read2codec2wordprintf(codecNo,CODEC_REG_CFG_R);
#endif		
   /* Switching Regulator Control */
   write2codec2word(codecNo,0x01,CODEC_REG_SRC_W);
   for(j=0; j<1; j++)
   {
     /* Need delay - don't remove it */
     PRINT("\r\n*****Channel: configuration *****\r\n");
     /* Enable programming of the channel */
     codecChanCfgEnable_88111(codecNo,j);	/* Channel 0  */
     /* Configure the Impedence */
     codecImpedanceCfg_88111(codecNo);
     /* Ringing Signal Configurations */
     codecSignalGBias_88111(codecNo,CODEC_RINGING_TONE); 	

     /* Loop Supervision Parameters */
     ucAddr = CODEC_REG_LOOP_SUPERVISION_W;
     length = 4;
     write2codecArray(codecNo,ucAddr,&LOOP_SUPERVISION[0],length);

#if LEGERITY_UNIT
     ucAddr = CODEC_REG_LOOP_SUPERVISION_R;
     read2codecArrayPrintf(codecNo,ucAddr,length);
#endif		
     /* DC Feed Parameters */				
     ucAddr = CODEC_REG_DC_FEED_W;
     length = 2;
     write2codecArray(codecNo,ucAddr,&DC_FEED[0],length);
#if LEGERITY_UNIT
     ucAddr = CODEC_REG_DC_FEED_R;
     read2codecArrayPrintf(codecNo,ucAddr,length);
#endif		
     /* Program DC Parameter */
     ucAddr = CODEC_REG_SYS_STATECFG_W;
     cData = 0x21;
     write2codec2word(codecNo,ucAddr,cData);
  
#if LEGERITY_UNIT
     ucAddr = CODEC_REG_SYS_STATECFG_R;
     read2codec2wordprintf(codecNo,ucAddr);
#endif		
     /* Configure Time Slots */
     /* TX Time Slot */
     ucAddr = CODEC_REG_TX_TS_W;
     if(codecNo == 0)
     {
       cData = slicHandlers.ucTimeSlot0;
     }
     else 
     {
       cData = slicHandlers.ucTimeSlot1;
     }
     write2codec2word(codecNo,ucAddr,cData);
#if LEGERITY_UNIT
     ucAddr = CODEC_REG_TX_TS_R;
     read2codec2wordprintf(codecNo,ucAddr);
#endif			
	
     ucAddr = CODEC_REG_RX_TS_W;
     write2codec2word(codecNo,ucAddr,cData);
#if LEGERITY_UNIT
     ucAddr = CODEC_REG_RX_TS_R;
     read2codec2wordprintf(codecNo,ucAddr);
#endif		

     /* Program Edge of the clock , clock slot register as negetive */
     ucAddr = CODEC_REG_TS_EDGE_W;
     cData = 0x3F;
     write2codec2word(codecNo,ucAddr,cData);

#if LEGERITY_UNIT
     ucAddr = CODEC_REG_TS_EDGE_R;
     read2codec2wordprintf(codecNo,ucAddr);
#endif	

     mdelay(5);
     /* System State Register: Disconnect */
     ucAddr = CODEC_REG_SYS_STATE_W;
     cData = CODEC_STATE_DISCONNECT;  
     write2codec2word(codecNo,ucAddr,cData);

#if LEGERITY_UNIT
     ucAddr = CODEC_REG_SYS_STATE_R;
     read2codec2wordprintf(codecNo,ucAddr);
#endif		

     /* System State Register: IDLE */
     ucAddr = CODEC_REG_SYS_STATE_W;
     cData = CODEC_STATE_IDLE;  		
     write2codec2word(codecNo,ucAddr,cData);
#if LEGERITY_UNIT
     ucAddr = CODEC_REG_SYS_STATE_R;
     read2codec2wordprintf(codecNo,ucAddr);
#endif	
     ucAddr = CODEC_REG_REGULATOR_PARA_W;
     length = sizeof(REGULATOR_PARA);
     write2codecArray(codecNo,ucAddr,REGULATOR_PARA,length);
#if LEGERITY_UNIT
     ucAddr = CODEC_REG_REGULATOR_PARA_R;
     read2codecArrayPrintf(codecNo,ucAddr,length);
#endif		
     /* Disable programming of the channel */
     codecChanCfgDisable_88111(codecNo,j);
     mdelay(10);
     /* Disable channel - 1 */
     codecChanCfgDisable_88111(codecNo,j+1);
#if LEGERITY_UNIT
     PRINT("\r\n*****Channel: configuration end*****\r\n");
#endif
  }
  DEBUG(PRINT("Codec/Slic initialization successfully(V1.3)\n\r"), DEBUG_INFO);
}


/*======================================================================
 * Function Name	: slicModeSetting 
 * Description  	: setting the slic mode
 *======================================================================
 */
void slicModeSetting_88111(int codecNo,int chNo,int mode)
{
  unsigned char ucAddr;
  char cData;	
  chNo = 0;
  codecChanCfgEnable_88111(codecNo,chNo);
  
  switch(mode)
  {
    case SLIC_STANDBY: /* SLIC Standby */
      /* enable the channel programming capability */
      ucAddr = CODEC_REG_SYS_STATE_W;
      cData = CODEC_STATE_IDLE;				
      write2codec2word(codecNo,ucAddr,cData);
      break;
    case SLIC_ACTIVE: /* SLIC Activate */
      /* enable the channel programming capability */
      /* Here channel number is always as "0" */
      ucAddr = CODEC_REG_SYS_STATE_W;
      cData = CODEC_STATE_ACTIVE;	
      write2codec2word(codecNo,ucAddr,cData);
      break;
    case SLIC_RING:  /* Slic Ring */
      ucAddr = CODEC_REG_SYS_STATE_W;
      cData = CODEC_STATE_BALANCE_RINGING;	/* Balance Ringing state */
      write2codec2word(codecNo,ucAddr,cData);
      break;
    case SLIC_RINGOFF: /* Slic Ring Off */
      ucAddr = CODEC_REG_SYS_STATE_W;
      cData = CODEC_STATE_ACTIVE;	
      write2codec2word(codecNo,ucAddr,cData);
      break; 
    default:
      return;
    }
    /* diable the channel programming capability */
    codecChanCfgDisable_88111(codecNo,chNo);
}

/*======================================================================
 * Function Name	: codecReadStatus
 * Description  	: read on hook/off hook status
 *======================================================================
 */
unsigned short codecReadStatus_88111(int codecNo)
{
  char cStatus = 0xff;
  unsigned char ucData[2] = {0,0};
  unsigned char ucAddr;
  ucAddr = CODEC_REG_READ_SIGNAL_POLL;
  read2codecArray(codecNo,ucAddr,ucData,2);

  /* Le88111: D0 in byte 1(channel 1) - "0" means on hook "1" means off hook */
  ucData[0] = ucData[0] & 0x01;	/* Read channel 1 hook status */
  if(codecNo == 0)	/* Codec 1 port 0*/
  {			
    cStatus = ucData[0]; /* Logic channel 1 */
  }
  else if(codecNo == 1)
  {
    cStatus = ucData[0] << 1; /* Logic channel 2 */		
  }
  return(cStatus); /* Bit 0 means channel 1, Bit 1 means channel 2 */
}
	
/*======================================================================
  Function to enable Channel Configurations.
 ======================================================================*/
static void codecChanCfgEnable_88111(int codecNo, int chNo)
{
  unsigned char ucAddr;
  unsigned char ucData;

  ucAddr = CODEC_REG_CH_CHAN_ENABLE_W;
  ucData = 1;
  write2codec2word(codecNo,ucAddr,ucData);

#if LEGERITY_UNIT_NO
  ucAddr = CODEC_REG_CH_CHAN_ENABLE_R;
  read2codec2wordprintf(codecNo,ucAddr);
#endif		
}    

/*======================================================================
  Function to disable Channel Configurations.
 ======================================================================*/
static void codecChanCfgDisable_88111(int codecNo,int chNo)
{
  unsigned char ucAddr;
  unsigned char ucData;
  ucAddr = CODEC_REG_CH_CHAN_ENABLE_W;
  ucData = 0;
  write2codec2word(codecNo,ucAddr,ucData);

#if LEGERITY_UNIT_NO
  ucAddr = CODEC_REG_CH_CHAN_ENABLE_R;
  read2codec2wordprintf(codecNo,ucAddr);
#endif	
}

/*======================================================================
	Function to program coefficients. 
  ====================================================================*/
static void codecImpedanceCfg_88111(int codecNo)
{
  unsigned char ucAddr;
  unsigned char cData;
  int length;
  
  int codec_Type = confGetPCMMode(0);
  UINT16 country;
  confGetCountryOpts(&country);
  if(country != 0 && country != 1)
    country = 1;
  country = 0; /* For time being, Program SLIC only for 600 Ohms */
  /* Voice Path Gains (AISN Filter) */
  ucAddr = CODEC_REG_VOICE_GAIN_W;
  cData = Impedance_VOICE_GAIN[country][codec_Type];  	
  write2codec2word(codecNo,ucAddr,cData);

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_VOICE_GAIN_R;
  read2codec2wordprintf(codecNo,ucAddr);
#endif		

  /* Digital Impedance Scaling Network (DISN Filter) */
  ucAddr = CODEC_REG_DISN_W;
  cData = Impedance_DIMDENCE[country][codec_Type];  	
  write2codec2word(codecNo,ucAddr,cData);
#if LEGERITY_UNIT
  ucAddr = CODEC_REG_DISN_R;
  read2codec2wordprintf(codecNo,ucAddr);
#endif	

  udelay(100000);
  /* ZFIR Filter Coefficients */
  ucAddr = CODEC_REG_Z_FIR_FILITER_W;
  length = 10;
  write2codecArray(codecNo,ucAddr,&Impedance_Z_FIR_COFF[country][codec_Type][0],length);	

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_Z_FIR_FILITER_R;
  read2codecArrayPrintf(codecNo,ucAddr,length);
#endif	

  /* ZIIR Filter Coefficients */
  ucAddr = CODEC_REG_Z_IIR_FLITER_W;
  length = 5;
  write2codecArray(codecNo,ucAddr,&Impedance_Z_IIR_COFF[country][codec_Type][0],length);	

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_Z_IIR_FLITER_R;
  read2codecArrayPrintf(codecNo,ucAddr,length);
#endif	
		
  /* R Filter Coefficients */
  ucAddr = CODEC_REG_R_FLITER_W;
  length = 14;
  write2codecArray(codecNo,ucAddr,&Impedance_R_COFF[country][codec_Type][0],length);	

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_R_FLITER_R;
  read2codecArrayPrintf(codecNo,ucAddr,length);
#endif		

  /* X Filter Coefficients */
  ucAddr = CODEC_REG_X_FLITER_W;
  length = 12;
  write2codecArray(codecNo,ucAddr,&Impedance_X_COFF[country][codec_Type][0],length);	

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_X_FLITER_R;
  read2codecArrayPrintf(codecNo,ucAddr,length);
#endif		

  /* GR (Receive Gain) */
  ucAddr = CODEC_REG_GR_FLITER_W;
  length = 2;
  write2codecArray(codecNo,ucAddr,&Impedance_RX_GAIN[country][codec_Type][0],length);	

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_GR_FLITER_R;
  read2codecArrayPrintf(codecNo,ucAddr,length);
#endif	

  /* GX (Transmit Gain) */
  ucAddr = CODEC_REG_GX_FLITER_W;
  length = 2;
  write2codecArray(codecNo,ucAddr,&Impedance_TX_GAIN[country][codec_Type][0],length);	

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_GX_FLITER_R;
  read2codecArrayPrintf(codecNo,ucAddr,length);
#endif		
	
  /* BFIR Filter  Coefficients */
  ucAddr = CODEC_REG_B_FIR_FLITER_W;
  length = 14;
  write2codecArray(codecNo,ucAddr,&Impedance_B_FIR_COFF[country][codec_Type][0],length);	

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_B_FIR_FLITER_R;
  read2codecArrayPrintf(codecNo,ucAddr,length);
#endif	
	
  /* BIIR Filter Coefficients */
  ucAddr = CODEC_REG_B_IIR_FLITER_W;
  length = 2;
  write2codecArray(codecNo,ucAddr,&Impedance_B_IIR_COFF[country][codec_Type][0],length);

#if LEGERITY_UNIT
  ucAddr = CODEC_REG_B_IIR_FLITER_R;
  read2codecArrayPrintf(codecNo,ucAddr,length);
#endif		

  /* Operating Conditions */
  ucAddr = CODEC_REG_OPR_CONDITION_W;
  cData = Impedance_OPCOND[country][codec_Type];  	
  write2codec2word(codecNo,ucAddr,cData);
#if LEGERITY_UNIT
  ucAddr = CODEC_REG_OPR_CONDITION_R;
  read2codec2wordprintf(codecNo,ucAddr);
#endif		

  /* Operating Functions: PCM mode/Filter enable/disable */
  ucAddr = CODEC_REG_OPR_FUN_W;
  cData = slicHandlers.ucPcmMode;  	
  write2codec2word(codecNo,ucAddr,cData);
#if LEGERITY_UNIT
  ucAddr = CODEC_REG_OPR_FUN_R;
  read2codec2wordprintf(codecNo,ucAddr);
#endif	
}

/*======================================================================
	Function to set Ringing parameters .
  =====================================================================*/
static void codecSignalGBias_88111(int codecNo,int ToneType)
{
  unsigned char ucAddr;
  int length;

  
  /* Signal Generator A and B Parameters: Sin/25HZ/65Vpk/no Bais */
  ucAddr = CODEC_REG_SIG_GEN_PARA_W;
  length = 11;
  write2codecArray(codecNo,ucAddr,&TONE_SIGNAL_GEN[0],length);
  
}


void resetSLIC(void)
{
  legerity88111_init(0);
  legerity88111_init(1);
}
