#include <oswrapper.h>
#include "legerity88221.h"
#include "legerityrw.h"

/**********************************************************************/
/*							Internal functions						  */
/**********************************************************************/
static void codecChanCfgEnable(int codecNo,int chNo);
static void codecChanCfgDisable(int codecNo,int chNo);
static void codecChanWriteNValue(u8 cno, u8 addr, u8 *pcData, u8 length);
static void codecReadNValue(u8 cno, u8 addr, u8 *pcData, u8 length); 
static void codecChinaALawCfg(int codecNo);
static void codecChinaRinging(int codecNo);
static void codecReadPrint(int codecNo,unsigned char addr,unsigned char *pcData,char length);


extern slicHandlers_t slicHandlers;
void codecPcmInterface_88221(unsigned char ucCodecType)
{
  DEBUG(PRINT("Codec Type => %d\n",ucCodecType),DEBUG_INFO);
  switch(ucCodecType)
  {
   case A_LAW:
    slicHandlers.ucTimeSlot0 = 1;
    slicHandlers.ucTimeSlot1 = 2;
    slicHandlers.ucPcmMode = 0x3F; //A-law
    slicHandlers.ucClock = 0x02;  //  ---2.048MHz
    break;
   case MU_LAW:
    slicHandlers.ucTimeSlot0 = 1;
    slicHandlers.ucTimeSlot1 = 2;
    slicHandlers.ucPcmMode = 0x7F; //Mu-Law
    slicHandlers.ucClock = 0x82;  //  ---2.048MHz
    break;
   default:
    slicHandlers.ucTimeSlot0 = 3;
    slicHandlers.ucTimeSlot1 = 5;
    slicHandlers.ucPcmMode = 0xbF; //Linear
    slicHandlers.ucClock =  0x82;  //  ---2.048MHz
  }
 DEBUG(PRINT("Sport Codec:%d\r\n",ucCodecType), DEBUG_INFO);
}



#define LEGERITY_UNIT 1
static void codec_delay(u32 time)
{
    volatile u32 i,j;
    for (i = 0; i < time; i++)
    {
        for (j = 0; j < 10; j++);
    }
}
/*======================================================================
 * Function Name	: codecInit 
 * Description  	: Initialize le88221 codec/slic
 * Input 			: codecNo - Useless now
 *======================================================================
 */ 
void legerity88221_init(int codecNo)
{
    int j,length;
    unsigned char ucAddr;
    unsigned char aucTempData[100];
    char cData;	
    cData = confGetPCMMode(0);
    codecPcmInterface_88221(cData);

	/**********************************************************
			                      _	    _
	             SPI CS Timing:    |___|
	***********************************************************/

	/* Hardware Reset */
        write2codec1word(codecNo, CODEC_REG_HW_RESET);
        mdelay(200);
	/* Read device ID */
	ucAddr = 0x73;
	length = 2;
	codecReadNValue(codecNo,ucAddr,aucTempData,length);

#if LEGERITY_UNIT	
	printk("\r\nDevice Id: 0x%x 0x%x \r\n",aucTempData[0],aucTempData[1]);
#endif	
        mdelay(200);
	/* Device Configuration Register */
	ucAddr = CODEC_REG_CFG_W;
	cData = slicHandlers.ucClock;  		
	length = 1;
	codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#if LEGERITY_UNIT
	ucAddr = CODEC_REG_CFG_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif
#if 0
        	/* Set auto clock select disable */
        	ucAddr = 0x68;
        	cData = 0x0;
        	length = 1;
        	codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

        	ucAddr = 0x69;
            codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif
            
    codec_delay(20000);	/* Can't remove this */

	/* Switching Regulator Control */
	ucAddr = CODEC_REG_REGULATOR_CTL_W;
	cData = 0x02;  		
	length = 1;	
	codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_REGULATOR_CTL_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	

	/* Switching Regulator Parameters: use  XB=VBATL, VBH=-75V, VBL=-25V  */
	ucAddr = CODEC_REG_REGULATOR_PARA_W;
	length = sizeof(REGULATOR_PARA_88221);
	codecChanWriteNValue(codecNo,ucAddr,REGULATOR_PARA_88221,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_REGULATOR_PARA_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

	/* Xmit and Rcv Clock Slot Register}  Xmt change on positive edge of PCLK,
	                                      7 Xmt/Rcv clock slot            */
	ucAddr = CODEC_REG_TS_EDGE_W;
	cData = 0x7F;
	length = 1;
	codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_TS_EDGE_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	

	/* Configure channel */
	for(j=0; j<MAX_SLIC_CHANNELS; j++)
	{
	
#ifdef LEGERITY_UNIT
		printk("\r\n*****Channel: %d configuration start*****\r\n",(j+1));
#endif
		/* Enable programming of the channel */
		codecChanCfgEnable(codecNo,j);	/* J is channel */

		/* Country lated */
		/* Configure the data which is relative to the country standard */
		/* China A-LAW */
		codecChinaALawCfg(codecNo);

		/* Configure TX/RX time slot */
		/* Set time slot (31,0) */
		if (j == 0)
		{
		    cData = slicHandlers.ucTimeSlot0;
		} else if (j == 1)
		{
		    cData = slicHandlers.ucTimeSlot1;
		} else {
		    printk("\n timeslot set error!");
		}
		
		ucAddr = CODEC_REG_TX_TS_W;
//		cData = j + 1;  			/* Can't be modified (ADI spec.)*/	
		length = 1;			
		codecChanWriteNValue(codecNo,ucAddr,&cData,length);	 

#ifdef LEGERITY_UNIT
		ucAddr = CODEC_REG_TX_TS_R;
        codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif			
		
		ucAddr = CODEC_REG_RX_TS_W;
		codecChanWriteNValue(codecNo,ucAddr,&cData,length);

#ifdef LEGERITY_UNIT
		ucAddr = CODEC_REG_RX_TS_R;
        codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

		/* Country lated */
		/* China Ringing (Not standard)*/
		codecChinaRinging(codecNo);
		
		/* Loop Supervision Parameters */
		ucAddr = CODEC_REG_LOOP_SUPERVISION_W;
		length = sizeof(LOOP_SUPERVISION_88221);
		codecChanWriteNValue(codecNo,ucAddr,LOOP_SUPERVISION_88221,length);

#ifdef LEGERITY_UNIT
		ucAddr = CODEC_REG_LOOP_SUPERVISION_R;
        codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		
				
		/* DC Feed Parameters */
		ucAddr = CODEC_REG_DC_FEED_W;
		length = sizeof(DC_FEED_88221);
		codecChanWriteNValue(codecNo,ucAddr,DC_FEED_88221,length);

#ifdef LEGERITY_UNIT
		ucAddr = CODEC_REG_DC_FEED_R;
        codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

		codec_delay(10000);

		/* System State Register: Disconnect */
		ucAddr = CODEC_REG_SYS_STATE_W;
		cData = CODEC_STATE_DISCONNECT;  
		length = 1;
		codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#ifdef LEGERITY_UNIT
		ucAddr = CODEC_REG_SYS_STATE_R;
        codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

		/* System State Register: Disconnect */
		ucAddr = CODEC_REG_SYS_STATE_W;
		cData = CODEC_STATE_IDLE;  		
		length = 1;
		codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#ifdef LEGERITY_UNIT
		ucAddr = CODEC_REG_SYS_STATE_R;
        codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	

		/* System State Register: Active */
		ucAddr = CODEC_REG_SYS_STATE_W;
		cData = CODEC_STATE_ACTIVE;  	
		length = 1;
		codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#ifdef LEGERITY_UNIT
		ucAddr = CODEC_REG_SYS_STATE_R;
        codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	

		/* Disable programming of the channel */
		codecChanCfgDisable(codecNo,j);	/* J is channel */

#ifdef LEGERITY_UNIT
		printk("\r\n*****Channel: %d configuration end*****\r\n",(j+1));
#endif
	}
#if 0	
    printk("\n show regulator register");
#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_REGULATOR_PARA_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,3);
#endif		
	printk("\n reset it");
	/* Switching Regulator Control */
	ucAddr = CODEC_REG_REGULATOR_CTL_W;
	cData = 0x02;  		
	length = 1;	
	codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_REGULATOR_CTL_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	

	/* Switching Regulator Parameters: use  XB=VBATL, VBH=-75V, VBL=-25V  */
	ucAddr = CODEC_REG_REGULATOR_PARA_W;
	length = sizeof(REGULATOR_PARA);
	codecChanWriteNValue(codecNo,ucAddr,REGULATOR_PARA_88221,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_REGULATOR_PARA_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		
#endif
	
}

/*======================================================================
 * Function Name	: slicModeSetting 
 * Description  	: setting the slic mode
 *======================================================================
 */
void slicModeSetting_88221(int codecNo,int chNo,int mode)
{
	int length;
	unsigned char ucAddr;
	char cData;	
#if 0
     /* Samuel Weng 2005/04/28 Only for testing */
	printf("Enter slicModeSetting Ch: %d Mode %d\r\n",chNo,mode);
#endif
	
	/* enable the channel programming capability */
	codecChanCfgEnable(codecNo,chNo);

    switch(mode)
    {
		case SLIC_STANDBY: 			
			ucAddr = CODEC_REG_SYS_STATE_W;
			cData = CODEC_STATE_IDLE;				/* Idle state */
			length = 1;
			codecChanWriteNValue(codecNo,ucAddr,&cData,length);
			break;

		case SLIC_ACTIVE:
			ucAddr = CODEC_REG_SYS_STATE_W;
			cData = CODEC_STATE_ACTIVE;				/* Active state */
			length = 1;
			codecChanWriteNValue(codecNo,ucAddr,&cData,length);
			break;

		case SLIC_RING:	
			ucAddr = CODEC_REG_SYS_STATE_W;
			cData = CODEC_STATE_BALANCE_RINGING;	/* Balance Ringing state */
			length = 1;
			codecChanWriteNValue(codecNo,ucAddr,&cData,length);
			break;
			
		case SLIC_RING_LOWBSEL:	/* ??? */
			/* Useless now */
			break;
  
		case SLIC_RINGOFF: 		/* ??? */
	                ucAddr = CODEC_REG_SYS_STATE_W;
                        cData = CODEC_STATE_ACTIVE;
                        write2codec2word(codecNo,ucAddr,cData);
			/* Useless now */
			break; 

		case SLIC_LOOPBACK:		/* ??? */
			/* Useless now */			
			break;

    	default:
        	break;
    }
   
    /* diable the channel programming capability */
    codecChanCfgDisable(codecNo,chNo);
}

/*======================================================================
 * Function Name	: codecReadStatus
 * Description  	: read on hook/off hook status
 *======================================================================
 */
unsigned short codecReadStatus_88221(int codecNo)
{
	char cStatus;
	unsigned char ucData[2] = {0,0};
	char length;
	unsigned char ucAddr;



#if 0	
    unsigned char aucTempData[100];
    static int test_count = 0;
	

    if (!(test_count%100))
    {
	    ucAddr = CODEC_REG_REGULATOR_PARA_R;
	    length = 3;
        codecReadPrint(codecNo,ucAddr,aucTempData,length);
        
    }

#endif

    
	ucAddr = CODEC_REG_READ_SIGNAL_POLL;
	length = 2;
	codecReadNValue(codecNo,ucAddr,ucData,length);

#if 0	
    if (!(test_count%100))
    {
        printk("\n data[0]=0x%x data[1]=0x%x", ucData[0], ucData[1]);
        
    }
#endif
    	
	/* Le88221: D0 in byte 1(channel 1) - "0" means on hook "1" means off hook */
	/*          D0 in byte 2(channel 2) - "0" means on hook "1" means off hook*/
	ucData[0] = ucData[0] & 0x01;	/* Read channel 1 hook status */
	ucData[1] = ucData[1] & 0x01;   /* Read channel 2 hook status */
	cStatus = ucData[0] | (ucData[1] << 1);

#if 0
    test_count ++;
#endif
    		
	return(cStatus); /* Bit 0 means channel 1, Bit 1 means channel 2 */
	                  /* ADI definition: "1" - on hook "0" - off hook */
}

#if 0	/* Internal function definitions */ 
#endif 

/*======================================================================
 * Function Name	: codecChanCfgEnable 
 * Description  	: Enable the channel programming for the given channel
 * Input			: chNo: {0,...}
 *======================================================================
 */
static void codecChanCfgEnable(int codecNo, int chNo)
{
	unsigned char ucAddr;
	unsigned char ucData;
	int length;

	ucData = 1 << chNo;
	ucAddr = CODEC_REG_CH_CHAN_ENABLE_W;
	length = 1;
	codecChanWriteNValue(codecNo,ucAddr,&ucData,length); 

#ifdef TEST_LEGERITY_UNIT
	ucAddr = CODEC_REG_CH_CHAN_ENABLE_R;
    length = 1;
    codecReadPrint(codecNo,ucAddr,&ucData,length);
#endif		
}    

/*======================================================================
 * Function Name	: codecChanCfgDisable
 * Description  	: Disable the channel programming for the given channel
 * Input 			: codecNo: Useless now;
 *                    chNo   : {0,...}
 *======================================================================
 */
static void codecChanCfgDisable(int codecNo,int chNo)
{
	unsigned char ucAddr;
	unsigned char ucData;
	int length;

	ucAddr = CODEC_REG_CH_CHAN_ENABLE_W;
	ucData = 0;
	length = 1;
    codecChanWriteNValue(codecNo,ucAddr,&ucData,length);

#ifdef TEST_LEGERITY_UNIT

	ucAddr = CODEC_REG_CH_CHAN_ENABLE_R;
    length = 1;
    codecReadPrint(codecNo,ucAddr,&ucData,length);
#endif	
}

/*======================================================================
 * Function Name	: codecChanWriteNValue 
 * Description  	: write the given data at given address for a 
 *                    given channel for the given codec. 
 * Input:			: codecNo - Useless now.
 *======================================================================
 */
static void codecChanWriteNValue(u8 cno, u8 addr, u8 *pcdata, u8 length) //(int codecNo,char addr,char* pcdata,int length)
{
#if 0
	char cData;
	int i;
	
	if(pcdata == NULL)
	{
		printk("codecChanWriteNValue input error!\r\n");
		return;
	}

	codecEndofCommand(codecNo);			// CS High
	codecStartofCommand(codecNo);   	// CS Low
	codecSetSPIWrite();					// Enable SPI writing function
	SPIsendData(&addr,1);
		
	for(i=0; i<length; i++)
	{
		codecEndofCommand(codecNo); 	// CS High
		codecStartofCommand(codecNo); 	// CS Low
		cData = *(pcdata + i);
		SPIsendData(&cData,1);
	}
	codecEndofCommand(codecNo); 		// CS High		
	u8 data;
	s8 i;
	u8 cs_no = 1;
	spi_select_cs(cs_no, SPI_CS_LOW);       /* CS Low */
	spi_write_enable();				        /* Enable SPI writing function */
	spi_put_data(addr);

    spi_select_cs(cs_no, SPI_CS_HIGH);      /* CS High */

	for(i = 0; i < length; i++)
	{
	    codec_delay(1);                     /* CS pulse for next transmit */
	    spi_select_cs(cs_no, SPI_CS_LOW);   /* CS Low */
		data = *(pcdata + i);
		spi_put_data(data);
		spi_select_cs(cs_no, SPI_CS_HIGH);  /* CS High */
	}
#endif
if(length == 1)
  write2codec2word(cno,addr,pcdata[0]);
else 
  write2codecArray(cno,addr,pcdata,length);

}
/*======================================================================
 * Function Name	: codecReadNValue 
 * Description  	: read N data from given address 
 * Input            : 1)codecNo: Useless.
 *					  2)*pcData: Store data returned.
 *                    3)length:  Reading length.
 *======================================================================
 */
static void codecReadNValue(u8 cno, u8 addr, u8 *pcData, u8 length) //(int codecNo,char addr,unsigned char *pcData,char length) 
{
#if 0
    unsigned char dummy,value;
	int i;

	if(pcData == NULL)
	{
		return;
    }

    for(i=0; i<length; i++)	
	{
		*((char*)pcData + i) = 0;
	}
   
	codecEndofCommand(codecNo);		// CS High
	codecStartofCommand(codecNo);   // CS Low
	codecSetSPIWrite();				// Enable SPI writing function
	SPIsendData(&addr,1); 
	codecEndofCommand(codecNo);		// CS High

	for(i=0; i<length; i++)
	{
		codecStartofCommand(codecNo);	// CS Low
		codecSetSPIRead();				// Enable SPI reading function
		SPIrecvData(&dummy,1); 
		codecEndofCommand(codecNo);		// CS High 
		SPIrecvData(&value,1); 
		*((char*)pcData + i) = value;
		codecEndofCommand(codecNo);		// CS High
	}
	
    return;
    u8 dummy,value;
	s8 i;
    u8 cs_no = 1;

    spi_select_cs(cs_no, SPI_CS_LOW);   // CS Low
    spi_write_enable();
    spi_put_data(addr);


    spi_select_cs(cs_no, SPI_CS_HIGH);
    spi_read_enable();
    for (i = 0; i < length; i++)
    {
        codec_delay(1);
        spi_select_cs(cs_no, SPI_CS_LOW);
        spi_get_data(&dummy);
        codec_delay(1);
        spi_select_cs(cs_no, SPI_CS_HIGH);
        spi_get_data(&value);

		*((u8 *)pcData + i) = value;
		if (value == 0xff)
		{
		    printk("\hardware ERR");;
		}
	}
#endif
    if(length == 1)
      pcData[0] = read2codec2word(cno,addr);
    else
      read2codecArray(cno,addr,pcData,length);
}

/*======================================================================
 * Function Name	: static void codecChinaALawCfg(int codecNo) 
 * Description  	: 
 *======================================================================
 */
static void codecChinaALawCfg(int codecNo)
{
    unsigned char ucAddr;
	char cData;
	int length;
	unsigned char aucTempData[100];
		
	/* R-Filter Coefficients */
	ucAddr = CODEC_REG_R_FLITER_W;
	length = sizeof(CHINA_ALAW_R_COFF);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_ALAW_R_COFF,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_R_FLITER_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

	/* Z-Filter (IIR Only) Coefficients */
	ucAddr = CODEC_REG_Z_IIR_FLITER_W;
	length = sizeof(CHINA_ALAW_Z_IIR_COFF);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_ALAW_Z_IIR_COFF,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_Z_IIR_FLITER_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

	/* Voice Path Gains */
	ucAddr = CODEC_REG_VOICE_GAIN_W;
	cData = CHINA_ALAW_VOICE_GAIN[0];  	
	codecChanWriteNValue(codecNo,ucAddr,&cData,1);

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_VOICE_GAIN_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,1);
#endif		

	/* GX (Transmit Gain) */
	ucAddr = CODEC_REG_GX_FLITER_W;
	length = sizeof(CHINA_ALAW_TX_GAIN);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_ALAW_TX_GAIN,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_GX_FLITER_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

	/* GR (Receive Gain) */
	ucAddr = CODEC_REG_GR_FLITER_W;
	length = sizeof(CHINA_ALAW_RX_GAIN);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_ALAW_RX_GAIN,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_GR_FLITER_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	
	
	/* B1-Filter (FIR Only) Coefficients */
	ucAddr = CODEC_REG_B_FIR_FLITER_W;
	length = sizeof(CHINA_ALAW_B_FIR_COFF);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_ALAW_B_FIR_COFF,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_B_FIR_FLITER_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	

	/* X-Filter Coefficients */
	ucAddr = CODEC_REG_X_FLITER_W;
	length = sizeof(CHINA_ALAW_X_COFF);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_ALAW_X_COFF,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_X_FLITER_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	
	
	/* B2-Filter (IIR Only) Coefficients */
	ucAddr = CODEC_REG_B_IIR_FLITER_W;
	length = sizeof(CHINA_ALAW_B_IIR_COFF);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_ALAW_B_IIR_COFF,length);

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_B_IIR_FLITER_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

	/* Z-Filter (FIR Only) Coefficients */
	ucAddr = CODEC_REG_Z_FIR_FILITER_W;
	length = sizeof(CHINA_ALAW_Z_FIR_COFF);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_ALAW_Z_FIR_COFF,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_Z_FIR_FILITER_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif	

	/* Digital Impedance Scaling Network */
	ucAddr = CODEC_REG_DISN_W;
	cData = CHINA_ALAW_DIMDENCE[0];  	
	length = 1;
	codecChanWriteNValue(codecNo,ucAddr,&cData,length);

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_DISN_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

	/* Operating Conditions */
	ucAddr = CODEC_REG_OPR_CONDITION_W;
	cData = CHINA_ALAW_OPCOND[0];  	
	length = 1;
	codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_OPR_CONDITION_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		

	/* Operating Functions */
	ucAddr = CODEC_REG_OPR_FUN_W;
	cData = slicHandlers.ucPcmMode;  	
	length = 1;
	codecChanWriteNValue(codecNo,ucAddr,&cData,length);	

#ifdef LEGERITY_UNIT
	ucAddr = CODEC_REG_OPR_FUN_R;
    codecReadPrint(codecNo,ucAddr,aucTempData,length);
#endif		
 }

/*======================================================================
 * Function Name	: codecChinaRing
 * Description  	: 
 *======================================================================
 */
static void codecChinaRinging(int codecNo)
{
	unsigned char ucAddr;
	char cData;
	int length;
	
	/* Signal Generator A and B Parameters: Sin/25HZ/65Vpk/no Bais */
	ucAddr = CODEC_REG_SIG_GEN_PARA;
	length = sizeof(CHINA_RING_SIGNAL_GEN);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_RING_SIGNAL_GEN,length);

	/* Cadence Timer */
	ucAddr = CODEC_REG_CANDECE_TIMER;
	length = sizeof(CHINA_RING_CADENCE);
	codecChanWriteNValue(codecNo,ucAddr,CHINA_RING_CADENCE,length);

	/* Signal Generator Control: cadencer enable */
	ucAddr = CODEC_REG_SIG_GEN_CTL;
	cData = 0x80;  		
	length = 1;
	codecChanWriteNValue(codecNo,ucAddr,&cData,length);	
}

#if 0
/*======================================================================
 * Function Name	: static void codecSetSPIWrite(void) 
 * Description  	: 
 *======================================================================
 */
 static void codecSetSPIWrite(void)
 {
 	/* Setting SPI control register */
// 	*(volatile unsigned long *)0xb9030000 = 0x5c01; // write initiate, mode 3
 }

/*======================================================================
 * Function Name	: static void codecSetSPIRead(void) 
 * Description  	: 
 *======================================================================
 */
 static void codecSetSPIRead(void)
 {
 	/* Setting SPI control register */
 //	*(volatile unsigned long *)0xb9030000 = 0x5c00; // Read initiate, mode 3
 }

/*======================================================================
 * Function Name	: codecStartofCommand  
 * Description  	: enable the chipselect for the given codec
 *                    This is required to indicate the start of the 
 *                    command for the codec.
 * Input            : codecNO: useless now.
 *======================================================================
 */
static void codecStartofCommand(int codecNo)
{
//	spi_select_cs(1, 0);	
}
      
/*======================================================================
 * Function Name	: codecEndofCommand   
 * Description  	: disable the chipselect for the given codec.
 *                    This is required to indicate the end of command
 *                    to the codec.
 * Input            : codecNO: useless now.
 *======================================================================
 */ 
static void codecEndofCommand(int codecNo)
{
//	spi_select_cs(1, 1);    
}

#endif
/*======================================================================
 * Function Name	: codecReadPrint   
 * Description  	: Read the register and print it.
 * Input            : 
 *======================================================================
 */ 
static void codecReadPrint(int codecNo,unsigned char addr,unsigned char *pcData,char length)
{
	int i;

	for(i=0; i<length; i++)
	{
		*(pcData + i) = 0;
	}	

        if(length == 0)
          read2codec2wordprintf(codecNo,addr);
        else
        	read2codecArrayPrintf(codecNo,addr,length);
}

#ifdef LEGERITY_UNIT_NOT /* UNIT TEST FUNCTIONS */

/*======================================================================
 * Function Name	: UT_CODEC_MODESETTING(int port)   
 * Description  	: Let codec ringing
 * Input            : 
 *======================================================================
 */

void UT_CODEC_MODESETTING(int iPort,int iMode)
{
	unsigned char ucAddr;
	char cData;
	if((iMode != SLIC_STANDBY) || (iMode != SLIC_ACTIVE) || (iMode != SLIC_RING) || \
       (iMode != SLIC_RINGOFF) || (iMode != SLIC_RING_LOWBSEL) || (iMode != SLIC_LOOPBACK))
	{
		printk("iMode: 0-Standby 1-Active 2-Ring\r\n");
	}	

	slicModeSetting(0,iPort,iMode); 
}

/*======================================================================
 * Function Name	: UT_CODEC_HOOKSTATUS(int iPort)   
 * Description  	: Read hook status
 * Input            : 
 *======================================================================
 */ 
void UT_CODEC_HOOKSTATUS(int iPort)
{
	unsigned char ucAddr;
	char cData[2];
	int length;

	ucAddr = CODEC_REG_READ_SIGNAL_POLL;
	length = 2;
	codecReadNValue(0,ucAddr,cData,length);
	cData[0] = cData[0] & 0x01;	/* Read channel 1 hook status */
	cData[1] = cData[1] & 0x01; /* Read channel 2 hook status */
	if(iPort == 1) 
	{
		printk("Hook Status(0: on hook - 1: on hook): %d\r\n",cData[0]);
	}

	if(iPort == 2)
	{
		printk("Hook Status(0: on hook - 1: on hook): %d\r\n",cData[1]);	
	}	
}

/*======================================================================
 * Function Name	: UT_CODEC_READ_REG(unsigned char ucAddr)   
 * Description  	: Read the value of register
 * Input            : 
 *======================================================================
 */ 
 void UT_CODEC_READ_REG(unsigned char ucAddr,int length)
 {
 	unsigned char ucChar;

	codecReadPrint(0,ucAddr,&ucChar,length);
 }     

#endif

