
#include "include/si3216.h"
#include "include/belgium_const.h"

const ringStruct belgiumRingTable;
const toneCadenceTables belgiumToneCadenceTables [BE_TONE_END][BE_MAX_NUM_CADENCE];

/*
The following Array contains BELGIUM Ring Parmeters
*/
const ringStruct  belgiumRingTable = {
   	// TYPE_BELGIUM
	BE_RING_OSC_FREQ_50HZ_IR7,
	BE_RING_OSC_AMP_50HZ_IR8,
	BE_RING_OSC_INITPHASE_50HZ_IR9,
	BE_RING_ON_1S5_LSB_DR48,
	BE_RING_ON_1S5_MSB_DR49,
	BE_RING_OFF_3S5_LSB_DR50,
	BE_RING_OFF_3S5_MSB_DR51,
	BE_RING_TRIP_THRESH_50HZ_IR16,
	BE_RING_TRIP_FILTER_50HZ_IR23,
	BE_RT_DEBOUNCE_50HZ_DR70
	
};

/*
The following Array contains BELGIUM Tones Parmeters
*/
const toneCadenceTables  belgiumToneCadenceTables [BE_TONE_END][BE_MAX_NUM_CADENCE] =
{
	{ // BE_NULL_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // BE_DIAL_TONE = BE_VOIP_DIAL_TONE
		{
		0, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 440Hz -8.5dBm0 Continuous 
				BE_DIAL_IR0,
				BE_DIAL_IR1,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // BE_ROUTING_TONE <=> CALL_IN_PROGRESS
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 425Hz -10,5dBm0 50ms On 50ms Off
				BE_ROUTING_TONE_C0_IR0,
				BE_ROUTING_TONE_C0_IR1,
				0x00,
				BE_ROUTING_TONE_C0_DR36,
				BE_ROUTING_TONE_C0_DR37,
				BE_ROUTING_TONE_C0_DR38,
				BE_ROUTING_TONE_C0_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_RING_BACK_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 440Hz -8dBm0 1.5s On 3.5s Off
				BE_RINGBACK_IR0,
				BE_RINGBACK_IR1,
				0x00,
				BE_RINGBACK_DR36,
				BE_RINGBACK_DR37,
				BE_RINGBACK_DR38,
				BE_RINGBACK_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_BUSY_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 440Hz -8dBm0 0.5s On 0.5s Off
				BE_BUSY_IR0,
				BE_BUSY_IR1,
				0x00,
				BE_BUSY_DR36,
				BE_BUSY_DR37,
				BE_BUSY_DR38,
				BE_BUSY_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BELGIUM_MSG_WAITING_TONE = BE_VOIP_MWI_TONE
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C0_IR0,
				BE_MSG_WAITING_C0_IR1,
				0x00,
				BE_MSG_WAITING_C0_DR40,
				BE_MSG_WAITING_C0_DR41,
				BE_MSG_WAITING_C0_DR42,
				BE_MSG_WAITING_C0_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		2, // Next Cadence 2 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C1_IR0,
				BE_MSG_WAITING_C1_IR1,
				0x00,
				BE_MSG_WAITING_C1_DR40,
				BE_MSG_WAITING_C1_DR41,
				BE_MSG_WAITING_C1_DR42,
				BE_MSG_WAITING_C1_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		3, // Next Cadence 3 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C1_IR0,
				BE_MSG_WAITING_C1_IR1,
				0x00,
				BE_MSG_WAITING_C1_DR40,
				BE_MSG_WAITING_C1_DR41,
				BE_MSG_WAITING_C1_DR42,
				BE_MSG_WAITING_C1_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		4, // Next Cadence 4 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C1_IR0,
				BE_MSG_WAITING_C1_IR1,
				0x00,
				BE_MSG_WAITING_C1_DR40,
				BE_MSG_WAITING_C1_DR41,
				BE_MSG_WAITING_C1_DR42,
				BE_MSG_WAITING_C1_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		0, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C1_IR0,
				BE_MSG_WAITING_C1_IR1,
				0x00,
				BE_MSG_WAITING_C1_DR40,
				BE_MSG_WAITING_C1_DR41,
				BE_MSG_WAITING_C1_DR42,
				BE_MSG_WAITING_C1_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_CALL_WAITING_TONE
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 440Hz -8dBm0 0.3s On 8s Off
				BE_CALL_WAIT_C0_IR0,
				BE_CALL_WAIT_C0_IR1,
				0x00,
				BE_CALL_WAIT_C0_DR36,
				BE_CALL_WAIT_C0_DR37,
				BE_CALL_WAIT_C0_DR38,
				BE_CALL_WAIT_C0_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		0, // Next Cadence 0 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 2s Off
				BE_CALL_WAIT_C1_IR0,
				BE_CALL_WAIT_C1_IR1,
				0x00,
				BE_CALL_WAIT_C1_DR36,
				BE_CALL_WAIT_C1_DR37,
				BE_CALL_WAIT_C1_DR38,
				BE_CALL_WAIT_C1_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},
		
	{ // BE_ALERTING_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 2130Hz -9dBm0 80ms On
				BE_ALERTING_IR0,
				BE_ALERTING_IR1,
				0x00,
				BE_ALERTING_DR36,
				BE_ALERTING_DR37,
				0x00,
				0x00
				},
				{ // OSC2 2750Hz -9dBm0 80ms On
				BE_ALERTING_IR3,
				BE_ALERTING_IR4,
				0x00,
				BE_ALERTING_DR40,
				BE_ALERTING_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_VOIP_DIAL_TONE = BE_DIAL_TONE
		{
		0, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 440Hz -8.5dBm0 Continuous 
				BE_VOIP_DIAL_C0_IR0,
				BE_VOIP_DIAL_C0_IR1,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // BE_VOIP_MWI_TONE = BELGIUM_MSG_WAITING_TONE
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C0_IR0,
				BE_MSG_WAITING_C0_IR1,
				0x00,
				BE_MSG_WAITING_C0_DR40,
				BE_MSG_WAITING_C0_DR41,
				BE_MSG_WAITING_C0_DR42,
				BE_MSG_WAITING_C0_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		2, // Next Cadence 2 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C1_IR0,
				BE_MSG_WAITING_C1_IR1,
				0x00,
				BE_MSG_WAITING_C1_DR40,
				BE_MSG_WAITING_C1_DR41,
				BE_MSG_WAITING_C1_DR42,
				BE_MSG_WAITING_C1_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		3, // Next Cadence 3 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C1_IR0,
				BE_MSG_WAITING_C1_IR1,
				0x00,
				BE_MSG_WAITING_C1_DR40,
				BE_MSG_WAITING_C1_DR41,
				BE_MSG_WAITING_C1_DR42,
				BE_MSG_WAITING_C1_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		4, // Next Cadence 4 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C1_IR0,
				BE_MSG_WAITING_C1_IR1,
				0x00,
				BE_MSG_WAITING_C1_DR40,
				BE_MSG_WAITING_C1_DR41,
				BE_MSG_WAITING_C1_DR42,
				BE_MSG_WAITING_C1_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		0, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{
				BE_MSG_WAITING_C1_IR0,
				BE_MSG_WAITING_C1_IR1,
				0x00,
				BE_MSG_WAITING_C1_DR40,
				BE_MSG_WAITING_C1_DR41,
				BE_MSG_WAITING_C1_DR42,
				BE_MSG_WAITING_C1_DR43
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

#if 0
//Si TONA differente entre mode PSTN et mode VoIP ce qui est le cas chez Belgacom. POur Mobistar on prend la meme tone en tre PSTN et VoIP

	{ // BE_VOIP_DIAL_TONE
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 440Hz -8.5dBm0 500ms On 20ms Off
				BE_VOIP_DIAL_C0_IR0,
				BE_VOIP_DIAL_C0_IR1,
				0x00,
				BE_VOIP_DIAL_C0_DR36,
				BE_VOIP_DIAL_C0_DR37,
				BE_VOIP_DIAL_C0_DR38,
				BE_VOIP_DIAL_C0_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		2, // Next Cadence 2 Osc1
		0, // No Next Cadence Osc2
			{
				{// OSC1 1000Hz -8.5dBm0 250ms On 20ms Off
				BE_VOIP_DIAL_C1_IR0,
				BE_VOIP_DIAL_C1_IR1,
				0x00,
				BE_VOIP_DIAL_C1_DR36,
				BE_VOIP_DIAL_C1_DR37,
				BE_VOIP_DIAL_C1_DR38,
				BE_VOIP_DIAL_C1_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		3, // Next Cadence 3 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 740Hz -8.5dBm0 250ms On 20ms Off
				BE_VOIP_DIAL_C2_IR0,
				BE_VOIP_DIAL_C2_IR1,
				0x00,
				BE_VOIP_DIAL_C2_DR36,
				BE_VOIP_DIAL_C2_DR37,
				BE_VOIP_DIAL_C2_DR38,
				BE_VOIP_DIAL_C2_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 440Hz -8.5dBm0 2s On 20ms Off
				BE_VOIP_DIAL_C3_IR0,
				BE_VOIP_DIAL_C3_IR1,
				0x00,
				BE_VOIP_DIAL_C3_DR36,
				BE_VOIP_DIAL_C3_DR37,
				BE_VOIP_DIAL_C3_DR38,
				BE_VOIP_DIAL_C3_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // BE_VOIP_MWI_TONE 
		{
		1, // Next Cadence 1 Osc1
		1, // Next Cadence 1 Osc2
			{
				{ // OSC1 440Hz -8.5dBm0 550ms On 20ms Off
				BE_VOIP_MWI_C0_IR0,
				BE_VOIP_MWI_C0_IR1,
				0x00,
				BE_VOIP_MWI_C0_DR36,
				BE_VOIP_MWI_C0_DR37,
				BE_VOIP_MWI_C0_DR38,
				BE_VOIP_MWI_C0_DR39
				},
				{ // OSC2 330Hz -5dBm0 50ms On 150ms Off
				BE_VOIP_MWI_C0_IR3,
				BE_VOIP_MWI_C0_IR4,
				0x00,
				BE_VOIP_MWI_C0_DR40,
				BE_VOIP_MWI_C0_DR41,
				BE_VOIP_MWI_C0_DR42,
				BE_VOIP_MWI_C0_DR43
				},
			},
		},
		{
		2, // Next Cadence 2 Osc1
		2, // Next Cadence 2 Osc2
			{
				{ // OSC1 1000Hz -8.5dBm0 250ms On 20ms Off
				BE_VOIP_MWI_C1_IR0,
				BE_VOIP_MWI_C1_IR1,
				0x00,
				BE_VOIP_MWI_C1_DR36,
				BE_VOIP_MWI_C1_DR37,
				BE_VOIP_MWI_C1_DR38,
				BE_VOIP_MWI_C1_DR39
				},
				{ // OSC2 330Hz -5dBm0 50ms On 860ms Off
				BE_VOIP_MWI_C1_IR3,
				BE_VOIP_MWI_C1_IR4,
				0x00,
				BE_VOIP_MWI_C1_DR40,
				BE_VOIP_MWI_C1_DR41,
				BE_VOIP_MWI_C1_DR42,
				BE_VOIP_MWI_C1_DR43
				},
			},
		},
		{
		3, // Next Cadence 3 Osc1
		3, // Next Cadence 3 Osc2
			{
				{ // OSC1 740Hz -8.5dBm0 250ms On 20ms Off
				BE_VOIP_MWI_C2_IR0,
				BE_VOIP_MWI_C2_IR1,
				0x00,
				BE_VOIP_MWI_C2_DR36,
				BE_VOIP_MWI_C2_DR37,
				BE_VOIP_MWI_C2_DR38,
				BE_VOIP_MWI_C2_DR39
				},
				{ // OSC2 330Hz -5dBm0 50ms On 150ms Off
				BE_VOIP_MWI_C2_IR3,
				BE_VOIP_MWI_C2_IR4,
				0x00,
				BE_VOIP_MWI_C2_DR40,
				BE_VOIP_MWI_C2_DR41,
				BE_VOIP_MWI_C2_DR42,
				BE_VOIP_MWI_C2_DR43
				},
			},
		},
		{
		1, // Next Cadence 1 Osc1
		4, // Next Cadence 4 Osc2
			{
				{ // OSC1 440Hz -8.5dBm0 1650ms On 20ms Off
				BE_VOIP_MWI_C3_IR0,
				BE_VOIP_MWI_C3_IR1,
				0x00,
				BE_VOIP_MWI_C3_DR36,
				BE_VOIP_MWI_C3_DR37,
				BE_VOIP_MWI_C3_DR38,
				BE_VOIP_MWI_C3_DR39
				},
				{ // OSC2 330Hz -5dBm0 50ms On 300ms Off
				BE_VOIP_MWI_C3_IR3,
				BE_VOIP_MWI_C3_IR4,
				0x00,
				BE_VOIP_MWI_C3_DR40,
				BE_VOIP_MWI_C3_DR41,
				BE_VOIP_MWI_C3_DR42,
				BE_VOIP_MWI_C3_DR43
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		5, // Next Cadence 5 Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 330Hz -5dBm0 50ms On 150ms Off
				BE_VOIP_MWI_C4_IR3,
				BE_VOIP_MWI_C4_IR4,
				0x00,
				BE_VOIP_MWI_C4_DR40,
				BE_VOIP_MWI_C4_DR41,
				BE_VOIP_MWI_C4_DR42,
				BE_VOIP_MWI_C4_DR43
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		6, // Next Cadence 6 Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 330Hz -5dBm0 50ms On 300ms Off
				BE_VOIP_MWI_C5_IR3,
				BE_VOIP_MWI_C5_IR4,
				0x00,
				BE_VOIP_MWI_C5_DR40,
				BE_VOIP_MWI_C5_DR41,
				BE_VOIP_MWI_C5_DR42,
				BE_VOIP_MWI_C5_DR43
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		7, // Next Cadence 7 Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 330Hz -5dBm0 50ms On 150ms Off
				BE_VOIP_MWI_C6_IR3,
				BE_VOIP_MWI_C6_IR4,
				0x00,
				BE_VOIP_MWI_C6_DR40,
				BE_VOIP_MWI_C6_DR41,
				BE_VOIP_MWI_C6_DR42,
				BE_VOIP_MWI_C6_DR43
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		2, // Next Cadence 2 Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 330Hz -5dBm0 50ms On 860ms Off
				BE_VOIP_MWI_C7_IR3,
				BE_VOIP_MWI_C7_IR4,
				0x00,
				BE_VOIP_MWI_C7_DR40,
				BE_VOIP_MWI_C7_DR41,
				BE_VOIP_MWI_C7_DR42,
				BE_VOIP_MWI_C7_DR43
				},
			},
		},
	},
#endif
   
// DTMF Tones

	{ // BE_DTMF_DIG_0_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -9dBm0 80ms On
				BE_FREQ_941Hz,
				BE_F941Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1336Hz,
				BE_F1336Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_1_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -9dBm0 80ms On
				BE_FREQ_697Hz,
				BE_F697Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1209Hz,
				BE_F1209Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_2_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -9dBm0 80ms On
				BE_FREQ_697Hz,
				BE_F697Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1336Hz,
				BE_F1336Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_3_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -9dBm0 80ms On
				BE_FREQ_697Hz,
				BE_F697Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1477Hz,
				BE_F1477Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_4_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -9dBm0 80ms On
				BE_FREQ_770Hz,
				BE_F770Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1209Hz,
				BE_F1209Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_5_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -9dBm0 80ms On
				BE_FREQ_770Hz,
				BE_F770Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1336Hz,
				BE_F1336Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_6_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -9dBm0 80ms On
				BE_FREQ_770Hz,
				BE_F770Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1477Hz,
				BE_F1477Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_7_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -9dBm0 80ms On
				BE_FREQ_852Hz,
				BE_F852Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1209Hz,
				BE_F1209Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_8_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -9dBm0 80ms On
				BE_FREQ_852Hz,
				BE_F852Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1336Hz,
				BE_F1336Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_9_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -9dBm0 80ms On
				BE_FREQ_852Hz,
				BE_F852Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1477Hz,
				BE_F1477Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_A_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -9dBm0 80ms On
				BE_FREQ_697Hz,
				BE_F697Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1633Hz,
				BE_F1633Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_B_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -9dBm0 80ms On
				BE_FREQ_770Hz,
				BE_F770Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1633Hz,
				BE_F1633Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_C_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -9dBm0 80ms On
				BE_FREQ_852Hz,
				BE_F852Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1633Hz,
				BE_F1633Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_D_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -9dBm0 80ms On
				BE_FREQ_941Hz,
				BE_F941Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1633Hz,
				BE_F1633Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_STAR_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -9dBm0 80ms On
				BE_FREQ_941Hz,
				BE_F941Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1209Hz,
				BE_F1209Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // BE_DTMF_DIG_HASH_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -9dBm0 80ms On
				BE_FREQ_941Hz,
				BE_F941Hz_AMP_M11dBm0,
				0x00,
				BE_DTMF_on_80ms_DR36,
				BE_DTMF_on_80ms_DR37,
				0x00,
				0x00
				},
				{
				BE_FREQ_1477Hz,
				BE_F1477Hz_AMP_M9dBm0,
				0x00,
				BE_DTMF_on_80ms_DR40,
				BE_DTMF_on_80ms_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	
};

