/******************************************************************************
*
*   Copyright (C) 2002 Analog Devices India (P) Ltd. All rights are reserved.
*
*   The information and source code contained herein is the exclusive
*   property of Analog Devices India (P) Ltd. and may not be disclosed,
*   examined or reproduced in whole or in part without explicit written
*   authorization from the compnay.
*
******************************************************************************/

#ifndef __FRANCE_CONF_H
#define __FRANCE_CONF_H

//****************************************************************************
//		Plan de transmission du FXS FRANCE : CPLX +2.5dBIn/-6.5dBout
//****************************************************************************
// SAGEM CFe : changement du plan de transmission du FXS : +2.5dBIn/-6.5dBout (au lieu de +3dBIn/-7dBout) 
// attnuation FXS totale en transmission de 2,5 dB avec les attnuations de 3.5 dB d'ATX, de 1.63 dB du mode linaire et gain ADCG de 2.63dB
// attnuation FXS totale en rception de 6,5 dB avec les attnuations de 3.5 dB d'ARX, de 0.15 dB intrinsque et 2.85dB de DACG 

// Transmit Path Digital To Analog Converter Gain/Attenuation = +2.63dB.
#define FR_XMIT_DIGITAL_GAIN_CPLX_IR14 		0x56A2
// Receive Path Digital To Analog Converter Gain/Attenuation = -2.85dB.
#define FR_RECV_DIGITAL_GAIN_CPLX_IR13 		0x2E19


//****************************************************************************
//		FRANCE Ring specifications : Ring 50Hz 35V 1.5s On 3.5s Off
//****************************************************************************
// Ringing Active Timer = 125uS * 0x2EE0 = 1.5S
#define FR_RING_ON_1S5_LSB_DR48 			0xE0
#define FR_RING_ON_1S5_MSB_DR49 			0x2E
// Ringing Inactive Timer = 125uS * 0x6D60 = 3.5S
#define FR_RING_OFF_3S5_LSB_DR50 			0x60
#define FR_RING_OFF_3S5_MSB_DR51 			0x6D

// Ring Oscillator Frequency Coefficient for 50Hz.
#define FR_RING_OSC_FREQ_50HZ_IR7 			0x79BC
// Ring Oscillator Amplitude Register for 50Hz and 35V.
#define FR_RING_OSC_AMP_50HZ_IR8 			0x030C
// Ring Oscillator Initial Phase Register for 50Hz and 35V.
#define FR_RING_OSC_INITPHASE_50HZ_IR9 		0x0000
// Data sheet SI3216.
#define FR_RING_TRIP_THRESH_50HZ_IR16 		0x3600
#define FR_RING_TRIP_FILTER_50HZ_IR23 		0x06A8
// Ring Trip Detect Debounce Interval = 1.25mS * 0x05 = 6,25mS.
#define FR_RT_DEBOUNCE_50HZ_DR70 			0x05


//****************************************************************************
//		FRANCE Tones specifications
//****************************************************************************
#define FR_FREQ_330Hz 				0x7EED
#define FR_F330Hz_AMP_M5dBm0 			0x00D1

#define FR_FREQ_440Hz 				0x7E18
#define FR_F440Hz_AMP_M3dBm05 		0x014B
#define FR_F440Hz_AMP_M8dBm0 			0x00C5
#define FR_F440Hz_AMP_M8dBm05 		0x00BA

#define FR_FREQ_2130Hz 				0x55C6
#define FR_F2130Hz_AMP_M9dBm0 		0x0386

#define FR_FREQ_2750Hz 				0x3C57
#define FR_F2750Hz_AMP_M9dBm0 		0x04C0


// OSC1	440Hz -3.5dBm0 Continuous
#define	FR_DIAL_IR0 				FR_FREQ_440Hz
#define	FR_DIAL_IR1 				FR_F440Hz_AMP_M3dBm05

// OSC1	440Hz -8dBm0 1.5s On 3.5s Off
#define	FR_RINGBACK_IR0 			FR_FREQ_440Hz
#define	FR_RINGBACK_IR1 			FR_F440Hz_AMP_M8dBm0
#define	FR_RINGBACK_DR36 			0xE0
#define	FR_RINGBACK_DR37 			0x2E
#define	FR_RINGBACK_DR38 			0X60
#define	FR_RINGBACK_DR39 			0X6D

// OSC1	440Hz -8dBm0 0.5s On 0.5s Off
#define	FR_BUSY_IR0 				FR_FREQ_440Hz
#define	FR_BUSY_IR1 				FR_F440Hz_AMP_M8dBm0
#define	FR_BUSY_DR36 				0xA0
#define	FR_BUSY_DR37 				0x0F
#define	FR_BUSY_DR38 				0xA0
#define	FR_BUSY_DR39 				0x0F

// OSC1	440Hz -8.5dBm0 Continuous
#define	FR_MSG_WAITING_IR0 			FR_FREQ_440Hz
#define	FR_MSG_WAITING_IR1 			FR_F440Hz_AMP_M8dBm05
// OSC2	330Hz -5dBm0 50ms On 150ms Off
#define	FR_MSG_WAITING_C0_IR3 		FR_FREQ_330Hz
#define	FR_MSG_WAITING_C0_IR4 		FR_F330Hz_AMP_M5dBm0
#define	FR_MSG_WAITING_C0_DR40 		0x90
#define	FR_MSG_WAITING_C0_DR41 		0x01
#define	FR_MSG_WAITING_C0_DR42 		0xB0
#define	FR_MSG_WAITING_C0_DR43 		0x04
// OSC2	330Hz -5dBm0 50ms On 300ms Off
#define	FR_MSG_WAITING_C1_IR3 		FR_FREQ_330Hz
#define	FR_MSG_WAITING_C1_IR4 		FR_F330Hz_AMP_M5dBm0
#define	FR_MSG_WAITING_C1_DR40 		0x90
#define	FR_MSG_WAITING_C1_DR41 		0x01
#define	FR_MSG_WAITING_C1_DR42 		0x60
#define	FR_MSG_WAITING_C1_DR43 		0x09

// OSC1	440Hz -8dBm0 0.3s On 8s Off
#define	FR_CALL_WAIT_C0_IR0 		FR_FREQ_440Hz
#define	FR_CALL_WAIT_C0_IR1 		FR_F440Hz_AMP_M8dBm0
#define	FR_CALL_WAIT_C0_DR36 		0x60	
#define	FR_CALL_WAIT_C0_DR37 		0x09
#define	FR_CALL_WAIT_C0_DR38 		0x00
#define	FR_CALL_WAIT_C0_DR39 		0xFA
// OSC1 2s Off
#define	FR_CALL_WAIT_C1_IR0 		0x00
#define	FR_CALL_WAIT_C1_IR1 		0x00
#define	FR_CALL_WAIT_C1_DR36 		0x00	
#define	FR_CALL_WAIT_C1_DR37 		0x00
#define	FR_CALL_WAIT_C1_DR38 		0x80
#define	FR_CALL_WAIT_C1_DR39 		0x3E

// OSC1	2130Hz -9dBm0 80ms On
#define	FR_ALERTING_IR0 			FR_FREQ_2130Hz
#define	FR_ALERTING_IR1 			FR_F2130Hz_AMP_M9dBm0
#define	FR_ALERTING_DR36 			0x80
#define	FR_ALERTING_DR37 			0x02
#define	FR_ALERTING_DR38 			0x00
#define	FR_ALERTING_DR39 			0x00
// OSC2	2750Hz -9dBm0 80ms On
#define	FR_ALERTING_IR3 			FR_FREQ_2750Hz
#define	FR_ALERTING_IR4 			FR_F2750Hz_AMP_M9dBm0
#define	FR_ALERTING_DR40 			0x80
#define	FR_ALERTING_DR41 			0x02
#define	FR_ALERTING_DR42 			0x00
#define	FR_ALERTING_DR43 			0x00

// OSC1	440Hz -8.5dBm0 500ms On 20ms Off
#define	FR_VOIP_DIAL_C0_IR0 		FR_FREQ_440Hz
#define	FR_VOIP_DIAL_C0_IR1 		FR_F440Hz_AMP_M8dBm05
#define	FR_VOIP_DIAL_C0_DR36 		0xA0
#define	FR_VOIP_DIAL_C0_DR37 		0x0F
#define	FR_VOIP_DIAL_C0_DR38 		0xA0
#define	FR_VOIP_DIAL_C0_DR39 		0x00
// OSC1	1000Hz -8.5dBm0 250ms On 20ms Off
// OSC1	1000Hz -17dBm0 250ms On 20ms Off : reduction du niveau de la frequence 1000Hz pour ameliorer
// la detection du premier digit DTMF en presence de la tonalite 1000Hz
#define	FR_VOIP_DIAL_C1_IR0 		0x7642
#define	FR_VOIP_DIAL_C1_IR1 		0x00A0 // 0x01AC -> -8.5dBm0
#define	FR_VOIP_DIAL_C1_DR36 		0xD0
#define	FR_VOIP_DIAL_C1_DR37 		0x07
#define	FR_VOIP_DIAL_C1_DR38 		0xA0
#define	FR_VOIP_DIAL_C1_DR39 		0x00
// OSC1	740Hz -8.5dBm0 250ms On 20ms Off
// OSC1	740Hz -17dBm0 250ms On 20ms Off : reduction du niveau de la frequence 740Hz pour ameliorer
// la detection du premier digit DTMF en presence de la tonalite 740Hz
#define	FR_VOIP_DIAL_C2_IR0 		0x7AA2
#define	FR_VOIP_DIAL_C2_IR1 		0x0076 // 0x013B -> -8.5dBm0
#define	FR_VOIP_DIAL_C2_DR36 		0xD0
#define	FR_VOIP_DIAL_C2_DR37 		0x07
#define	FR_VOIP_DIAL_C2_DR38 		0xA0
#define	FR_VOIP_DIAL_C2_DR39 		0x00
// OSC1	440Hz -8.5dBm0 2s On 20ms Off
#define	FR_VOIP_DIAL_C3_IR0 		FR_FREQ_440Hz
#define	FR_VOIP_DIAL_C3_IR1 		FR_F440Hz_AMP_M8dBm05
#define	FR_VOIP_DIAL_C3_DR36 		0x80
#define	FR_VOIP_DIAL_C3_DR37 		0x3E
#define	FR_VOIP_DIAL_C3_DR38 		0xA0
#define	FR_VOIP_DIAL_C3_DR39 		0x00

// OSC1	440Hz -8.5dBm0 550ms On 20ms Off
#define	FR_VOIP_MWI_C0_IR0 			FR_FREQ_440Hz
#define	FR_VOIP_MWI_C0_IR1 			FR_F440Hz_AMP_M8dBm05
#define	FR_VOIP_MWI_C0_DR36 		0x30
#define	FR_VOIP_MWI_C0_DR37 		0x11
#define	FR_VOIP_MWI_C0_DR38 		0xA0
#define	FR_VOIP_MWI_C0_DR39 		0x00
// OSC1	1000Hz -8.5dBm0 250ms On 20ms Off
// OSC1	1000Hz -17dBm0 250ms On 20ms Off : reduction du niveau de la frequence 1000Hz pour ameliorer
// la detection du premier digit DTMF en presence de la tonalite 1000Hz
#define	FR_VOIP_MWI_C1_IR0 			0x7642
#define	FR_VOIP_MWI_C1_IR1 			0x00A0 // 0x01AC -> -8.5dBm0
#define	FR_VOIP_MWI_C1_DR36 		0xD0
#define	FR_VOIP_MWI_C1_DR37 		0x07
#define	FR_VOIP_MWI_C1_DR38 		0xA0
#define	FR_VOIP_MWI_C1_DR39 		0x00
// OSC1	740Hz -8.5dBm0 250ms On 20ms Off
// OSC1	740Hz -17dBm0 250ms On 20ms Off : reduction du niveau de la frequence 740Hz pour ameliorer
// la detection du premier digit DTMF en presence de la tonalite 740Hz
#define	FR_VOIP_MWI_C2_IR0 			0x7AA2
#define	FR_VOIP_MWI_C2_IR1 			0x0076 // 0x013B -> -8.5dBm0
#define	FR_VOIP_MWI_C2_DR36 		0xD0
#define	FR_VOIP_MWI_C2_DR37 		0x07
#define	FR_VOIP_MWI_C2_DR38 		0xA0
#define	FR_VOIP_MWI_C2_DR39 		0x00
// OSC1	440Hz -8.5dBm0 1650ms On 20ms Off
#define	FR_VOIP_MWI_C3_IR0 			FR_FREQ_440Hz
#define	FR_VOIP_MWI_C3_IR1 			FR_F440Hz_AMP_M8dBm05
#define	FR_VOIP_MWI_C3_DR36 		0x90
#define	FR_VOIP_MWI_C3_DR37 		0x33
#define	FR_VOIP_MWI_C3_DR38 		0xA0
#define	FR_VOIP_MWI_C3_DR39 		0x00
// OSC2	330Hz -5dBm0 50ms On 150ms Off
#define	FR_VOIP_MWI_C0_IR3 			FR_FREQ_330Hz
#define	FR_VOIP_MWI_C0_IR4 			FR_F330Hz_AMP_M5dBm0
#define	FR_VOIP_MWI_C0_DR40 		0x90
#define	FR_VOIP_MWI_C0_DR41 		0x01
#define	FR_VOIP_MWI_C0_DR42 		0xB0
#define	FR_VOIP_MWI_C0_DR43 		0x04
// OSC2	330Hz -5dBm0 50ms On 860ms Off
#define	FR_VOIP_MWI_C1_IR3 			FR_FREQ_330Hz
#define	FR_VOIP_MWI_C1_IR4 			FR_F330Hz_AMP_M5dBm0
#define	FR_VOIP_MWI_C1_DR40 		0x90
#define	FR_VOIP_MWI_C1_DR41 		0x01
#define	FR_VOIP_MWI_C1_DR42 		0xE0
#define	FR_VOIP_MWI_C1_DR43 		0x1A
// OSC2	330Hz -5dBm0 50ms On 150ms Off
#define	FR_VOIP_MWI_C2_IR3 			FR_FREQ_330Hz
#define	FR_VOIP_MWI_C2_IR4 			FR_F330Hz_AMP_M5dBm0
#define	FR_VOIP_MWI_C2_DR40 		0x90
#define	FR_VOIP_MWI_C2_DR41 		0x01
#define	FR_VOIP_MWI_C2_DR42 		0xB0
#define	FR_VOIP_MWI_C2_DR43 		0x04
// OSC2	330Hz -5dBm0 50ms On 300ms Off
#define	FR_VOIP_MWI_C3_IR3 			FR_FREQ_330Hz
#define	FR_VOIP_MWI_C3_IR4 			FR_F330Hz_AMP_M5dBm0
#define	FR_VOIP_MWI_C3_DR40 		0x90
#define	FR_VOIP_MWI_C3_DR41 		0x01
#define	FR_VOIP_MWI_C3_DR42 		0x60
#define	FR_VOIP_MWI_C3_DR43 		0x09
// OSC2	330Hz -5dBm0 50ms On 150ms Off
#define	FR_VOIP_MWI_C4_IR3 			FR_FREQ_330Hz
#define	FR_VOIP_MWI_C4_IR4 			FR_F330Hz_AMP_M5dBm0
#define	FR_VOIP_MWI_C4_DR40 		0x90
#define	FR_VOIP_MWI_C4_DR41 		0x01
#define	FR_VOIP_MWI_C4_DR42 		0xB0
#define	FR_VOIP_MWI_C4_DR43 		0x04
// OSC2	330Hz -5dBm0 50ms On 300ms Off
#define	FR_VOIP_MWI_C5_IR3 			FR_FREQ_330Hz
#define	FR_VOIP_MWI_C5_IR4 			FR_F330Hz_AMP_M5dBm0
#define	FR_VOIP_MWI_C5_DR40 		0x90
#define	FR_VOIP_MWI_C5_DR41 		0x01
#define	FR_VOIP_MWI_C5_DR42 		0x60
#define	FR_VOIP_MWI_C5_DR43 		0x09
// OSC2	330Hz -5dBm0 50ms On 150ms Off
#define	FR_VOIP_MWI_C6_IR3 			FR_FREQ_330Hz
#define	FR_VOIP_MWI_C6_IR4 			FR_F330Hz_AMP_M5dBm0
#define	FR_VOIP_MWI_C6_DR40 		0x90
#define	FR_VOIP_MWI_C6_DR41 		0x01
#define	FR_VOIP_MWI_C6_DR42 		0xB0
#define	FR_VOIP_MWI_C6_DR43 		0x04
// OSC2	330Hz -5dBm0 50ms On 860ms Off
#define	FR_VOIP_MWI_C7_IR3 			FR_FREQ_330Hz
#define	FR_VOIP_MWI_C7_IR4 			FR_F330Hz_AMP_M5dBm0
#define	FR_VOIP_MWI_C7_DR40 		0x90
#define	FR_VOIP_MWI_C7_DR41 		0x01
#define	FR_VOIP_MWI_C7_DR42 		0xE0
#define	FR_VOIP_MWI_C7_DR43 		0x1A


//****************************************************************************
//		FRANCE Dtmf specifications
//****************************************************************************
#define	FR_DTMF_FREQ_697Hz 			0x7b3c 
#define	FR_DTMF_F697Hz_AMP_M11dBm0 	0xdd

#define	FR_DTMF_FREQ_770Hz 			0x7a31 
#define	FR_DTMF_F770Hz_AMP_M11dBm0 	0xf5

#define	FR_DTMF_FREQ_852Hz 			0x78e6 
#define	FR_DTMF_F852Hz_AMP_M11dBm0 	0x110

#define	FR_DTMF_FREQ_941Hz 			0x775c 
#define	FR_DTMF_F941Hz_AMP_M11dBm0 	0x12d

#define	FR_DTMF_FREQ_1209Hz 		0x71d7 
#define	FR_DTMF_F1209Hz_AMP_M9dBm0 	0x1ea

#define	FR_DTMF_FREQ_1336Hz 		0x6ec8 
#define	FR_DTMF_F1336Hz_AMP_M9dBm0 	0x220

#define	FR_DTMF_FREQ_1477Hz 		0x6b10 
#define	FR_DTMF_F1477Hz_AMP_M9dBm0 	0x25d

#define	FR_DTMF_FREQ_1633Hz 		0x6692 
#define	FR_DTMF_F1633Hz_AMP_M9dBm0 	0x2a1

// OSC1	80ms On
#define	FR_DTMF_DR36 				0x80
#define	FR_DTMF_DR37 				0x02
// OSC2	80ms On
#define	FR_DTMF_DR40 				0x80
#define	FR_DTMF_DR41 				0x02

typedef enum
{
	FR_NULL_TONE 					= 0,
	FR_DIAL_TONE 					= 1,
	FR_NULL_CALL_IN_PROGRESS 		= 2,
	FR_RING_BACK_TONE 				= 3,
	FR_BUSY_TONE 					= 4,
	FR_MSG_WAITING_TONE 			= 5,
	FR_CALL_WAITING_TONE 			= 6,
	FR_ALERTING_TONE 				= 7,                                                                                
	FR_VOIP_DIAL_TONE 				= 8,
	FR_VOIP_MWI_TONE 				= 9,
	FR_DTMF_DIG_0_TONE_LOCAL 		= 10,
	FR_DTMF_DIG_1_TONE_LOCAL 		= 11,
	FR_DTMF_DIG_2_TONE_LOCAL 		= 12,
	FR_DTMF_DIG_3_TONE_LOCAL 		= 13,
	FR_DTMF_DIG_4_TONE_LOCAL 		= 14,
	FR_DTMF_DIG_5_TONE_LOCAL 		= 15,
	FR_DTMF_DIG_6_TONE_LOCAL 		= 16,
	FR_DTMF_DIG_7_TONE_LOCAL 		= 17,
	FR_DTMF_DIG_8_TONE_LOCAL 		= 18,
	FR_DTMF_DIG_9_TONE_LOCAL 		= 19,
	FR_DTMF_DIG_A_TONE_LOCAL 		= 20,
	FR_DTMF_DIG_B_TONE_LOCAL 		= 21,
	FR_DTMF_DIG_C_TONE_LOCAL 		= 22,
	FR_DTMF_DIG_D_TONE_LOCAL 		= 23,
	FR_DTMF_DIG_STAR_TONE_LOCAL 		= 24,
	FR_DTMF_DIG_HASH_TONE_LOCAL 		= 25,
	FR_TONE_END 					= 26
} enumFranceTone;

#define	FR_MAX_NUM_CADENCE 			8


extern const ringStruct franceRingTable;
extern const toneCadenceTables franceToneCadenceTables [FR_TONE_END][FR_MAX_NUM_CADENCE];

#endif
