
#include "include/si3216.h"
#include "include/netherlands_const.h"

const ringStruct netherlandsRingTable;
const toneCadenceTables netherlandsToneCadenceTables [NL_TONE_END][NL_MAX_NUM_CADENCE];

/*
The following Array contains NETHERLANDS Ring Parmeters
*/
const ringStruct  netherlandsRingTable = {
	// TYPE_NETHERLANDS : Ring 25Hz 35V 1s On 4s Off
	NL_RING_OSC_FREQ_25HZ_IR7,
	NL_RING_OSC_AMP_25HZ_IR8,
	NL_RING_OSC_INITPHASE_25HZ_IR9, 
	NL_RING_ON_1S_LSB_DR48,
	NL_RING_ON_1S_MSB_DR49,
	NL_RING_OFF_4S_LSB_DR50,
	NL_RING_OFF_4S_MSB_DR51,
	NL_RING_TRIP_THRESH_25HZ_IR16,
	NL_RING_TRIP_FILTER_25HZ_IR23,
	NL_RT_DEBOUNCE_25HZ_DR70
};
                     
/*
The following Array contains NETHERLANDS Tones Parmeters
*/
const toneCadenceTables  netherlandsToneCadenceTables [NL_TONE_END][NL_MAX_NUM_CADENCE] =
{
	{ // NL_NULL_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_DIAL_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 425Hz -11.5dBm0 Continuous
				NL_DIAL_IR0,
				NL_DIAL_IR1,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_NULL_CALL_IN_PROGRESS
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_RING_BACK_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 425Hz -6dBm0 1s On 4s Off
				NL_RINGBACK_IR0,
				NL_RINGBACK_IR1,
				0x00,
				NL_RINGBACK_DR36,
				NL_RINGBACK_DR37,
				NL_RINGBACK_DR38,
				NL_RINGBACK_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_BUSY_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 425Hz -6dBm0 0.5s On 0.5s Off
				NL_BUSY_IR0,
				NL_BUSY_IR1,
				0x00,
				NL_BUSY_DR36,
				NL_BUSY_DR37,
				NL_BUSY_DR38,
				NL_BUSY_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_NULL_MSG_WAITING_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_CALL_WAITING_TONE
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -13dBm0 0.5s On 8s Off
				NL_CALL_WAIT_C0_IR0,
				NL_CALL_WAIT_C0_IR1,
				0x00,
				NL_CALL_WAIT_C0_DR36,
				NL_CALL_WAIT_C0_DR37,
				NL_CALL_WAIT_C0_DR38,
				NL_CALL_WAIT_C0_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		0, // Next Cadence 0 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 1.5s Off
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				NL_CALL_WAIT_C1_DR38,
				NL_CALL_WAIT_C1_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_NULL_ALERTING_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_VOIP_DIAL_TONE
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -11.5dBm0 500ms On 20ms Off
				NL_VOIP_DIAL_C0_IR0,
				NL_VOIP_DIAL_C0_IR1,
				0x00,
				NL_VOIP_DIAL_C0_DR36,
				NL_VOIP_DIAL_C0_DR37,
				NL_VOIP_DIAL_C0_DR38,
				NL_VOIP_DIAL_C0_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		2, // Next Cadence 2 Osc1
		0, // No Next Cadence Osc2
			{
				{// OSC1	1000Hz -17dBm0 250ms On 20ms Off
				NL_VOIP_DIAL_C1_IR0,
				NL_VOIP_DIAL_C1_IR1,
				0x00,
				NL_VOIP_DIAL_C1_DR36,
				NL_VOIP_DIAL_C1_DR37,
				NL_VOIP_DIAL_C1_DR38,
				NL_VOIP_DIAL_C1_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		3, // Next Cadence 3 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	740Hz -17dBm0 250ms On 20ms Off
				NL_VOIP_DIAL_C2_IR0,
				NL_VOIP_DIAL_C2_IR1,
				0x00,
				NL_VOIP_DIAL_C2_DR36,
				NL_VOIP_DIAL_C2_DR37,
				NL_VOIP_DIAL_C2_DR38,
				NL_VOIP_DIAL_C2_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -11.5dBm0 2s On 20ms Of
				NL_VOIP_DIAL_C3_IR0,
				NL_VOIP_DIAL_C3_IR1,
				0x00,
				NL_VOIP_DIAL_C3_DR36,
				NL_VOIP_DIAL_C3_DR37,
				NL_VOIP_DIAL_C3_DR38,
				NL_VOIP_DIAL_C3_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // NL_VOIP_MWI_TONE = FR_VOIP_MWI_TONE
		{
		1, // Next Cadence 1 Osc1
		1, // Next Cadence 1 Osc2
			{
				{ // OSC1 440Hz -8.5dBm0 550ms On 20ms Off
				NL_VOIP_MWI_C0_IR0,
				NL_VOIP_MWI_C0_IR1,
				0x00,
				NL_VOIP_MWI_C0_DR36,
				NL_VOIP_MWI_C0_DR37,
				NL_VOIP_MWI_C0_DR38,
				NL_VOIP_MWI_C0_DR39
				},
				{ // OSC2 330Hz -5dBm0 50ms On 150ms Off
				NL_VOIP_MWI_C0_IR3,
				NL_VOIP_MWI_C0_IR4,
				0x00,
				NL_VOIP_MWI_C0_DR40,
				NL_VOIP_MWI_C0_DR41,
				NL_VOIP_MWI_C0_DR42,
				NL_VOIP_MWI_C0_DR43
				},
			},
		},
		{
		2, // Next Cadence 2 Osc1
		2, // Next Cadence 2 Osc2
			{
				{ // OSC1 1000Hz -8.5dBm0 250ms On 20ms Off
				NL_VOIP_MWI_C1_IR0,
				NL_VOIP_MWI_C1_IR1,
				0x00,
				NL_VOIP_MWI_C1_DR36,
				NL_VOIP_MWI_C1_DR37,
				NL_VOIP_MWI_C1_DR38,
				NL_VOIP_MWI_C1_DR39
				},
				{ // OSC2 330Hz -5dBm0 50ms On 860ms Off
				NL_VOIP_MWI_C1_IR3,
				NL_VOIP_MWI_C1_IR4,
				0x00,
				NL_VOIP_MWI_C1_DR40,
				NL_VOIP_MWI_C1_DR41,
				NL_VOIP_MWI_C1_DR42,
				NL_VOIP_MWI_C1_DR43
				},
			},
		},
		{
		3, // Next Cadence 3 Osc1
		3, // Next Cadence 3 Osc2
			{
				{ // OSC1 740Hz -8.5dBm0 250ms On 20ms Off
				NL_VOIP_MWI_C2_IR0,
				NL_VOIP_MWI_C2_IR1,
				0x00,
				NL_VOIP_MWI_C2_DR36,
				NL_VOIP_MWI_C2_DR37,
				NL_VOIP_MWI_C2_DR38,
				NL_VOIP_MWI_C2_DR39
				},
				{ // OSC2 330Hz -5dBm0 50ms On 150ms Off
				NL_VOIP_MWI_C2_IR3,
				NL_VOIP_MWI_C2_IR4,
				0x00,
				NL_VOIP_MWI_C2_DR40,
				NL_VOIP_MWI_C2_DR41,
				NL_VOIP_MWI_C2_DR42,
				NL_VOIP_MWI_C2_DR43
				},
			},
		},
		{
		1, // Next Cadence 1 Osc1
		4, // Next Cadence 4 Osc2
			{
				{ // OSC1 440Hz -8.5dBm0 1650ms On 20ms Off
				NL_VOIP_MWI_C3_IR0,
				NL_VOIP_MWI_C3_IR1,
				0x00,
				NL_VOIP_MWI_C3_DR36,
				NL_VOIP_MWI_C3_DR37,
				NL_VOIP_MWI_C3_DR38,
				NL_VOIP_MWI_C3_DR39
				},
				{ // OSC2 330Hz -5dBm0 50ms On 300ms Off
				NL_VOIP_MWI_C3_IR3,
				NL_VOIP_MWI_C3_IR4,
				0x00,
				NL_VOIP_MWI_C3_DR40,
				NL_VOIP_MWI_C3_DR41,
				NL_VOIP_MWI_C3_DR42,
				NL_VOIP_MWI_C3_DR43
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		5, // Next Cadence 5 Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 330Hz -5dBm0 50ms On 150ms Off
				NL_VOIP_MWI_C4_IR3,
				NL_VOIP_MWI_C4_IR4,
				0x00,
				NL_VOIP_MWI_C4_DR40,
				NL_VOIP_MWI_C4_DR41,
				NL_VOIP_MWI_C4_DR42,
				NL_VOIP_MWI_C4_DR43
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		6, // Next Cadence 6 Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 330Hz -5dBm0 50ms On 300ms Off
				NL_VOIP_MWI_C5_IR3,
				NL_VOIP_MWI_C5_IR4,
				0x00,
				NL_VOIP_MWI_C5_DR40,
				NL_VOIP_MWI_C5_DR41,
				NL_VOIP_MWI_C5_DR42,
				NL_VOIP_MWI_C5_DR43
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		7, // Next Cadence 7 Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 330Hz -5dBm0 50ms On 150ms Off
				NL_VOIP_MWI_C6_IR3,
				NL_VOIP_MWI_C6_IR4,
				0x00,
				NL_VOIP_MWI_C6_DR40,
				NL_VOIP_MWI_C6_DR41,
				NL_VOIP_MWI_C6_DR42,
				NL_VOIP_MWI_C6_DR43
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		2, // Next Cadence 2 Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 330Hz -5dBm0 50ms On 860ms Off
				NL_VOIP_MWI_C7_IR3,
				NL_VOIP_MWI_C7_IR4,
				0x00,
				NL_VOIP_MWI_C7_DR40,
				NL_VOIP_MWI_C7_DR41,
				NL_VOIP_MWI_C7_DR42,
				NL_VOIP_MWI_C7_DR43
				},
			},
		},
	},

	{ // NL_DTMF_DIG_0_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -11dBm0 80ms On
				NL_DTMF_FREQ_941Hz,
				NL_DTMF_F941Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1336Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1336Hz,
				NL_DTMF_F1336Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_1_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz 11dBm0 80ms On
				NL_DTMF_FREQ_697Hz,
				NL_DTMF_F697Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1209Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1209Hz,
				NL_DTMF_F1209Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_2_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -11dBm0 80ms On
				NL_DTMF_FREQ_697Hz,
				NL_DTMF_F697Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1336Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1336Hz,
				NL_DTMF_F1336Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_3_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -11dBm0 80ms On
				NL_DTMF_FREQ_697Hz,
				NL_DTMF_F697Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1477Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1477Hz,
				NL_DTMF_F1477Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_4_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -11dBm0 80ms On
				NL_DTMF_FREQ_770Hz,
				NL_DTMF_F770Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1209Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1209Hz,
				NL_DTMF_F1209Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_5_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -11dBm0 80ms On
				NL_DTMF_FREQ_770Hz,
				NL_DTMF_F770Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1336Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1336Hz,
				NL_DTMF_F1336Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_6_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -11dBm0 80ms On
				NL_DTMF_FREQ_770Hz,
				NL_DTMF_F770Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1477Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1477Hz,
				NL_DTMF_F1477Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_7_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -11dBm0 80ms On
				NL_DTMF_FREQ_852Hz,
				NL_DTMF_F852Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1209Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1209Hz,
				NL_DTMF_F1209Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_8_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -11dBm0 80ms On
				NL_DTMF_FREQ_852Hz,
				NL_DTMF_F852Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1336Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1336Hz,
				NL_DTMF_F1336Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_9_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -11dBm0 80ms On
				NL_DTMF_FREQ_852Hz,
				NL_DTMF_F852Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1477Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1477Hz,
				NL_DTMF_F1477Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_A_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -11dBm0 80ms On
				NL_DTMF_FREQ_697Hz,
				NL_DTMF_F697Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1633Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1633Hz,
				NL_DTMF_F1633Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_B_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -11dBm0 80ms On
				NL_DTMF_FREQ_770Hz,
				NL_DTMF_F770Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1633Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1633Hz,
				NL_DTMF_F1633Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_C_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -11dBm0 80ms On
				NL_DTMF_FREQ_852Hz,
				NL_DTMF_F852Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1633Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1633Hz,
				NL_DTMF_F1633Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_D_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -11dBm0 80ms On
				NL_DTMF_FREQ_941Hz,
				NL_DTMF_F941Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1633Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1633Hz,
				NL_DTMF_F1633Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_STAR_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -11dBm0 80ms On
				NL_DTMF_FREQ_941Hz,
				NL_DTMF_F941Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1209Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1209Hz,
				NL_DTMF_F1209Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // NL_DTMF_DIG_HASH_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -11dBm0 80ms On
				NL_DTMF_FREQ_941Hz,
				NL_DTMF_F941Hz_AMP_M11dBm0,
				0x00,
				NL_DTMF_DR36,
				NL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1477Hz -9dBm0 80ms On
				NL_DTMF_FREQ_1477Hz,
				NL_DTMF_F1477Hz_AMP_M9dBm0,
				0x00,
				NL_DTMF_DR40,
				NL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
};


