
#include "include/si3216.h"
#include "include/poland_const.h"

const ringStruct polandRingTable;
const toneCadenceTables polandToneCadenceTables [PL_TONE_END][PL_MAX_NUM_CADENCE];

/*
The following Array contains POLAND Ring Parmeters
*/
const ringStruct  polandRingTable = {
	// TYPE_POLAND : Ring 25Hz 35V 1s On 4s Off
	PL_RING_OSC_FREQ_25HZ_IR7,
	PL_RING_OSC_AMP_25HZ_IR8,
	PL_RING_OSC_INITPHASE_25HZ_IR9, 
	PL_RING_ON_1S_LSB_DR48,
	PL_RING_ON_1S_MSB_DR49,
	PL_RING_OFF_4S_LSB_DR50,
	PL_RING_OFF_4S_MSB_DR51,
	PL_RING_TRIP_THRESH_25HZ_IR16,
	PL_RING_TRIP_FILTER_25HZ_IR23,
	PL_RT_DEBOUNCE_25HZ_DR70
};

/*
The following Array contains POLAND Tones Parmeters
*/
const toneCadenceTables  polandToneCadenceTables [PL_TONE_END][PL_MAX_NUM_CADENCE] =
{
	{ // PL_NULL_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_DIAL_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 continuous
				PL_DIAL_IR0,
				PL_DIAL_IR1,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_CALL_IN_PROGRESS
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 425Hz -6dBm0 200ms On 200ms Off
				PL_CALL_IN_PROGRESS_C0_IR0,
				PL_CALL_IN_PROGRESS_C0_IR1,
				0x00,
				PL_CALL_IN_PROGRESS_C0_DR36,
				PL_CALL_IN_PROGRESS_C0_DR37,
				PL_CALL_IN_PROGRESS_C0_DR38,
				PL_CALL_IN_PROGRESS_C0_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_RING_BACK_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 1s On 4s Off
				PL_RINGBACK_IR0,
				PL_RINGBACK_IR1,
				0x00,
				PL_RINGBACK_DR36,
				PL_RINGBACK_DR37,
				PL_RINGBACK_DR38,
				PL_RINGBACK_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_BUSY_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 425Hz -6dBm0 0.5s On 0.5s Off
				PL_BUSY_IR0,
				PL_BUSY_IR1,
				0x00,
				PL_BUSY_DR36,
				PL_BUSY_DR37,
				PL_BUSY_DR38,
				PL_BUSY_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_MSG_WAITING_TONE
		{
		1, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.2s On 0.2s Off
				PL_MSG_WAITING_C013_IR0,
				PL_MSG_WAITING_C013_IR1,
				0x00,
				PL_MSG_WAITING_C013_DR36,
				PL_MSG_WAITING_C013_DR37,
				PL_MSG_WAITING_C013_DR38,
				PL_MSG_WAITING_C013_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
			{
		2, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.2s On 0.2s Off
				PL_MSG_WAITING_C013_IR0,
				PL_MSG_WAITING_C013_IR1,
				0x00,
				PL_MSG_WAITING_C013_DR36,
				PL_MSG_WAITING_C013_DR37,
				PL_MSG_WAITING_C013_DR38,
				PL_MSG_WAITING_C013_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		3, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.4s On 0.4s Off
				PL_MSG_WAITING_C2_IR0,
				PL_MSG_WAITING_C2_IR1,
				0x00,
				PL_MSG_WAITING_C2_DR36,
				PL_MSG_WAITING_C2_DR37,
				PL_MSG_WAITING_C2_DR38,
				PL_MSG_WAITING_C2_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		4, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.2s On 0.2s Off
				PL_MSG_WAITING_C013_IR0,
				PL_MSG_WAITING_C013_IR1,
				0x00,
				PL_MSG_WAITING_C013_DR36,
				PL_MSG_WAITING_C013_DR37,
				PL_MSG_WAITING_C013_DR38,
				PL_MSG_WAITING_C013_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.2s On 0.5s Off
				PL_MSG_WAITING_C4_IR0,
				PL_MSG_WAITING_C4_IR1,
				0x00,
				PL_MSG_WAITING_C4_DR36,
				PL_MSG_WAITING_C4_DR37,
				PL_MSG_WAITING_C4_DR38,
				PL_MSG_WAITING_C4_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_CALL_WAITING_TONE
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 425Hz -6dBm0 0.150s On 0.150s Off
				PL_CALL_WAIT_C0_IR0,
				PL_CALL_WAIT_C0_IR1,
				0x00,
				PL_CALL_WAIT_C0_DR36,
				PL_CALL_WAIT_C0_DR37,
				PL_CALL_WAIT_C0_DR38,
				PL_CALL_WAIT_C0_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		0, // Next Cadence 0 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 425Hz -6dBm0 0.150s On 4s Off
				PL_CALL_WAIT_C1_IR0,
				PL_CALL_WAIT_C1_IR1,
				0x00,
				PL_CALL_WAIT_C1_DR36,
				PL_CALL_WAIT_C1_DR37,
				PL_CALL_WAIT_C1_DR38,
				PL_CALL_WAIT_C1_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_ALERTING_TONE
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1 2130Hz -9dBm0 80ms On
				PL_ALERTING_IR0,
				PL_ALERTING_IR1,
				0x00,
				PL_ALERTING_DR36,
				PL_ALERTING_DR37,
				0x00,
				0x00
				},
				{ // OSC2 2750Hz -9dBm0 80ms On
				PL_ALERTING_IR3,
				PL_ALERTING_IR4,
				0x00,
				PL_ALERTING_DR40,
				PL_ALERTING_DR41,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_VOIP_DIAL_TONE
		{
		1, // Next Cadence 1 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.3s On 0.2s Off
				PL_VOIP_DIAL_C0_IR0,
				PL_VOIP_DIAL_C0_IR1,
				0x00,
				PL_VOIP_DIAL_C0_DR36,
				PL_VOIP_DIAL_C0_DR37,
				PL_VOIP_DIAL_C0_DR38,
				PL_VOIP_DIAL_C0_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		0, // Next Cadence 0 Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 1.6s On 0.2s Off
				PL_VOIP_DIAL_C1_IR0,
				PL_VOIP_DIAL_C1_IR1,
				0x00,
				PL_VOIP_DIAL_C1_DR36,
				PL_VOIP_DIAL_C1_DR37,
				PL_VOIP_DIAL_C1_DR38,
				PL_VOIP_DIAL_C1_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_VOIP_MSG_WAITING_TONE = PL_MSG_WAITING_TONE
		{
		1, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.2s On 0.2s Off
				PL_MSG_WAITING_C013_IR0,
				PL_MSG_WAITING_C013_IR1,
				0x00,
				PL_MSG_WAITING_C013_DR36,
				PL_MSG_WAITING_C013_DR37,
				PL_MSG_WAITING_C013_DR38,
				PL_MSG_WAITING_C013_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
			{
		2, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.2s On 0.2s Off
				PL_MSG_WAITING_C013_IR0,
				PL_MSG_WAITING_C013_IR1,
				0x00,
				PL_MSG_WAITING_C013_DR36,
				PL_MSG_WAITING_C013_DR37,
				PL_MSG_WAITING_C013_DR38,
				PL_MSG_WAITING_C013_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		3, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.4s On 0.4s Off
				PL_MSG_WAITING_C2_IR0,
				PL_MSG_WAITING_C2_IR1,
				0x00,
				PL_MSG_WAITING_C2_DR36,
				PL_MSG_WAITING_C2_DR37,
				PL_MSG_WAITING_C2_DR38,
				PL_MSG_WAITING_C2_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		4, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.2s On 0.2s Off
				PL_MSG_WAITING_C013_IR0,
				PL_MSG_WAITING_C013_IR1,
				0x00,
				PL_MSG_WAITING_C013_DR36,
				PL_MSG_WAITING_C013_DR37,
				PL_MSG_WAITING_C013_DR38,
				PL_MSG_WAITING_C013_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
		{
		0, // No Next Cadence Osc1
		0, // No Next Cadence Osc2
			{
				{ // OSC1	425Hz -6dBm0 0.2s On 0.5s Off
				PL_MSG_WAITING_C4_IR0,
				PL_MSG_WAITING_C4_IR1,
				0x00,
				PL_MSG_WAITING_C4_DR36,
				PL_MSG_WAITING_C4_DR37,
				PL_MSG_WAITING_C4_DR38,
				PL_MSG_WAITING_C4_DR39
				},
				{ // OSC2 Not Used
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00,
				0x00
				},
			},
		},
	},

	{ // PL_DTMF_DIG_0_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -11dBm0 80ms On
				PL_DTMF_FREQ_941Hz,
				PL_DTMF_F941Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1336Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1336Hz,
				PL_DTMF_F1336Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_1_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz 11dBm0 80ms On
				PL_DTMF_FREQ_697Hz,
				PL_DTMF_F697Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1209Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1209Hz,
				PL_DTMF_F1209Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_2_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -11dBm0 80ms On
				PL_DTMF_FREQ_697Hz,
				PL_DTMF_F697Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1336Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1336Hz,
				PL_DTMF_F1336Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_3_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -11dBm0 80ms On
				PL_DTMF_FREQ_697Hz,
				PL_DTMF_F697Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1477Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1477Hz,
				PL_DTMF_F1477Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_4_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -11dBm0 80ms On
				PL_DTMF_FREQ_770Hz,
				PL_DTMF_F770Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1209Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1209Hz,
				PL_DTMF_F1209Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_5_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -11dBm0 80ms On
				PL_DTMF_FREQ_770Hz,
				PL_DTMF_F770Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1336Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1336Hz,
				PL_DTMF_F1336Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_6_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -11dBm0 80ms On
				PL_DTMF_FREQ_770Hz,
				PL_DTMF_F770Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1477Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1477Hz,
				PL_DTMF_F1477Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_7_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -11dBm0 80ms On
				PL_DTMF_FREQ_852Hz,
				PL_DTMF_F852Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1209Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1209Hz,
				PL_DTMF_F1209Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_8_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -11dBm0 80ms On
				PL_DTMF_FREQ_852Hz,
				PL_DTMF_F852Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1336Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1336Hz,
				PL_DTMF_F1336Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_9_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -11dBm0 80ms On
				PL_DTMF_FREQ_852Hz,
				PL_DTMF_F852Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1477Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1477Hz,
				PL_DTMF_F1477Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_A_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 697Hz -11dBm0 80ms On
				PL_DTMF_FREQ_697Hz,
				PL_DTMF_F697Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1633Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1633Hz,
				PL_DTMF_F1633Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_B_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 770Hz -11dBm0 80ms On
				PL_DTMF_FREQ_770Hz,
				PL_DTMF_F770Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1633Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1633Hz,
				PL_DTMF_F1633Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_C_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 852Hz -11dBm0 80ms On
				PL_DTMF_FREQ_852Hz,
				PL_DTMF_F852Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1633Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1633Hz,
				PL_DTMF_F1633Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_D_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -11dBm0 80ms On
				PL_DTMF_FREQ_941Hz,
				PL_DTMF_F941Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1633Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1633Hz,
				PL_DTMF_F1633Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_STAR_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -11dBm0 80ms On
				PL_DTMF_FREQ_941Hz,
				PL_DTMF_F941Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1209Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1209Hz,
				PL_DTMF_F1209Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
	
	{ // PL_DTMF_DIG_HASH_TONE_LOCAL
		{
		0,  // No Next Cadence Osc1
		0,  // No Next Cadence Osc1
			{
				{ // OSC1 941Hz -11dBm0 80ms On
				PL_DTMF_FREQ_941Hz,
				PL_DTMF_F941Hz_AMP_M11dBm0,
				0x00,
				PL_DTMF_DR36,
				PL_DTMF_DR37,
				0x00,
				0x00
				},
				{ // OSC2 1477Hz -9dBm0 80ms On
				PL_DTMF_FREQ_1477Hz,
				PL_DTMF_F1477Hz_AMP_M9dBm0,
				0x00,
				PL_DTMF_DR40,
				PL_DTMF_DR41,
				0x00,
				0x00
				},
			},
		},
	},
};


