
#include <linux/module.h>
#include <linux/tty.h>
#include <linux/proc_fs.h>
#include <asm/uaccess.h>

#include <oswrapper.h>
#include <processor.h>

#include "include/slic_proc.h"
#include "include/si3050.h"

extern UCHAR si3050_readReg(UCHAR address);
extern void si3050_writeReg(UCHAR address,UCHAR data);


// name for the file;
#define si3050_proc_filename "si3050"
static struct proc_dir_entry * si3050_dir_entry; // procfs filename 

// read  a register, if indirect != 0 => indirect register 
static unsigned char si3050_read_register(int regn, int indirect)
{
unsigned char ret;
    if (regn > 60) return 0;
    if (indirect) printk("SLIC si3050 does not have indirect registeres\n");

  osLockInterrupts();	/* Sagem qualif only */
    ret = si3050_readReg(regn);
  osUnlockInterrupts();	/* Sagem qualif only */

    return ret;
}

// write a register, if indirect != 0 => indirect register
static void si3050_write_register(int regn, unsigned char value, int indirect)
{
    if (regn > 60) return;
    if (indirect) printk("SLIC si3050 does not have indirect registeres\n");

  osLockInterrupts();	/* Sagem qualif only */
    si3050_writeReg(regn, value);
  osUnlockInterrupts();	/* Sagem qualif only */

}

void show_spi_ctl(unsigned short spi_ctl)
{
    const char * spi_ctl_timod[] = { "InitOnRead", "InitOnWrite", "Reserved", "Reserved"};
    const char * spi_ctl_sz []   = { "sz", "SZ" };
    const char * spi_ctl_gm []   = { "gm", "GM" };
    const char * spi_ctl_psse [] = { "psse", "PSSE"};
    const char * spi_ctl_emiso []= { "emiso", "EMSIO"};
    const char * spi_ctl_size [] = { "8bit", "16bit"};
    const char * spi_ctl_lsbf [] = { "MSBf", "LSBf"};
    const char * spi_ctl_cpha [] = { "cpha", "CPHA"};
    const char * spi_ctl_cpol [] = { "clkActHigh", "clkActLow"};
    const char * spi_ctl_mstr [] = { "SPI:Slave", "Spi:Master"};
    const char * spi_ctl_wom  [] = { "NormalO", "OpenDrain"};
    const char * spi_ctl_spe  [] = { "SPI:Disabled", "SPI:Enable"};
    
    printk("0x%x : [%s %s %s %s %s %s %s %s %s %s %s %s]\n",  spi_ctl, 
	    spi_ctl_spe [(spi_ctl & (1 <<14) ) >>14 ],
	    spi_ctl_wom [(spi_ctl & (1 <<13) ) >>13 ],
	    spi_ctl_mstr[(spi_ctl & (1 <<12) ) >>12 ],
	    spi_ctl_cpol[(spi_ctl & (1 <<11) ) >>11 ],
	    spi_ctl_cpha[(spi_ctl & (1 <<10) ) >>10 ],
	    spi_ctl_lsbf[(spi_ctl & (1 << 9) ) >> 9 ],
	    spi_ctl_size[(spi_ctl & (1 << 8) ) >> 7 ],
	    spi_ctl_emiso[(spi_ctl& (1 << 5) ) >> 5 ],
	    spi_ctl_psse[(spi_ctl & (1 << 4) ) >> 4 ],
	    spi_ctl_gm  [(spi_ctl & (1 << 3) ) >> 3 ],
	    spi_ctl_sz  [(spi_ctl & (1 << 2) ) >> 2 ],
	    spi_ctl_timod[spi_ctl & 0x3]); 
}

// procfs write function :
static int si3050_procfs_write (struct file * file, const char * buffer, unsigned long count, void * data)
{
    int reg;
    unsigned int val;
    int indirect;
    // warning data comes from userland !
    char cmdbuf [40] = {0}; // this is too much, but that's ok at least
    
    if ( count > 39 ) return -EFAULT;

    if (copy_from_user (cmdbuf, buffer, count))
    {
	printk("SLIC: si3050 can't get copy_from_user !!\n");
	return -EFAULT;
    }
    
    switch( slic_proc_decode_cmd(cmdbuf, count,  &reg, &val, &indirect) )
    {
	case SLIC_PROC_WRITE_REG :
		si3050_write_register(reg, val,  indirect);
		return count;
		break;
	case SLIC_PROC_READ_REG :
		printk("Read register %d r%d=0x%x\n", reg, reg, si3050_read_register(reg, indirect));
		return count;
		break;

	case SLIC_PROC_SHOW_SPI_CONF :
		{
		    unsigned short spi_baud = * (volatile unsigned short *) SPI_BAUD_ADDRESS;
		    unsigned short spi_ctl = * (volatile unsigned short *) SPI_CTRL_ADDRESS;

		    
		    const char * spi_stat_spif[] = { "spif", "SPIF"};
		    const char * spi_stat_modf[] = { "modf", "MODF"};
		    const char * spi_stat_txe [] = { "txe", "TXE"};
		    const char * spi_stat_txs [] = { "txs", "TXS"};
		    const char * spi_stat_rbsy[] = { "rbsy", "RBSY"};
		    const char * spi_stat_rxs [] = { "rxs", "RXS" };
		    const char * spi_stat_txcol[]= { "txcol", "TXCOL"};
		    
		    unsigned short spi_status;

		    const char *hex2bin [] = { 
						"0000", "0001", "0010", "0011", "0100", "0101", "0110", "0111",
						"1000", "1001", "1010", "1011", "1100", "1101", "1110", "1111",
					      };
		    unsigned short spi_flag;	
		    
		    printk("SLIC si3050: *** SPI Config ***\n"); 
		    
		    printk("SLIC si3050: SPI_BAUD = 0x%x => Frequency = %u MHz\n", spi_baud, 100 / (2 * spi_baud));
		    printk("SLIC si3050: SPI_CTL "); show_spi_ctl(spi_ctl);
		    
		    spi_status = * (unsigned short *) SPI_STATUS_ADDRESS;
		    printk("SLIC si3050: SPI_ST   = 0x%x [%s %s %s %s %s %s %s]\n",   spi_status,
			    spi_stat_txcol[(spi_status & (1 << 6) ) >> 6],
			    spi_stat_rxs [ (spi_status & (1 << 5) ) >> 5],
			    spi_stat_rbsy[ (spi_status & (1 << 4) ) >> 4],
			    spi_stat_txs [ (spi_status & (1 << 3) ) >> 3],
			    spi_stat_txe [ (spi_status & (1 << 2) ) >> 2],
			    spi_stat_modf[ (spi_status & (1 << 1) ) >> 1],
			    spi_stat_spif[ (spi_status & (1 << 0) ) >> 0]
			    );
		    
		    spi_flag = * (unsigned short *) SPI_FLAG_ADDRESS;
		    printk("SLIC si3050: SPI_FLAG = 0x%4x [%s.%s:%s.%s]\n", 
			    spi_flag, 
			    hex2bin[ (spi_flag & 0xF000) >>12 ],
			    hex2bin[ (spi_flag & 0x0F00) >> 8 ],
			    hex2bin[ (spi_flag & 0x00F0) >> 4 ], 
			    hex2bin[ (spi_flag & 0x000F) >> 0 ] );
		    return count;
		    break;
		}

	case SLIC_PROC_SETBAUD:
		printk("SLIC si3050: set SPI baudrate to 0x%x\n", val);
		(* (unsigned short *) SPI_BAUD_ADDRESS ) = val;
		return count;
		break;	
		
	default:
		printk("SLIC: si3050 : Don't understand the command '%s'\n", cmdbuf);
		return -EFAULT;
		break;
    } 

    return -EFAULT;
}


// structure used to define all registers :

struct register_info 
{
    int number; 	// the register number
    char * name;	// the name of the register
    int indirect;		// is the register direct or not (1 => indirect)
};

// big register information  !
static struct register_info register_description [] = 
{
    { 1, 	"(Control 1)               ", 0},
    { 2, 	"(Control 2)               ", 0},
    { 3,	"(Interrupt Mask)          ", 0},
    { 4,	"(Interrupt Source)        ", 0},
    { 5,	"(DAA Control 1)           ", 0},
    { 6, 	"(DAA Control 2)           ", 0},
    { 7, 	"(Sample Rate)             ", 0},
    { 10, 	"(DAA Control 3)           ", 0},
    { 11, 	"(Sys./ Ln-Side Dev. Rev.) ", 0},
    { 12,	"(Line side device status) ", 0},
    { 13,	"(Line side device rev.)   ", 0},
    { 14,       "(DAA Control 4)           ", 0},
    { 15, 	"(TX/RX Gain Control 1)    ", 0},
    { 16,       "(Internation Control 1)   ", 0},
    { 17,       "(Internation Control 2)   ", 0},
    { 18,       "(Internation Control 3)   ", 0},
    { 19,       "(Internation Control 4)   ", 0},
    { 20,       "(Call Progress RX Att.)   ", 0},
    { 21,       "(Call Progress TX Att.)   ", 0},
    { 22,       "(Ring Validation Ctrl 1)  ", 0},
    { 23,       "(Ring Validation Ctrl 2)  ", 0},
    { 24,       "(Ring Validation Ctrl 3)  ", 0},
    { 25,       "(Resistor Calibration)    ", 0},
    { 26,       "(DC Termination Control)  ", 0},
    { 28,       "(Loop Current Status)     ", 0},
    { 29,       "(Line Voltage Status)     ", 0},
    { 30,       "(AC Termination Control)  ", 0},
    { 31,       "(DAA Control 5)           ", 0},
    { 32,       "(Ground Start Control)    ", 0},
    { 33,       "(PCM/SPI Mode Select)     ", 0},
    { 34,       "(PCM Trans Start Cnt-L B.)", 0},
    { 35,       "(PCM Trans Start Cnt-H B.)", 0},
    { 36,       "(PCM Recv Start Cnt-L B.) ", 0},
    { 37,       "(PCM Recv Start Cnt-H B.) ", 0},
    { 38,       "(TX Gain Control 2)       ", 0},
    { 39,       "(RX Gain Control 2)       ", 0},
    { 40,       "(TX Gain Control 3)       ", 0},
    { 41,       "(RX Gain Control 3)       ", 0},
    { 42,       "(GCI Control 3)           ", 0},
    { 43,       "(Line Cur/Volt Thres Int.)", 0},
    { 44,       "(Ln Cur/Volt.ThresInt.Ctl)", 0},
    { 45,       "(Prog Hybrid Reg 1)       ", 0},
    { 46,       "(Prog Hybrid Reg 2)       ", 0},
    { 47,       "(Prog Hybrid Reg 3)       ", 0},
    { 48,       "(Prog Hybrid Reg 4)       ", 0},
    { 49,       "(Prog Hybrid Reg 5)       ", 0},
    { 50,       "(Prog Hybrid Reg 6)       ", 0},
    { 51,       "(Prog Hybrid Reg 7)       ", 0},
    { 52,       "(Prog Hybrid Reg 8)       ", 0},
    { 59,       "(Spark Quenching Control) ", 0},
};

static int register_number = 49;	// number of elements of the last array


#define N_REG_PER_LINE 2

// Read method used by user to read the procfs file :
int si3050_procfs_read(char * buff, char **buffchar, off_t offset, int buffer_length, int * eof, void * data)
{
    static char buffer [3*1024]; // this is huge, for test only !
    static int n;
    int ret = 0;

    // first reset the packet ...
    if (offset > 0 ) 
    {
	// Now we are here, is there still some stuffs to do ?
	if (offset >= n )
	{
	    *eof = 1;
	    ret = 0;
	} else {
	    // Stills some to do ... alrigth.
	    if (buffer_length > (n - offset ))
	    {
		memcpy(buff + offset, buffer + offset, (n - offset));
		ret = n; // return total read from begin
		*eof = 1;
	    } else {
		// still some more
		
		memcpy(buff + offset, buffer + offset, buffer_length);
		ret = buffer_length + offset; // must return total read from the beginning
	    }
	    
	}

    } else {

	// if we are at zero, then generate the buffer ...
	int i;
	
	n = 0;

	memset (buffer, 0, 3*1024);
	n += sprintf(buffer + n, "# Slic si3050 FXO, SPI Bus 2:0\n");

	for (i = 0; i < register_number ; i++)
	{
	    n += sprintf(buffer + n, "r%.2d %s = 0x%.2X %s", 
			  register_description[i].number,
			  register_description[i].name,
			  si3050_read_register(register_description[i].number, register_description[i].indirect),
			  (register_description[i].indirect) ? "[I]" : ""
		    );
	    // pagination 
	    if (  (((i+1) % N_REG_PER_LINE) == 0 ) && ( (i!=0) && (N_REG_PER_LINE != 1))  ) 
	    {
		n += sprintf(buffer + n, "\n");
	    }
	    else 
	    {
		n += sprintf(buffer + n, "  ");
	    }
	}
//	if ((i+1) % N_REG_PER_LINE != 0) n += sprintf(buffer + n, "\n");
	n += sprintf(buffer + n, "\n");
/*
	n += sprintf(buffer + n, "# Use 'echo rN=0xXX > /proc/bus/spi/slic/" si3050_proc_filename "' to modify a direct register\n");
	n += sprintf(buffer + n, "#  - where N is the number of the register\n");
	n += sprintf(buffer + n, "#  - and XX the hexadecimal value you want to write in\n");
	n += sprintf(buffer + n, "# 'echo read rN > /proc/bus/spi/slic/" si3050_proc_filename"' to read only one regsiter\n");
	n += sprintf(buffer + n, "# 'echo reset spi > /proc/bus/spi/slic/" si3050_proc_filename"' to reset the SPI automat\n");
	n += sprintf(buffer + n, "# additionnal commands : \n");
	n += sprintf(buffer + n, "# spi config: \n");
	n += sprintf(buffer + n, "# trace <on/off>: \n");
	n += sprintf(buffer + n, "# spi setbaud 0xXXXX: \n");
	n += sprintf(buffer + n, "# spi setctl 0xXXXX: \n");
	n += sprintf(buffer + n, "# spi setcs <auto/off>: \n");
	n += sprintf(buffer + n, "# spi setreset <auto/off>: \n");
*/
	n += sprintf(buffer + n, "State %d Vmax %d Polarite %d \n", fxoState, si3050_vmax, si3050_pola_pos);

	n ++; // 0 character
	n += sprintf(buffer + n, "# %d bytes read\n", n - 1); //Use this to tune the buffer size

	// buffer is now ready, and n contains the size of it ...
	// return the first buffer_length buffer ..
	
	if (n >  buffer_length) 
	{
	    memcpy(buff, buffer, buffer_length);
	    //ret = buffer_length;
	    ret = buffer_length;
	} else {
	    memcpy(buff, buffer, n);
	    ret = n;
	    *eof = 1;
	}
    }
    return ret;
}


// Called to init the procfs ( to create a file ... in the proc) 
int slic_si3050_proc_init(void)
{
    si3050_dir_entry = create_proc_entry(si3050_proc_filename, 0644, proc_bus_spi_slic);
    if (!si3050_dir_entry)
    {
	printk("SLIC : can't create si3050 proc entry\n");
	return 1;
    }

    si3050_dir_entry->read_proc = si3050_procfs_read;
    si3050_dir_entry->write_proc = si3050_procfs_write;
    si3050_dir_entry->owner = THIS_MODULE;
    si3050_dir_entry->mode = S_IFREG | 0644;
    si3050_dir_entry->uid = 0;
    si3050_dir_entry->gid = 0;
    si3050_dir_entry->size = 2305; // change the file size !! 
    
    return 0;
}

// Called to cleanup the module procfs entry
void slic_si3050_proc_cleanup(void)
{
    remove_proc_entry(si3050_proc_filename, proc_bus_spi_slic);
}
