#include <linux/kernel.h>
#include <linux/module.h>
#include <linux/tty.h>
#include <linux/proc_fs.h>
#include <linux/ctype.h>

#include <oswrapper.h>
#include "include/slic_proc.h"


struct proc_dir_entry * proc_bus_spi; // Used to keep track of the /proc/bus/spi directory created

// This one has to be public ... 
struct proc_dir_entry * proc_bus_spi_slic; // /proc/bus/spi/slic directory created

#define help_file_filename "README"
static struct proc_dir_entry * help_file_entry; // procfs filename 

// return a number of command if the cmd is a command

// This function decode a command from the user, return 0 in success, -1 and printk a warning if error
// returns the command number (defined in slic_proc.h), -1 if not a command
// cmd is lowered ... 
int slic_proc_decode_cmd(char * cmd, int count, int * reg, unsigned int * value, int * indirect)
{
     
    int r;
    int val;
    int indir;
    char * offset;
    int n;
    int i;

    // first lower all the cmd;

    for (i = 0; i < count; i++) cmd[i] = tolower(cmd[i]);
    
    // first test if it is a write command ( rN=0xXXX [indirect])
     
    do // this while is used to separate different recognitions blocks
    {
	offset = strchr(cmd, 'r');
	if (!offset) break; // if can't find the first 'r' then that's not a write cmd

	n = sscanf(offset, "r%d", &r);
	if (n != 1) break; 


	if (!(offset = strchr(offset, '=')) ) break;
	offset ++;
	
	while (offset - cmd < count && (*offset == ' ' || *offset == '\t') ) offset ++; // eat the blanks
	if (offset - cmd >= count) break; // no more chars ?

	n = sscanf(offset, "0x%x", &val); 
	if (n != 1) break;
	

	if (strstr(offset, "indirect")) indir = 1;
	else indir = 0;

	*reg = r;
	*value = val;
	*indirect = indir;
	return SLIC_PROC_WRITE_REG;
    } while (0);
    // is it a read command then ?? read rN [indirect]
    do 
    {
	offset = strstr(cmd, "read");
	if (!offset) break;

	offset = strchr(offset + 4, 'r');
	if (!offset) break;

	n = sscanf(offset, "r%d", &r);
	if (n != 1) break;
	
	if (strstr(offset, "indirect")) indir = 1;
	else indir = 0;

	*reg = r;
	*indirect = indir;
	return SLIC_PROC_READ_REG;

    } while(0);

#ifdef FIRMWARE_CONF_COUNTRY_NL
    // is it a FXS line monitoring command ?
    do 
    {
	int on;
	offset = strstr(cmd, "volt"); 
	if (! offset) break;

	if ( strstr(offset + 5, "on"))
		on = LINE_MONITORING_YES;
	else
		if (strstr(offset + 5, "off"))
			on = LINE_MONITORING_NO;
	else break;

	*value = on;
	return SLIC_PROC_LINE_MONITORING;
    } while (0);
#endif

    // is it a reset_spi command : reset spi
    do 
    {
	offset = strstr(cmd, "reset");
	if (!offset) break;
    
	offset = strstr(offset + 5, "spi");
	if (!offset) break;
	
	return SLIC_PROC_RESET_SPI;
	
    } while(0);

    // is it a trace command ?
    do 
    {
	int on;
	offset = strstr(cmd, "trace"); 
	if (! offset) break;

	if ( strstr(offset + 5, "on")) on = 1;
	else if (strstr(offset + 5, "off")) on = 0;
	else break;

	*indirect = on;
	return SLIC_PROC_TRACE;
    } while (0);

    // show spi config : "spi config"	
    do 
    {
	offset = strstr(cmd, "spi");
	if (!offset) break;

	if (!strstr(offset + 3, "config")) break;
	return SLIC_PROC_SHOW_SPI_CONF;	
    } while (0);


    // set baudrate : "spi setbaud 0xXXXX"
    do
    {
	offset = strstr(cmd, "spi");
	if (!offset) break;

	offset = strstr(offset + 3, "setbaud");
	if (!offset) break;
	
	offset +=7;

	while (offset - cmd < count && (*offset == ' ' || *offset == '\t') ) offset ++; // eat the blanks
	if (offset - cmd >= count) break; // no more chars ?
	
	n = sscanf(offset, "0x%x", &val);
	if (n != 1) break;

	*value = val;

	return SLIC_PROC_SETBAUD;
    } while (0);

    // set cs auto raise or not "spi setcs auto" / "spi setcs off"
    do 
    {
	offset = strstr(cmd, "spi");
	if (!offset) break; 

	offset = strstr(offset + 3, "setcs");
	if (!offset) break;

	if ( strstr(offset + 5, "auto")) indir = 1;
	else if (strstr(offset + 5, "off")) indir = 0;
	else break;
	*indirect = indir;
	return SLIC_PROC_SET_CS_RAISE;
    } while (0);

    
    //	 "spi setreset <auto/off>"
    do 
    {
	offset = strstr(cmd, "spi");
	if (!offset) break; 

	offset = strstr(offset + 3, "setreset");
	if (!offset) break;

	if ( strstr(offset + 5, "auto")) indir = 1;
	else if (strstr(offset + 5, "off")) indir = 0;
	else break;
	*indirect = indir;
	return  SLIC_PROC_SET_AUTORESET; 
    } while (0);

    //	 "spi setctl 0xXXXX"
    do 
    {
	offset = strstr(cmd, "spi");
	if (!offset) break; 

	offset = strstr(offset + 3, "setctl");
	if (!offset) break;

	offset += 6;

	while (offset - cmd < count && (*offset == ' ' || *offset == '\t') ) offset ++; // eat the blanks
	if (offset - cmd >= count) break; // no more chars ?
	
	n = sscanf(offset, "0x%x", &val);
	if (n != 1) break;

	*value = val;
	return SLIC_PROC_SET_SPI_CTL;
    } while (0);

    do 
    {
	offset = strstr(cmd, "spi");
	if (!offset) break;

	offset = strstr(offset + 3, "usehack");
	if (!offset) break;

	if (strstr(offset + 7, "on")) indir = 1;
	else if (strstr(offset + 7, "off")) indir = 0;
	else break;

	*indirect = indir;
	return SLIC_PROC_USE_HACK;
	
    } while (0);

    return -1;
}

/********** README file fonction *****************/
static int help_file_procfs_write (struct file * file, const char * buffer, unsigned long count, void * data)
{
return -EFAULT;
}

int help_file_procfs_read(char * buff, char **buffchar, off_t offset, int buffer_length, int * eof, void * data)
{
	static char buffer [3*1024]; // this is huge, for test only !
	static int n;
	int ret = 0;
	
	n = 0;

	memset (buffer, 0, 3*1024);

	n += sprintf(buffer + n, "# -----------------------------------------------------------------------------\n");
	n += sprintf(buffer + n, "# - list of command for SLIC: file si3050, si3216-0 and si3216-1 (if created) -\n");
	n += sprintf(buffer + n, "# -----------------------------------------------------------------------------\n");

//	n += sprintf(buffer + n, "# Use 'echo rN=0xXX > /proc/bus/spi/slic/si3xxxxx to modify a direct register\n");
//	n += sprintf(buffer + n, "# or  'echo rN=0xXXXX indirect > /proc/bus/spi/slic/si3216-x to modify an indirect register\n");

	n += sprintf(buffer + n, "# Use 'echo rN=0xXX > si3xxxxx' to modify a direct register\n");
	n += sprintf(buffer + n, "# Use 'echo rN=0xXXXX indirect > si3216-x' to modify an indirect register\n");
	n += sprintf(buffer + n, "#  - where N is the number of the register (decimal)\n");
	n += sprintf(buffer + n, "#  - and XX or XXXX the hexadecimal value you want to write in\n");
	n += sprintf(buffer + n, "#\n");

#ifdef FIRMWARE_CONF_COUNTRY_NL
	n += sprintf(buffer + n, "# Use 'volt x > si3216' to monitoring FXS line voltage\n");
	n += sprintf(buffer + n, "#  - where x is on/off\n");
	n += sprintf(buffer + n, "#\n");
#endif

	n += sprintf(buffer + n, "# Use 'cat si3xxxxx' to read all regsiters\n");
	n += sprintf(buffer + n, "#\n");

	n += sprintf(buffer + n, "# -------------------------------------------------------------------------\n");
	n += sprintf(buffer + n, "# ----- list of command for TONE: generating tone and ring on a phone -----\n");
	n += sprintf(buffer + n, "# -------------------------------------------------------------------------\n");

	n += sprintf(buffer + n, "# Use 'echo tone x N > tone' to command tone\n");
	n += sprintf(buffer + n, "# Use 'echo tone x > tone' for quit tone\n");
	n += sprintf(buffer + n, "# - where x is the port number (0 or 1)\n");
	n += sprintf(buffer + n, "# - and N is the number of the tone\n");
	n += sprintf(buffer + n, "#\n");
	n += sprintf(buffer + n, "# the phone must be OFFHOOK for tone test\n");
	n += sprintf(buffer + n, "# the phone must be ONHOOK  for ring test\n");
	n += sprintf(buffer + n, "# those test can be do when test api (sigVoip) is runing \n");
	n += sprintf(buffer + n, "#\n");
	n += sprintf(buffer + n, "# No read fonction\n");
	n += sprintf(buffer + n, "#\n");
	n += sprintf(buffer + n, "# tone aviable are:\n");
	n += sprintf(buffer + n, "#  0: DIAL_TONE\n");
	n += sprintf(buffer + n, "#  1: RING_BACK_TONE\n");
	n += sprintf(buffer + n, "#  2: BUSY1_TONE\n");
	n += sprintf(buffer + n, "#  3: ERROR_TONE\n");
	n += sprintf(buffer + n, "#  4: CALL_WAITING_TONE1\n");
	n += sprintf(buffer + n, "#  7: OFFHOOK_WARNING_TONE\n");
	n += sprintf(buffer + n, "# 14: DIG_0_TONE\n");
	n += sprintf(buffer + n, "# 15: DIG_1_TONE\n");
	n += sprintf(buffer + n, "# 16: DIG_2_TONE\n");
	n += sprintf(buffer + n, "# 17: DIG_3_TONE\n");
	n += sprintf(buffer + n, "# 18: DIG_4_TONE\n");
	n += sprintf(buffer + n, "# 19: DIG_5_TONE\n");
	n += sprintf(buffer + n, "# 20: DIG_6_TONE\n");
	n += sprintf(buffer + n, "# 21: DIG_7_TONE\n");
	n += sprintf(buffer + n, "# 22: DIG_8_TONE\n");
	n += sprintf(buffer + n, "# 23: DIG_9_TONE\n");
	n += sprintf(buffer + n, "# 24: DIG_A_TONE\n");
	n += sprintf(buffer + n, "# 25: DIG_B_TONE\n");
	n += sprintf(buffer + n, "# 26: DIG_C_TONE\n");
	n += sprintf(buffer + n, "# 27: DIG_D_TONE\n");
	n += sprintf(buffer + n, "# 28: DIG_STAR_TONE\n");
	n += sprintf(buffer + n, "# 29: DIG_HASH_TONE\n");
	n += sprintf(buffer + n, "# 30: CPE_ALERTING_TONE\n");
	n += sprintf(buffer + n, "# 33: CALL_IN_PROGRESS\n");
	n += sprintf(buffer + n, "# 38: MESG_WAITING_INDICATOR_TONE\n");
	n += sprintf(buffer + n, "# 41: VOIP_DIAL_TONE\n");
	n += sprintf(buffer + n, "# 42: VOIP_MESG_WAITING_INDICATOR_TONE\n");
	n += sprintf(buffer + n, "# 46: RINGING \n");
	n += sprintf(buffer + n, "#\n");


	n += sprintf(buffer + n, "# ------------------------------------------------\n");
	n += sprintf(buffer + n, "# ---- additionnal commands for SPI control: -----\n");
	n += sprintf(buffer + n, "# ------------------------------------------------\n");
	n += sprintf(buffer + n, "# 'echo reset spi > /proc/bus/spi/slic/si3050 to reset the SPI automat\n");
	n += sprintf(buffer + n, "# spi config: \n");
	n += sprintf(buffer + n, "# trace <on/off>: \n");
	n += sprintf(buffer + n, "# spi setbaud 0xXXXX: \n");
	n += sprintf(buffer + n, "# spi setctl 0xXXXX: \n");
	n += sprintf(buffer + n, "# spi setcs <auto/off>: \n");
	n += sprintf(buffer + n, "# spi setreset <auto/off>: \n");

	if (n >  buffer_length) 
		{
		memcpy(buff, buffer, buffer_length);
		ret = buffer_length;
		}
	else 
		{
		memcpy(buff, buffer, n);
		ret = n;
		*eof = 1;
		}
return(ret);
}


// Initializes the procfs entries, return a non zero value on error
int slic_init_procfs(void)
{
    // first create our directory : /proc/bus/spi/slic
    if (!proc_bus)
    {
	printk("SLIC: /proc/bus does not exists !!! I can't create my directory\n");
	return 1;
    }
    
    proc_bus_spi = proc_mkdir("spi", proc_bus);
    
    if (!proc_bus_spi)
    {
	printk("SLIC: Can't create /proc/bus/spi !!!\n");
	return 1;
    }

    proc_bus_spi_slic = proc_mkdir("slic", proc_bus_spi);

    if (!proc_bus_spi_slic)
    {
	printk("SLIC: Can't create /proc/bus/spi/slic !!!\n");
	return 1;
    }

    // Everything is fine now, can call specific proc drivers now
    
    
    
#if 0
    if (spi_bus_proc_init() != 0) 
    {
	printk("SLIC: spi bus proc init failed\n");
	return 1;
    }
#endif

    if (slic_si3050_proc_init() != 0) 
    {
	printk("SLIC: Si3250 proc init failed\n");
	return 1;
    }

    if (slic_si3216_proc_init() != 0) 
    {
	printk("SLIC: Si3216 proc init failed\n");
	return 1;
    }

    if (tone_proc_init() != 0) 
    {
	printk("SLIC: tone proc init failed\n");
	return 1;
    }

    /**** fichier d'aide *******/
    help_file_entry = create_proc_entry(help_file_filename, 0644, proc_bus_spi_slic);
    if (!help_file_entry)
    {
	printk("SLIC : can't create README proc entry\n");
	return 1;
    }

    help_file_entry->read_proc = help_file_procfs_read;
    help_file_entry->write_proc = help_file_procfs_write;
    help_file_entry->owner = THIS_MODULE;
    help_file_entry->mode = S_IFREG | 0644;
    help_file_entry->uid = 0;
    help_file_entry->gid = 0;
    help_file_entry->size = 2305; // change the file size !! 
    

    return 0;   
}

// cleanup the procfs entries
void slic_remove_procfs(void)
{
    slic_si3050_proc_cleanup();
    slic_si3216_proc_cleanup();
#if 0
    spi_proc_bus_cleanup();
#endif

    remove_proc_entry(help_file_filename, proc_bus_spi_slic);

    if (proc_bus_spi_slic && proc_bus_spi) remove_proc_entry("slic", proc_bus_spi);
    if (proc_bus && proc_bus_spi) remove_proc_entry("spi", proc_bus);
}
